div.bootstrap {
  /*!
   * Bootstrap v4.0.0 (https://getbootstrap.com)
   * Copyright 2011-2018 The Bootstrap Authors
   * Copyright 2011-2018 Twitter, Inc.
   * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
   */
  /*# sourceMappingURL=bootstrap.min.css.map */ }
  div.bootstrap :root {
    --blue:#007bff;
    --indigo:#6610f2;
    --purple:#6f42c1;
    --pink:#e83e8c;
    --red:#dc3545;
    --orange:#fd7e14;
    --yellow:#ffc107;
    --green:#28a745;
    --teal:#20c997;
    --cyan:#17a2b8;
    --white:#fff;
    --gray:#6c757d;
    --gray-dark:#343a40;
    --primary:#007bff;
    --secondary:#6c757d;
    --success:#28a745;
    --info:#17a2b8;
    --warning:#ffc107;
    --danger:#dc3545;
    --light:#f8f9fa;
    --dark:#343a40;
    --breakpoint-xs:0;
    --breakpoint-sm:576px;
    --breakpoint-md:768px;
    --breakpoint-lg:992px;
    --breakpoint-xl:1200px;
    --font-family-sans-serif:-apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,"Helvetica Neue",Arial,sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol";
    --font-family-monospace:SFMono-Regular,Menlo,Monaco,Consolas,"Liberation Mono","Courier New",monospace; }
  div.bootstrap *, div.bootstrap ::after, div.bootstrap ::before {
    box-sizing: border-box; }
  div.bootstrap html {
    font-family: sans-serif;
    line-height: 1.15;
    -webkit-text-size-adjust: 100%;
    -ms-text-size-adjust: 100%;
    -ms-overflow-style: scrollbar;
    -webkit-tap-highlight-color: transparent; }
@-ms-viewport {
  div.bootstrap {
    width: device-width; } }
  div.bootstrap article, div.bootstrap aside, div.bootstrap dialog, div.bootstrap figcaption, div.bootstrap figure, div.bootstrap footer, div.bootstrap header, div.bootstrap hgroup, div.bootstrap main, div.bootstrap nav, div.bootstrap section {
    display: block; }
  div.bootstrap body {
    margin: 0;
    font-family: -apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,"Helvetica Neue",Arial,sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol";
    font-size: 1rem;
    font-weight: 400;
    line-height: 1.5;
    color: #212529;
    text-align: left;
    background-color: #fff; }
  div.bootstrap [tabindex="-1"]:focus {
    outline: 0 !important; }
  div.bootstrap hr {
    box-sizing: content-box;
    height: 0;
    overflow: visible; }
  div.bootstrap h1, div.bootstrap h2, div.bootstrap h3, div.bootstrap h4, div.bootstrap h5, div.bootstrap h6 {
    margin-top: 0;
    margin-bottom: .5rem; }
  div.bootstrap p {
    margin-top: 0;
    margin-bottom: 1rem; }
  div.bootstrap abbr[data-original-title], div.bootstrap abbr[title] {
    text-decoration: underline;
    -webkit-text-decoration: underline dotted;
    text-decoration: underline dotted;
    cursor: help;
    border-bottom: 0; }
  div.bootstrap address {
    margin-bottom: 1rem;
    font-style: normal;
    line-height: inherit; }
  div.bootstrap dl, div.bootstrap ol, div.bootstrap ul {
    margin-top: 0;
    margin-bottom: 1rem; }
  div.bootstrap ol ol, div.bootstrap ol ul, div.bootstrap ul ol, div.bootstrap ul ul {
    margin-bottom: 0; }
  div.bootstrap dt {
    font-weight: 700; }
  div.bootstrap dd {
    margin-bottom: .5rem;
    margin-left: 0; }
  div.bootstrap blockquote {
    margin: 0 0 1rem; }
  div.bootstrap dfn {
    font-style: italic; }
  div.bootstrap b, div.bootstrap strong {
    font-weight: bolder; }
  div.bootstrap small {
    font-size: 80%; }
  div.bootstrap sub, div.bootstrap sup {
    position: relative;
    font-size: 75%;
    line-height: 0;
    vertical-align: baseline; }
  div.bootstrap sub {
    bottom: -.25em; }
  div.bootstrap sup {
    top: -.5em; }
  div.bootstrap a {
    color: #007bff;
    text-decoration: none;
    background-color: transparent;
    -webkit-text-decoration-skip: objects; }
  div.bootstrap a:hover {
    color: #0056b3;
    text-decoration: underline; }
  div.bootstrap a:not([href]):not([tabindex]) {
    color: inherit;
    text-decoration: none; }
  div.bootstrap a:not([href]):not([tabindex]):focus, div.bootstrap a:not([href]):not([tabindex]):hover {
    color: inherit;
    text-decoration: none; }
  div.bootstrap a:not([href]):not([tabindex]):focus {
    outline: 0; }
  div.bootstrap code, div.bootstrap kbd, div.bootstrap pre, div.bootstrap samp {
    font-family: monospace,monospace;
    font-size: 1em; }
  div.bootstrap pre {
    margin-top: 0;
    margin-bottom: 1rem;
    overflow: auto;
    -ms-overflow-style: scrollbar; }
  div.bootstrap figure {
    margin: 0 0 1rem; }
  div.bootstrap img {
    vertical-align: middle;
    border-style: none; }
  div.bootstrap svg:not(:root) {
    overflow: hidden; }
  div.bootstrap table {
    border-collapse: collapse; }
  div.bootstrap caption {
    padding-top: .75rem;
    padding-bottom: .75rem;
    color: #6c757d;
    text-align: left;
    caption-side: bottom; }
  div.bootstrap th {
    text-align: inherit; }
  div.bootstrap label {
    display: inline-block;
    margin-bottom: .5rem; }
  div.bootstrap button {
    border-radius: 0; }
  div.bootstrap button:focus {
    outline: 1px dotted;
    outline: 5px auto -webkit-focus-ring-color; }
  div.bootstrap button, div.bootstrap input, div.bootstrap optgroup, div.bootstrap select, div.bootstrap textarea {
    margin: 0;
    font-family: inherit;
    font-size: inherit;
    line-height: inherit; }
  div.bootstrap button, div.bootstrap input {
    overflow: visible; }
  div.bootstrap button, div.bootstrap select {
    text-transform: none; }
  div.bootstrap [type=reset], div.bootstrap [type=submit], div.bootstrap button, div.bootstrap html [type=button] {
    -webkit-appearance: button; }
  div.bootstrap [type=button]::-moz-focus-inner, div.bootstrap [type=reset]::-moz-focus-inner, div.bootstrap [type=submit]::-moz-focus-inner, div.bootstrap button::-moz-focus-inner {
    padding: 0;
    border-style: none; }
  div.bootstrap input[type=checkbox], div.bootstrap input[type=radio] {
    box-sizing: border-box;
    padding: 0; }
  div.bootstrap input[type=date], div.bootstrap input[type=datetime-local], div.bootstrap input[type=month], div.bootstrap input[type=time] {
    -webkit-appearance: listbox; }
  div.bootstrap textarea {
    overflow: auto;
    resize: vertical; }
  div.bootstrap fieldset {
    min-width: 0;
    padding: 0;
    margin: 0;
    border: 0; }
  div.bootstrap legend {
    display: block;
    width: 100%;
    max-width: 100%;
    padding: 0;
    margin-bottom: .5rem;
    font-size: 1.5rem;
    line-height: inherit;
    color: inherit;
    white-space: normal; }
  div.bootstrap progress {
    vertical-align: baseline; }
  div.bootstrap [type=number]::-webkit-inner-spin-button, div.bootstrap [type=number]::-webkit-outer-spin-button {
    height: auto; }
  div.bootstrap [type=search] {
    outline-offset: -2px;
    -webkit-appearance: none; }
  div.bootstrap [type=search]::-webkit-search-cancel-button, div.bootstrap [type=search]::-webkit-search-decoration {
    -webkit-appearance: none; }
  div.bootstrap ::-webkit-file-upload-button {
    font: inherit;
    -webkit-appearance: button; }
  div.bootstrap output {
    display: inline-block; }
  div.bootstrap summary {
    display: list-item;
    cursor: pointer; }
  div.bootstrap template {
    display: none; }
  div.bootstrap [hidden] {
    display: none !important; }
  div.bootstrap .h1, div.bootstrap .h2, div.bootstrap .h3, div.bootstrap .h4, div.bootstrap .h5, div.bootstrap .h6, div.bootstrap h1, div.bootstrap h2, div.bootstrap h3, div.bootstrap h4, div.bootstrap h5, div.bootstrap h6 {
    margin-bottom: .5rem;
    font-family: inherit;
    font-weight: 500;
    line-height: 1.2;
    color: inherit; }
  div.bootstrap .h1, div.bootstrap h1 {
    font-size: 2.5rem; }
  div.bootstrap .h2, div.bootstrap h2 {
    font-size: 2rem; }
  div.bootstrap .h3, div.bootstrap h3 {
    font-size: 1.75rem; }
  div.bootstrap .h4, div.bootstrap h4 {
    font-size: 1.5rem; }
  div.bootstrap .h5, div.bootstrap h5 {
    font-size: 1.25rem; }
  div.bootstrap .h6, div.bootstrap h6 {
    font-size: 1rem; }
  div.bootstrap .lead {
    font-size: 1.25rem;
    font-weight: 300; }
  div.bootstrap .display-1 {
    font-size: 6rem;
    font-weight: 300;
    line-height: 1.2; }
  div.bootstrap .display-2 {
    font-size: 5.5rem;
    font-weight: 300;
    line-height: 1.2; }
  div.bootstrap .display-3 {
    font-size: 4.5rem;
    font-weight: 300;
    line-height: 1.2; }
  div.bootstrap .display-4 {
    font-size: 3.5rem;
    font-weight: 300;
    line-height: 1.2; }
  div.bootstrap hr {
    margin-top: 1rem;
    margin-bottom: 1rem;
    border: 0;
    border-top: 1px solid rgba(0, 0, 0, 0.1); }
  div.bootstrap .small, div.bootstrap small {
    font-size: 80%;
    font-weight: 400; }
  div.bootstrap .mark, div.bootstrap mark {
    padding: .2em;
    background-color: #fcf8e3; }
  div.bootstrap .list-unstyled {
    padding-left: 0;
    list-style: none; }
  div.bootstrap .list-inline {
    padding-left: 0;
    list-style: none; }
  div.bootstrap .list-inline-item {
    display: inline-block; }
  div.bootstrap .list-inline-item:not(:last-child) {
    margin-right: .5rem; }
  div.bootstrap .initialism {
    font-size: 90%;
    text-transform: uppercase; }
  div.bootstrap .blockquote {
    margin-bottom: 1rem;
    font-size: 1.25rem; }
  div.bootstrap .blockquote-footer {
    display: block;
    font-size: 80%;
    color: #6c757d; }
  div.bootstrap .blockquote-footer::before {
    content: "\2014 \00A0"; }
  div.bootstrap .img-fluid {
    max-width: 100%;
    height: auto; }
  div.bootstrap .img-thumbnail {
    padding: .25rem;
    background-color: #fff;
    border: 1px solid #dee2e6;
    border-radius: .25rem;
    max-width: 100%;
    height: auto; }
  div.bootstrap .figure {
    display: inline-block; }
  div.bootstrap .figure-img {
    margin-bottom: .5rem;
    line-height: 1; }
  div.bootstrap .figure-caption {
    font-size: 90%;
    color: #6c757d; }
  div.bootstrap code, div.bootstrap kbd, div.bootstrap pre, div.bootstrap samp {
    font-family: SFMono-Regular,Menlo,Monaco,Consolas,"Liberation Mono","Courier New",monospace; }
  div.bootstrap code {
    font-size: 87.5%;
    color: #e83e8c;
    word-break: break-word; }
  div.bootstrap a > code {
    color: inherit; }
  div.bootstrap kbd {
    padding: .2rem .4rem;
    font-size: 87.5%;
    color: #fff;
    background-color: #212529;
    border-radius: .2rem; }
  div.bootstrap kbd kbd {
    padding: 0;
    font-size: 100%;
    font-weight: 700; }
  div.bootstrap pre {
    display: block;
    font-size: 87.5%;
    color: #212529; }
  div.bootstrap pre code {
    font-size: inherit;
    color: inherit;
    word-break: normal; }
  div.bootstrap .pre-scrollable {
    max-height: 340px;
    overflow-y: scroll; }
  div.bootstrap .container {
    width: 100%;
    padding-right: 15px;
    padding-left: 15px;
    margin-right: auto;
    margin-left: auto; }
  @media (min-width: 576px) {
    div.bootstrap .container {
      max-width: 540px; } }
  @media (min-width: 768px) {
    div.bootstrap .container {
      max-width: 720px; } }
  @media (min-width: 992px) {
    div.bootstrap .container {
      max-width: 960px; } }
  @media (min-width: 1200px) {
    div.bootstrap .container {
      max-width: 1140px; } }
  div.bootstrap .container-fluid {
    width: 100%;
    padding-right: 15px;
    padding-left: 15px;
    margin-right: auto;
    margin-left: auto; }
  div.bootstrap .row {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    margin-right: -15px;
    margin-left: -15px; }
  div.bootstrap .no-gutters {
    margin-right: 0;
    margin-left: 0; }
  div.bootstrap .no-gutters > .col, div.bootstrap .no-gutters > [class*=col-] {
    padding-right: 0;
    padding-left: 0; }
  div.bootstrap .col, div.bootstrap .col-1, div.bootstrap .col-10, div.bootstrap .col-11, div.bootstrap .col-12, div.bootstrap .col-2, div.bootstrap .col-3, div.bootstrap .col-4, div.bootstrap .col-5, div.bootstrap .col-6, div.bootstrap .col-7, div.bootstrap .col-8, div.bootstrap .col-9, div.bootstrap .col-auto, div.bootstrap .col-lg, div.bootstrap .col-lg-1, div.bootstrap .col-lg-10, div.bootstrap .col-lg-11, div.bootstrap .col-lg-12, div.bootstrap .col-lg-2, div.bootstrap .col-lg-3, div.bootstrap .col-lg-4, div.bootstrap .col-lg-5, div.bootstrap .col-lg-6, div.bootstrap .col-lg-7, div.bootstrap .col-lg-8, div.bootstrap .col-lg-9, div.bootstrap .col-lg-auto, div.bootstrap .col-md, div.bootstrap .col-md-1, div.bootstrap .col-md-10, div.bootstrap .col-md-11, div.bootstrap .col-md-12, div.bootstrap .col-md-2, div.bootstrap .col-md-3, div.bootstrap .col-md-4, div.bootstrap .col-md-5, div.bootstrap .col-md-6, div.bootstrap .col-md-7, div.bootstrap .col-md-8, div.bootstrap .col-md-9, div.bootstrap .col-md-auto, div.bootstrap .col-sm, div.bootstrap .col-sm-1, div.bootstrap .col-sm-10, div.bootstrap .col-sm-11, div.bootstrap .col-sm-12, div.bootstrap .col-sm-2, div.bootstrap .col-sm-3, div.bootstrap .col-sm-4, div.bootstrap .col-sm-5, div.bootstrap .col-sm-6, div.bootstrap .col-sm-7, div.bootstrap .col-sm-8, div.bootstrap .col-sm-9, div.bootstrap .col-sm-auto, div.bootstrap .col-xl, div.bootstrap .col-xl-1, div.bootstrap .col-xl-10, div.bootstrap .col-xl-11, div.bootstrap .col-xl-12, div.bootstrap .col-xl-2, div.bootstrap .col-xl-3, div.bootstrap .col-xl-4, div.bootstrap .col-xl-5, div.bootstrap .col-xl-6, div.bootstrap .col-xl-7, div.bootstrap .col-xl-8, div.bootstrap .col-xl-9, div.bootstrap .col-xl-auto {
    position: relative;
    width: 100%;
    min-height: 1px;
    padding-right: 15px;
    padding-left: 15px; }
  div.bootstrap .col {
    -ms-flex-preferred-size: 0;
    flex-basis: 0;
    -webkit-box-flex: 1;
    -ms-flex-positive: 1;
    flex-grow: 1;
    max-width: 100%; }
  div.bootstrap .col-auto {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 auto;
    flex: 0 0 auto;
    width: auto;
    max-width: none; }
  div.bootstrap .col-1 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 8.333333%;
    flex: 0 0 8.333333%;
    max-width: 8.333333%; }
  div.bootstrap .col-2 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 16.666667%;
    flex: 0 0 16.666667%;
    max-width: 16.666667%; }
  div.bootstrap .col-3 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 25%;
    flex: 0 0 25%;
    max-width: 25%; }
  div.bootstrap .col-4 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 33.333333%;
    flex: 0 0 33.333333%;
    max-width: 33.333333%; }
  div.bootstrap .col-5 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 41.666667%;
    flex: 0 0 41.666667%;
    max-width: 41.666667%; }
  div.bootstrap .col-6 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 50%;
    flex: 0 0 50%;
    max-width: 50%; }
  div.bootstrap .col-7 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 58.333333%;
    flex: 0 0 58.333333%;
    max-width: 58.333333%; }
  div.bootstrap .col-8 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 66.666667%;
    flex: 0 0 66.666667%;
    max-width: 66.666667%; }
  div.bootstrap .col-9 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 75%;
    flex: 0 0 75%;
    max-width: 75%; }
  div.bootstrap .col-10 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 83.333333%;
    flex: 0 0 83.333333%;
    max-width: 83.333333%; }
  div.bootstrap .col-11 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 91.666667%;
    flex: 0 0 91.666667%;
    max-width: 91.666667%; }
  div.bootstrap .col-12 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 100%;
    flex: 0 0 100%;
    max-width: 100%; }
  div.bootstrap .order-first {
    -webkit-box-ordinal-group: 0;
    -ms-flex-order: -1;
    order: -1; }
  div.bootstrap .order-last {
    -webkit-box-ordinal-group: 14;
    -ms-flex-order: 13;
    order: 13; }
  div.bootstrap .order-0 {
    -webkit-box-ordinal-group: 1;
    -ms-flex-order: 0;
    order: 0; }
  div.bootstrap .order-1 {
    -webkit-box-ordinal-group: 2;
    -ms-flex-order: 1;
    order: 1; }
  div.bootstrap .order-2 {
    -webkit-box-ordinal-group: 3;
    -ms-flex-order: 2;
    order: 2; }
  div.bootstrap .order-3 {
    -webkit-box-ordinal-group: 4;
    -ms-flex-order: 3;
    order: 3; }
  div.bootstrap .order-4 {
    -webkit-box-ordinal-group: 5;
    -ms-flex-order: 4;
    order: 4; }
  div.bootstrap .order-5 {
    -webkit-box-ordinal-group: 6;
    -ms-flex-order: 5;
    order: 5; }
  div.bootstrap .order-6 {
    -webkit-box-ordinal-group: 7;
    -ms-flex-order: 6;
    order: 6; }
  div.bootstrap .order-7 {
    -webkit-box-ordinal-group: 8;
    -ms-flex-order: 7;
    order: 7; }
  div.bootstrap .order-8 {
    -webkit-box-ordinal-group: 9;
    -ms-flex-order: 8;
    order: 8; }
  div.bootstrap .order-9 {
    -webkit-box-ordinal-group: 10;
    -ms-flex-order: 9;
    order: 9; }
  div.bootstrap .order-10 {
    -webkit-box-ordinal-group: 11;
    -ms-flex-order: 10;
    order: 10; }
  div.bootstrap .order-11 {
    -webkit-box-ordinal-group: 12;
    -ms-flex-order: 11;
    order: 11; }
  div.bootstrap .order-12 {
    -webkit-box-ordinal-group: 13;
    -ms-flex-order: 12;
    order: 12; }
  div.bootstrap .offset-1 {
    margin-left: 8.333333%; }
  div.bootstrap .offset-2 {
    margin-left: 16.666667%; }
  div.bootstrap .offset-3 {
    margin-left: 25%; }
  div.bootstrap .offset-4 {
    margin-left: 33.333333%; }
  div.bootstrap .offset-5 {
    margin-left: 41.666667%; }
  div.bootstrap .offset-6 {
    margin-left: 50%; }
  div.bootstrap .offset-7 {
    margin-left: 58.333333%; }
  div.bootstrap .offset-8 {
    margin-left: 66.666667%; }
  div.bootstrap .offset-9 {
    margin-left: 75%; }
  div.bootstrap .offset-10 {
    margin-left: 83.333333%; }
  div.bootstrap .offset-11 {
    margin-left: 91.666667%; }
  @media (min-width: 576px) {
    div.bootstrap .col-sm {
      -ms-flex-preferred-size: 0;
      flex-basis: 0;
      -webkit-box-flex: 1;
      -ms-flex-positive: 1;
      flex-grow: 1;
      max-width: 100%; }
    div.bootstrap .col-sm-auto {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 auto;
      flex: 0 0 auto;
      width: auto;
      max-width: none; }
    div.bootstrap .col-sm-1 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 8.333333%;
      flex: 0 0 8.333333%;
      max-width: 8.333333%; }
    div.bootstrap .col-sm-2 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 16.666667%;
      flex: 0 0 16.666667%;
      max-width: 16.666667%; }
    div.bootstrap .col-sm-3 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 25%;
      flex: 0 0 25%;
      max-width: 25%; }
    div.bootstrap .col-sm-4 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 33.333333%;
      flex: 0 0 33.333333%;
      max-width: 33.333333%; }
    div.bootstrap .col-sm-5 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 41.666667%;
      flex: 0 0 41.666667%;
      max-width: 41.666667%; }
    div.bootstrap .col-sm-6 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 50%;
      flex: 0 0 50%;
      max-width: 50%; }
    div.bootstrap .col-sm-7 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 58.333333%;
      flex: 0 0 58.333333%;
      max-width: 58.333333%; }
    div.bootstrap .col-sm-8 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 66.666667%;
      flex: 0 0 66.666667%;
      max-width: 66.666667%; }
    div.bootstrap .col-sm-9 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 75%;
      flex: 0 0 75%;
      max-width: 75%; }
    div.bootstrap .col-sm-10 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 83.333333%;
      flex: 0 0 83.333333%;
      max-width: 83.333333%; }
    div.bootstrap .col-sm-11 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 91.666667%;
      flex: 0 0 91.666667%;
      max-width: 91.666667%; }
    div.bootstrap .col-sm-12 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 100%;
      flex: 0 0 100%;
      max-width: 100%; }
    div.bootstrap .order-sm-first {
      -webkit-box-ordinal-group: 0;
      -ms-flex-order: -1;
      order: -1; }
    div.bootstrap .order-sm-last {
      -webkit-box-ordinal-group: 14;
      -ms-flex-order: 13;
      order: 13; }
    div.bootstrap .order-sm-0 {
      -webkit-box-ordinal-group: 1;
      -ms-flex-order: 0;
      order: 0; }
    div.bootstrap .order-sm-1 {
      -webkit-box-ordinal-group: 2;
      -ms-flex-order: 1;
      order: 1; }
    div.bootstrap .order-sm-2 {
      -webkit-box-ordinal-group: 3;
      -ms-flex-order: 2;
      order: 2; }
    div.bootstrap .order-sm-3 {
      -webkit-box-ordinal-group: 4;
      -ms-flex-order: 3;
      order: 3; }
    div.bootstrap .order-sm-4 {
      -webkit-box-ordinal-group: 5;
      -ms-flex-order: 4;
      order: 4; }
    div.bootstrap .order-sm-5 {
      -webkit-box-ordinal-group: 6;
      -ms-flex-order: 5;
      order: 5; }
    div.bootstrap .order-sm-6 {
      -webkit-box-ordinal-group: 7;
      -ms-flex-order: 6;
      order: 6; }
    div.bootstrap .order-sm-7 {
      -webkit-box-ordinal-group: 8;
      -ms-flex-order: 7;
      order: 7; }
    div.bootstrap .order-sm-8 {
      -webkit-box-ordinal-group: 9;
      -ms-flex-order: 8;
      order: 8; }
    div.bootstrap .order-sm-9 {
      -webkit-box-ordinal-group: 10;
      -ms-flex-order: 9;
      order: 9; }
    div.bootstrap .order-sm-10 {
      -webkit-box-ordinal-group: 11;
      -ms-flex-order: 10;
      order: 10; }
    div.bootstrap .order-sm-11 {
      -webkit-box-ordinal-group: 12;
      -ms-flex-order: 11;
      order: 11; }
    div.bootstrap .order-sm-12 {
      -webkit-box-ordinal-group: 13;
      -ms-flex-order: 12;
      order: 12; }
    div.bootstrap .offset-sm-0 {
      margin-left: 0; }
    div.bootstrap .offset-sm-1 {
      margin-left: 8.333333%; }
    div.bootstrap .offset-sm-2 {
      margin-left: 16.666667%; }
    div.bootstrap .offset-sm-3 {
      margin-left: 25%; }
    div.bootstrap .offset-sm-4 {
      margin-left: 33.333333%; }
    div.bootstrap .offset-sm-5 {
      margin-left: 41.666667%; }
    div.bootstrap .offset-sm-6 {
      margin-left: 50%; }
    div.bootstrap .offset-sm-7 {
      margin-left: 58.333333%; }
    div.bootstrap .offset-sm-8 {
      margin-left: 66.666667%; }
    div.bootstrap .offset-sm-9 {
      margin-left: 75%; }
    div.bootstrap .offset-sm-10 {
      margin-left: 83.333333%; }
    div.bootstrap .offset-sm-11 {
      margin-left: 91.666667%; } }
  @media (min-width: 768px) {
    div.bootstrap .col-md {
      -ms-flex-preferred-size: 0;
      flex-basis: 0;
      -webkit-box-flex: 1;
      -ms-flex-positive: 1;
      flex-grow: 1;
      max-width: 100%; }
    div.bootstrap .col-md-auto {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 auto;
      flex: 0 0 auto;
      width: auto;
      max-width: none; }
    div.bootstrap .col-md-1 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 8.333333%;
      flex: 0 0 8.333333%;
      max-width: 8.333333%; }
    div.bootstrap .col-md-2 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 16.666667%;
      flex: 0 0 16.666667%;
      max-width: 16.666667%; }
    div.bootstrap .col-md-3 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 25%;
      flex: 0 0 25%;
      max-width: 25%; }
    div.bootstrap .col-md-4 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 33.333333%;
      flex: 0 0 33.333333%;
      max-width: 33.333333%; }
    div.bootstrap .col-md-5 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 41.666667%;
      flex: 0 0 41.666667%;
      max-width: 41.666667%; }
    div.bootstrap .col-md-6 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 50%;
      flex: 0 0 50%;
      max-width: 50%; }
    div.bootstrap .col-md-7 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 58.333333%;
      flex: 0 0 58.333333%;
      max-width: 58.333333%; }
    div.bootstrap .col-md-8 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 66.666667%;
      flex: 0 0 66.666667%;
      max-width: 66.666667%; }
    div.bootstrap .col-md-9 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 75%;
      flex: 0 0 75%;
      max-width: 75%; }
    div.bootstrap .col-md-10 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 83.333333%;
      flex: 0 0 83.333333%;
      max-width: 83.333333%; }
    div.bootstrap .col-md-11 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 91.666667%;
      flex: 0 0 91.666667%;
      max-width: 91.666667%; }
    div.bootstrap .col-md-12 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 100%;
      flex: 0 0 100%;
      max-width: 100%; }
    div.bootstrap .order-md-first {
      -webkit-box-ordinal-group: 0;
      -ms-flex-order: -1;
      order: -1; }
    div.bootstrap .order-md-last {
      -webkit-box-ordinal-group: 14;
      -ms-flex-order: 13;
      order: 13; }
    div.bootstrap .order-md-0 {
      -webkit-box-ordinal-group: 1;
      -ms-flex-order: 0;
      order: 0; }
    div.bootstrap .order-md-1 {
      -webkit-box-ordinal-group: 2;
      -ms-flex-order: 1;
      order: 1; }
    div.bootstrap .order-md-2 {
      -webkit-box-ordinal-group: 3;
      -ms-flex-order: 2;
      order: 2; }
    div.bootstrap .order-md-3 {
      -webkit-box-ordinal-group: 4;
      -ms-flex-order: 3;
      order: 3; }
    div.bootstrap .order-md-4 {
      -webkit-box-ordinal-group: 5;
      -ms-flex-order: 4;
      order: 4; }
    div.bootstrap .order-md-5 {
      -webkit-box-ordinal-group: 6;
      -ms-flex-order: 5;
      order: 5; }
    div.bootstrap .order-md-6 {
      -webkit-box-ordinal-group: 7;
      -ms-flex-order: 6;
      order: 6; }
    div.bootstrap .order-md-7 {
      -webkit-box-ordinal-group: 8;
      -ms-flex-order: 7;
      order: 7; }
    div.bootstrap .order-md-8 {
      -webkit-box-ordinal-group: 9;
      -ms-flex-order: 8;
      order: 8; }
    div.bootstrap .order-md-9 {
      -webkit-box-ordinal-group: 10;
      -ms-flex-order: 9;
      order: 9; }
    div.bootstrap .order-md-10 {
      -webkit-box-ordinal-group: 11;
      -ms-flex-order: 10;
      order: 10; }
    div.bootstrap .order-md-11 {
      -webkit-box-ordinal-group: 12;
      -ms-flex-order: 11;
      order: 11; }
    div.bootstrap .order-md-12 {
      -webkit-box-ordinal-group: 13;
      -ms-flex-order: 12;
      order: 12; }
    div.bootstrap .offset-md-0 {
      margin-left: 0; }
    div.bootstrap .offset-md-1 {
      margin-left: 8.333333%; }
    div.bootstrap .offset-md-2 {
      margin-left: 16.666667%; }
    div.bootstrap .offset-md-3 {
      margin-left: 25%; }
    div.bootstrap .offset-md-4 {
      margin-left: 33.333333%; }
    div.bootstrap .offset-md-5 {
      margin-left: 41.666667%; }
    div.bootstrap .offset-md-6 {
      margin-left: 50%; }
    div.bootstrap .offset-md-7 {
      margin-left: 58.333333%; }
    div.bootstrap .offset-md-8 {
      margin-left: 66.666667%; }
    div.bootstrap .offset-md-9 {
      margin-left: 75%; }
    div.bootstrap .offset-md-10 {
      margin-left: 83.333333%; }
    div.bootstrap .offset-md-11 {
      margin-left: 91.666667%; } }
  @media (min-width: 992px) {
    div.bootstrap .col-lg {
      -ms-flex-preferred-size: 0;
      flex-basis: 0;
      -webkit-box-flex: 1;
      -ms-flex-positive: 1;
      flex-grow: 1;
      max-width: 100%; }
    div.bootstrap .col-lg-auto {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 auto;
      flex: 0 0 auto;
      width: auto;
      max-width: none; }
    div.bootstrap .col-lg-1 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 8.333333%;
      flex: 0 0 8.333333%;
      max-width: 8.333333%; }
    div.bootstrap .col-lg-2 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 16.666667%;
      flex: 0 0 16.666667%;
      max-width: 16.666667%; }
    div.bootstrap .col-lg-3 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 25%;
      flex: 0 0 25%;
      max-width: 25%; }
    div.bootstrap .col-lg-4 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 33.333333%;
      flex: 0 0 33.333333%;
      max-width: 33.333333%; }
    div.bootstrap .col-lg-5 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 41.666667%;
      flex: 0 0 41.666667%;
      max-width: 41.666667%; }
    div.bootstrap .col-lg-6 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 50%;
      flex: 0 0 50%;
      max-width: 50%; }
    div.bootstrap .col-lg-7 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 58.333333%;
      flex: 0 0 58.333333%;
      max-width: 58.333333%; }
    div.bootstrap .col-lg-8 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 66.666667%;
      flex: 0 0 66.666667%;
      max-width: 66.666667%; }
    div.bootstrap .col-lg-9 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 75%;
      flex: 0 0 75%;
      max-width: 75%; }
    div.bootstrap .col-lg-10 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 83.333333%;
      flex: 0 0 83.333333%;
      max-width: 83.333333%; }
    div.bootstrap .col-lg-11 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 91.666667%;
      flex: 0 0 91.666667%;
      max-width: 91.666667%; }
    div.bootstrap .col-lg-12 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 100%;
      flex: 0 0 100%;
      max-width: 100%; }
    div.bootstrap .order-lg-first {
      -webkit-box-ordinal-group: 0;
      -ms-flex-order: -1;
      order: -1; }
    div.bootstrap .order-lg-last {
      -webkit-box-ordinal-group: 14;
      -ms-flex-order: 13;
      order: 13; }
    div.bootstrap .order-lg-0 {
      -webkit-box-ordinal-group: 1;
      -ms-flex-order: 0;
      order: 0; }
    div.bootstrap .order-lg-1 {
      -webkit-box-ordinal-group: 2;
      -ms-flex-order: 1;
      order: 1; }
    div.bootstrap .order-lg-2 {
      -webkit-box-ordinal-group: 3;
      -ms-flex-order: 2;
      order: 2; }
    div.bootstrap .order-lg-3 {
      -webkit-box-ordinal-group: 4;
      -ms-flex-order: 3;
      order: 3; }
    div.bootstrap .order-lg-4 {
      -webkit-box-ordinal-group: 5;
      -ms-flex-order: 4;
      order: 4; }
    div.bootstrap .order-lg-5 {
      -webkit-box-ordinal-group: 6;
      -ms-flex-order: 5;
      order: 5; }
    div.bootstrap .order-lg-6 {
      -webkit-box-ordinal-group: 7;
      -ms-flex-order: 6;
      order: 6; }
    div.bootstrap .order-lg-7 {
      -webkit-box-ordinal-group: 8;
      -ms-flex-order: 7;
      order: 7; }
    div.bootstrap .order-lg-8 {
      -webkit-box-ordinal-group: 9;
      -ms-flex-order: 8;
      order: 8; }
    div.bootstrap .order-lg-9 {
      -webkit-box-ordinal-group: 10;
      -ms-flex-order: 9;
      order: 9; }
    div.bootstrap .order-lg-10 {
      -webkit-box-ordinal-group: 11;
      -ms-flex-order: 10;
      order: 10; }
    div.bootstrap .order-lg-11 {
      -webkit-box-ordinal-group: 12;
      -ms-flex-order: 11;
      order: 11; }
    div.bootstrap .order-lg-12 {
      -webkit-box-ordinal-group: 13;
      -ms-flex-order: 12;
      order: 12; }
    div.bootstrap .offset-lg-0 {
      margin-left: 0; }
    div.bootstrap .offset-lg-1 {
      margin-left: 8.333333%; }
    div.bootstrap .offset-lg-2 {
      margin-left: 16.666667%; }
    div.bootstrap .offset-lg-3 {
      margin-left: 25%; }
    div.bootstrap .offset-lg-4 {
      margin-left: 33.333333%; }
    div.bootstrap .offset-lg-5 {
      margin-left: 41.666667%; }
    div.bootstrap .offset-lg-6 {
      margin-left: 50%; }
    div.bootstrap .offset-lg-7 {
      margin-left: 58.333333%; }
    div.bootstrap .offset-lg-8 {
      margin-left: 66.666667%; }
    div.bootstrap .offset-lg-9 {
      margin-left: 75%; }
    div.bootstrap .offset-lg-10 {
      margin-left: 83.333333%; }
    div.bootstrap .offset-lg-11 {
      margin-left: 91.666667%; } }
  @media (min-width: 1200px) {
    div.bootstrap .col-xl {
      -ms-flex-preferred-size: 0;
      flex-basis: 0;
      -webkit-box-flex: 1;
      -ms-flex-positive: 1;
      flex-grow: 1;
      max-width: 100%; }
    div.bootstrap .col-xl-auto {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 auto;
      flex: 0 0 auto;
      width: auto;
      max-width: none; }
    div.bootstrap .col-xl-1 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 8.333333%;
      flex: 0 0 8.333333%;
      max-width: 8.333333%; }
    div.bootstrap .col-xl-2 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 16.666667%;
      flex: 0 0 16.666667%;
      max-width: 16.666667%; }
    div.bootstrap .col-xl-3 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 25%;
      flex: 0 0 25%;
      max-width: 25%; }
    div.bootstrap .col-xl-4 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 33.333333%;
      flex: 0 0 33.333333%;
      max-width: 33.333333%; }
    div.bootstrap .col-xl-5 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 41.666667%;
      flex: 0 0 41.666667%;
      max-width: 41.666667%; }
    div.bootstrap .col-xl-6 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 50%;
      flex: 0 0 50%;
      max-width: 50%; }
    div.bootstrap .col-xl-7 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 58.333333%;
      flex: 0 0 58.333333%;
      max-width: 58.333333%; }
    div.bootstrap .col-xl-8 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 66.666667%;
      flex: 0 0 66.666667%;
      max-width: 66.666667%; }
    div.bootstrap .col-xl-9 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 75%;
      flex: 0 0 75%;
      max-width: 75%; }
    div.bootstrap .col-xl-10 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 83.333333%;
      flex: 0 0 83.333333%;
      max-width: 83.333333%; }
    div.bootstrap .col-xl-11 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 91.666667%;
      flex: 0 0 91.666667%;
      max-width: 91.666667%; }
    div.bootstrap .col-xl-12 {
      -webkit-box-flex: 0;
      -ms-flex: 0 0 100%;
      flex: 0 0 100%;
      max-width: 100%; }
    div.bootstrap .order-xl-first {
      -webkit-box-ordinal-group: 0;
      -ms-flex-order: -1;
      order: -1; }
    div.bootstrap .order-xl-last {
      -webkit-box-ordinal-group: 14;
      -ms-flex-order: 13;
      order: 13; }
    div.bootstrap .order-xl-0 {
      -webkit-box-ordinal-group: 1;
      -ms-flex-order: 0;
      order: 0; }
    div.bootstrap .order-xl-1 {
      -webkit-box-ordinal-group: 2;
      -ms-flex-order: 1;
      order: 1; }
    div.bootstrap .order-xl-2 {
      -webkit-box-ordinal-group: 3;
      -ms-flex-order: 2;
      order: 2; }
    div.bootstrap .order-xl-3 {
      -webkit-box-ordinal-group: 4;
      -ms-flex-order: 3;
      order: 3; }
    div.bootstrap .order-xl-4 {
      -webkit-box-ordinal-group: 5;
      -ms-flex-order: 4;
      order: 4; }
    div.bootstrap .order-xl-5 {
      -webkit-box-ordinal-group: 6;
      -ms-flex-order: 5;
      order: 5; }
    div.bootstrap .order-xl-6 {
      -webkit-box-ordinal-group: 7;
      -ms-flex-order: 6;
      order: 6; }
    div.bootstrap .order-xl-7 {
      -webkit-box-ordinal-group: 8;
      -ms-flex-order: 7;
      order: 7; }
    div.bootstrap .order-xl-8 {
      -webkit-box-ordinal-group: 9;
      -ms-flex-order: 8;
      order: 8; }
    div.bootstrap .order-xl-9 {
      -webkit-box-ordinal-group: 10;
      -ms-flex-order: 9;
      order: 9; }
    div.bootstrap .order-xl-10 {
      -webkit-box-ordinal-group: 11;
      -ms-flex-order: 10;
      order: 10; }
    div.bootstrap .order-xl-11 {
      -webkit-box-ordinal-group: 12;
      -ms-flex-order: 11;
      order: 11; }
    div.bootstrap .order-xl-12 {
      -webkit-box-ordinal-group: 13;
      -ms-flex-order: 12;
      order: 12; }
    div.bootstrap .offset-xl-0 {
      margin-left: 0; }
    div.bootstrap .offset-xl-1 {
      margin-left: 8.333333%; }
    div.bootstrap .offset-xl-2 {
      margin-left: 16.666667%; }
    div.bootstrap .offset-xl-3 {
      margin-left: 25%; }
    div.bootstrap .offset-xl-4 {
      margin-left: 33.333333%; }
    div.bootstrap .offset-xl-5 {
      margin-left: 41.666667%; }
    div.bootstrap .offset-xl-6 {
      margin-left: 50%; }
    div.bootstrap .offset-xl-7 {
      margin-left: 58.333333%; }
    div.bootstrap .offset-xl-8 {
      margin-left: 66.666667%; }
    div.bootstrap .offset-xl-9 {
      margin-left: 75%; }
    div.bootstrap .offset-xl-10 {
      margin-left: 83.333333%; }
    div.bootstrap .offset-xl-11 {
      margin-left: 91.666667%; } }
  div.bootstrap .table {
    width: 100%;
    max-width: 100%;
    margin-bottom: 1rem;
    background-color: transparent; }
  div.bootstrap .table td, div.bootstrap .table th {
    padding: .75rem;
    vertical-align: top;
    border-top: 1px solid #dee2e6; }
  div.bootstrap .table thead th {
    vertical-align: bottom;
    border-bottom: 2px solid #dee2e6; }
  div.bootstrap .table tbody + tbody {
    border-top: 2px solid #dee2e6; }
  div.bootstrap .table .table {
    background-color: #fff; }
  div.bootstrap .table-sm td, div.bootstrap .table-sm th {
    padding: .3rem; }
  div.bootstrap .table-bordered {
    border: 1px solid #dee2e6; }
  div.bootstrap .table-bordered td, div.bootstrap .table-bordered th {
    border: 1px solid #dee2e6; }
  div.bootstrap .table-bordered thead td, div.bootstrap .table-bordered thead th {
    border-bottom-width: 2px; }
  div.bootstrap .table-striped tbody tr:nth-of-type(odd) {
    background-color: rgba(0, 0, 0, 0.05); }
  div.bootstrap .table-hover tbody tr:hover {
    background-color: rgba(0, 0, 0, 0.075); }
  div.bootstrap .table-primary, div.bootstrap .table-primary > td, div.bootstrap .table-primary > th {
    background-color: #b8daff; }
  div.bootstrap .table-hover .table-primary:hover {
    background-color: #9fcdff; }
  div.bootstrap .table-hover .table-primary:hover > td, div.bootstrap .table-hover .table-primary:hover > th {
    background-color: #9fcdff; }
  div.bootstrap .table-secondary, div.bootstrap .table-secondary > td, div.bootstrap .table-secondary > th {
    background-color: #d6d8db; }
  div.bootstrap .table-hover .table-secondary:hover {
    background-color: #c8cbcf; }
  div.bootstrap .table-hover .table-secondary:hover > td, div.bootstrap .table-hover .table-secondary:hover > th {
    background-color: #c8cbcf; }
  div.bootstrap .table-success, div.bootstrap .table-success > td, div.bootstrap .table-success > th {
    background-color: #c3e6cb; }
  div.bootstrap .table-hover .table-success:hover {
    background-color: #b1dfbb; }
  div.bootstrap .table-hover .table-success:hover > td, div.bootstrap .table-hover .table-success:hover > th {
    background-color: #b1dfbb; }
  div.bootstrap .table-info, div.bootstrap .table-info > td, div.bootstrap .table-info > th {
    background-color: #bee5eb; }
  div.bootstrap .table-hover .table-info:hover {
    background-color: #abdde5; }
  div.bootstrap .table-hover .table-info:hover > td, div.bootstrap .table-hover .table-info:hover > th {
    background-color: #abdde5; }
  div.bootstrap .table-warning, div.bootstrap .table-warning > td, div.bootstrap .table-warning > th {
    background-color: #ffeeba; }
  div.bootstrap .table-hover .table-warning:hover {
    background-color: #ffe8a1; }
  div.bootstrap .table-hover .table-warning:hover > td, div.bootstrap .table-hover .table-warning:hover > th {
    background-color: #ffe8a1; }
  div.bootstrap .table-danger, div.bootstrap .table-danger > td, div.bootstrap .table-danger > th {
    background-color: #f5c6cb; }
  div.bootstrap .table-hover .table-danger:hover {
    background-color: #f1b0b7; }
  div.bootstrap .table-hover .table-danger:hover > td, div.bootstrap .table-hover .table-danger:hover > th {
    background-color: #f1b0b7; }
  div.bootstrap .table-light, div.bootstrap .table-light > td, div.bootstrap .table-light > th {
    background-color: #fdfdfe; }
  div.bootstrap .table-hover .table-light:hover {
    background-color: #ececf6; }
  div.bootstrap .table-hover .table-light:hover > td, div.bootstrap .table-hover .table-light:hover > th {
    background-color: #ececf6; }
  div.bootstrap .table-dark, div.bootstrap .table-dark > td, div.bootstrap .table-dark > th {
    background-color: #c6c8ca; }
  div.bootstrap .table-hover .table-dark:hover {
    background-color: #b9bbbe; }
  div.bootstrap .table-hover .table-dark:hover > td, div.bootstrap .table-hover .table-dark:hover > th {
    background-color: #b9bbbe; }
  div.bootstrap .table-active, div.bootstrap .table-active > td, div.bootstrap .table-active > th {
    background-color: rgba(0, 0, 0, 0.075); }
  div.bootstrap .table-hover .table-active:hover {
    background-color: rgba(0, 0, 0, 0.075); }
  div.bootstrap .table-hover .table-active:hover > td, div.bootstrap .table-hover .table-active:hover > th {
    background-color: rgba(0, 0, 0, 0.075); }
  div.bootstrap .table .thead-dark th {
    color: #fff;
    background-color: #212529;
    border-color: #32383e; }
  div.bootstrap .table .thead-light th {
    color: #495057;
    background-color: #e9ecef;
    border-color: #dee2e6; }
  div.bootstrap .table-dark {
    color: #fff;
    background-color: #212529; }
  div.bootstrap .table-dark td, div.bootstrap .table-dark th, div.bootstrap .table-dark thead th {
    border-color: #32383e; }
  div.bootstrap .table-dark.table-bordered {
    border: 0; }
  div.bootstrap .table-dark.table-striped tbody tr:nth-of-type(odd) {
    background-color: rgba(255, 255, 255, 0.05); }
  div.bootstrap .table-dark.table-hover tbody tr:hover {
    background-color: rgba(255, 255, 255, 0.075); }
  @media (max-width: 575.98px) {
    div.bootstrap .table-responsive-sm {
      display: block;
      width: 100%;
      overflow-x: auto;
      -webkit-overflow-scrolling: touch;
      -ms-overflow-style: -ms-autohiding-scrollbar; }
    div.bootstrap .table-responsive-sm > .table-bordered {
      border: 0; } }
  @media (max-width: 767.98px) {
    div.bootstrap .table-responsive-md {
      display: block;
      width: 100%;
      overflow-x: auto;
      -webkit-overflow-scrolling: touch;
      -ms-overflow-style: -ms-autohiding-scrollbar; }
    div.bootstrap .table-responsive-md > .table-bordered {
      border: 0; } }
  @media (max-width: 991.98px) {
    div.bootstrap .table-responsive-lg {
      display: block;
      width: 100%;
      overflow-x: auto;
      -webkit-overflow-scrolling: touch;
      -ms-overflow-style: -ms-autohiding-scrollbar; }
    div.bootstrap .table-responsive-lg > .table-bordered {
      border: 0; } }
  @media (max-width: 1199.98px) {
    div.bootstrap .table-responsive-xl {
      display: block;
      width: 100%;
      overflow-x: auto;
      -webkit-overflow-scrolling: touch;
      -ms-overflow-style: -ms-autohiding-scrollbar; }
    div.bootstrap .table-responsive-xl > .table-bordered {
      border: 0; } }
  div.bootstrap .table-responsive {
    display: block;
    width: 100%;
    overflow-x: auto;
    -webkit-overflow-scrolling: touch;
    -ms-overflow-style: -ms-autohiding-scrollbar; }
  div.bootstrap .table-responsive > .table-bordered {
    border: 0; }
  div.bootstrap .form-control {
    display: block;
    width: 100%;
    padding: .375rem .75rem;
    font-size: 1rem;
    line-height: 1.5;
    color: #495057;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid #ced4da;
    border-radius: .25rem;
    transition: border-color .15s ease-in-out,box-shadow .15s ease-in-out; }
  div.bootstrap .form-control::-ms-expand {
    background-color: transparent;
    border: 0; }
  div.bootstrap .form-control:focus {
    color: #495057;
    background-color: #fff;
    border-color: #80bdff;
    outline: 0;
    box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25); }
  div.bootstrap .form-control::-webkit-input-placeholder {
    color: #6c757d;
    opacity: 1; }
  div.bootstrap .form-control::-moz-placeholder {
    color: #6c757d;
    opacity: 1; }
  div.bootstrap .form-control:-ms-input-placeholder {
    color: #6c757d;
    opacity: 1; }
  div.bootstrap .form-control::-ms-input-placeholder {
    color: #6c757d;
    opacity: 1; }
  div.bootstrap .form-control::placeholder {
    color: #6c757d;
    opacity: 1; }
  div.bootstrap .form-control:disabled, div.bootstrap .form-control[readonly] {
    background-color: #e9ecef;
    opacity: 1; }
  div.bootstrap select.form-control:not([size]):not([multiple]) {
    height: calc(2.25rem + 2px); }
  div.bootstrap select.form-control:focus::-ms-value {
    color: #495057;
    background-color: #fff; }
  div.bootstrap .form-control-file, div.bootstrap .form-control-range {
    display: block;
    width: 100%; }
  div.bootstrap .col-form-label {
    padding-top: calc(.375rem + 1px);
    padding-bottom: calc(.375rem + 1px);
    margin-bottom: 0;
    font-size: inherit;
    line-height: 1.5; }
  div.bootstrap .col-form-label-lg {
    padding-top: calc(.5rem + 1px);
    padding-bottom: calc(.5rem + 1px);
    font-size: 1.25rem;
    line-height: 1.5; }
  div.bootstrap .col-form-label-sm {
    padding-top: calc(.25rem + 1px);
    padding-bottom: calc(.25rem + 1px);
    font-size: .875rem;
    line-height: 1.5; }
  div.bootstrap .form-control-plaintext {
    display: block;
    width: 100%;
    padding-top: .375rem;
    padding-bottom: .375rem;
    margin-bottom: 0;
    line-height: 1.5;
    background-color: transparent;
    border: solid transparent;
    border-width: 1px 0; }
  div.bootstrap .form-control-plaintext.form-control-lg, div.bootstrap .form-control-plaintext.form-control-sm, div.bootstrap .input-group-lg > .form-control-plaintext.form-control, div.bootstrap .input-group-lg > .input-group-append > .form-control-plaintext.btn, div.bootstrap .input-group-lg > .input-group-append > .form-control-plaintext.input-group-text, div.bootstrap .input-group-lg > .input-group-prepend > .form-control-plaintext.btn, div.bootstrap .input-group-lg > .input-group-prepend > .form-control-plaintext.input-group-text, div.bootstrap .input-group-sm > .form-control-plaintext.form-control, div.bootstrap .input-group-sm > .input-group-append > .form-control-plaintext.btn, div.bootstrap .input-group-sm > .input-group-append > .form-control-plaintext.input-group-text, div.bootstrap .input-group-sm > .input-group-prepend > .form-control-plaintext.btn, div.bootstrap .input-group-sm > .input-group-prepend > .form-control-plaintext.input-group-text {
    padding-right: 0;
    padding-left: 0; }
  div.bootstrap .form-control-sm, div.bootstrap .input-group-sm > .form-control, div.bootstrap .input-group-sm > .input-group-append > .btn, div.bootstrap .input-group-sm > .input-group-append > .input-group-text, div.bootstrap .input-group-sm > .input-group-prepend > .btn, div.bootstrap .input-group-sm > .input-group-prepend > .input-group-text {
    padding: .25rem .5rem;
    font-size: .875rem;
    line-height: 1.5;
    border-radius: .2rem; }
  div.bootstrap .input-group-sm > .input-group-append > select.btn:not([size]):not([multiple]), div.bootstrap .input-group-sm > .input-group-append > select.input-group-text:not([size]):not([multiple]), div.bootstrap .input-group-sm > .input-group-prepend > select.btn:not([size]):not([multiple]), div.bootstrap .input-group-sm > .input-group-prepend > select.input-group-text:not([size]):not([multiple]), div.bootstrap .input-group-sm > select.form-control:not([size]):not([multiple]), div.bootstrap select.form-control-sm:not([size]):not([multiple]) {
    height: calc(1.8125rem + 2px); }
  div.bootstrap .form-control-lg, div.bootstrap .input-group-lg > .form-control, div.bootstrap .input-group-lg > .input-group-append > .btn, div.bootstrap .input-group-lg > .input-group-append > .input-group-text, div.bootstrap .input-group-lg > .input-group-prepend > .btn, div.bootstrap .input-group-lg > .input-group-prepend > .input-group-text {
    padding: .5rem 1rem;
    font-size: 1.25rem;
    line-height: 1.5;
    border-radius: .3rem; }
  div.bootstrap .input-group-lg > .input-group-append > select.btn:not([size]):not([multiple]), div.bootstrap .input-group-lg > .input-group-append > select.input-group-text:not([size]):not([multiple]), div.bootstrap .input-group-lg > .input-group-prepend > select.btn:not([size]):not([multiple]), div.bootstrap .input-group-lg > .input-group-prepend > select.input-group-text:not([size]):not([multiple]), div.bootstrap .input-group-lg > select.form-control:not([size]):not([multiple]), div.bootstrap select.form-control-lg:not([size]):not([multiple]) {
    height: calc(2.875rem + 2px); }
  div.bootstrap .form-group {
    margin-bottom: 1rem; }
  div.bootstrap .form-text {
    display: block;
    margin-top: .25rem; }
  div.bootstrap .form-row {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    margin-right: -5px;
    margin-left: -5px; }
  div.bootstrap .form-row > .col, div.bootstrap .form-row > [class*=col-] {
    padding-right: 5px;
    padding-left: 5px; }
  div.bootstrap .form-check {
    position: relative;
    display: block;
    padding-left: 1.25rem; }
  div.bootstrap .form-check-input {
    position: absolute;
    margin-top: .3rem;
    margin-left: -1.25rem; }
  div.bootstrap .form-check-input:disabled ~ .form-check-label {
    color: #6c757d; }
  div.bootstrap .form-check-label {
    margin-bottom: 0; }
  div.bootstrap .form-check-inline {
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    padding-left: 0;
    margin-right: .75rem; }
  div.bootstrap .form-check-inline .form-check-input {
    position: static;
    margin-top: 0;
    margin-right: .3125rem;
    margin-left: 0; }
  div.bootstrap .valid-feedback {
    display: none;
    width: 100%;
    margin-top: .25rem;
    font-size: 80%;
    color: #28a745; }
  div.bootstrap .valid-tooltip {
    position: absolute;
    top: 100%;
    z-index: 5;
    display: none;
    max-width: 100%;
    padding: .5rem;
    margin-top: .1rem;
    font-size: .875rem;
    line-height: 1;
    color: #fff;
    background-color: rgba(40, 167, 69, 0.8);
    border-radius: .2rem; }
  div.bootstrap .custom-select.is-valid, div.bootstrap .form-control.is-valid, div.bootstrap .was-validated .custom-select:valid, div.bootstrap .was-validated .form-control:valid {
    border-color: #28a745; }
  div.bootstrap .custom-select.is-valid:focus, div.bootstrap .form-control.is-valid:focus, div.bootstrap .was-validated .custom-select:valid:focus, div.bootstrap .was-validated .form-control:valid:focus {
    border-color: #28a745;
    box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.25); }
  div.bootstrap .custom-select.is-valid ~ .valid-feedback, div.bootstrap .custom-select.is-valid ~ .valid-tooltip, div.bootstrap .form-control.is-valid ~ .valid-feedback, div.bootstrap .form-control.is-valid ~ .valid-tooltip, div.bootstrap .was-validated .custom-select:valid ~ .valid-feedback, div.bootstrap .was-validated .custom-select:valid ~ .valid-tooltip, div.bootstrap .was-validated .form-control:valid ~ .valid-feedback, div.bootstrap .was-validated .form-control:valid ~ .valid-tooltip {
    display: block; }
  div.bootstrap .form-check-input.is-valid ~ .form-check-label, div.bootstrap .was-validated .form-check-input:valid ~ .form-check-label {
    color: #28a745; }
  div.bootstrap .form-check-input.is-valid ~ .valid-feedback, div.bootstrap .form-check-input.is-valid ~ .valid-tooltip, div.bootstrap .was-validated .form-check-input:valid ~ .valid-feedback, div.bootstrap .was-validated .form-check-input:valid ~ .valid-tooltip {
    display: block; }
  div.bootstrap .custom-control-input.is-valid ~ .custom-control-label, div.bootstrap .was-validated .custom-control-input:valid ~ .custom-control-label {
    color: #28a745; }
  div.bootstrap .custom-control-input.is-valid ~ .custom-control-label::before, div.bootstrap .was-validated .custom-control-input:valid ~ .custom-control-label::before {
    background-color: #71dd8a; }
  div.bootstrap .custom-control-input.is-valid ~ .valid-feedback, div.bootstrap .custom-control-input.is-valid ~ .valid-tooltip, div.bootstrap .was-validated .custom-control-input:valid ~ .valid-feedback, div.bootstrap .was-validated .custom-control-input:valid ~ .valid-tooltip {
    display: block; }
  div.bootstrap .custom-control-input.is-valid:checked ~ .custom-control-label::before, div.bootstrap .was-validated .custom-control-input:valid:checked ~ .custom-control-label::before {
    background-color: #34ce57; }
  div.bootstrap .custom-control-input.is-valid:focus ~ .custom-control-label::before, div.bootstrap .was-validated .custom-control-input:valid:focus ~ .custom-control-label::before {
    box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem rgba(40, 167, 69, 0.25); }
  div.bootstrap .custom-file-input.is-valid ~ .custom-file-label, div.bootstrap .was-validated .custom-file-input:valid ~ .custom-file-label {
    border-color: #28a745; }
  div.bootstrap .custom-file-input.is-valid ~ .custom-file-label::before, div.bootstrap .was-validated .custom-file-input:valid ~ .custom-file-label::before {
    border-color: inherit; }
  div.bootstrap .custom-file-input.is-valid ~ .valid-feedback, div.bootstrap .custom-file-input.is-valid ~ .valid-tooltip, div.bootstrap .was-validated .custom-file-input:valid ~ .valid-feedback, div.bootstrap .was-validated .custom-file-input:valid ~ .valid-tooltip {
    display: block; }
  div.bootstrap .custom-file-input.is-valid:focus ~ .custom-file-label, div.bootstrap .was-validated .custom-file-input:valid:focus ~ .custom-file-label {
    box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.25); }
  div.bootstrap .invalid-feedback {
    display: none;
    width: 100%;
    margin-top: .25rem;
    font-size: 80%;
    color: #dc3545; }
  div.bootstrap .invalid-tooltip {
    position: absolute;
    top: 100%;
    z-index: 5;
    display: none;
    max-width: 100%;
    padding: .5rem;
    margin-top: .1rem;
    font-size: .875rem;
    line-height: 1;
    color: #fff;
    background-color: rgba(220, 53, 69, 0.8);
    border-radius: .2rem; }
  div.bootstrap .custom-select.is-invalid, div.bootstrap .form-control.is-invalid, div.bootstrap .was-validated .custom-select:invalid, div.bootstrap .was-validated .form-control:invalid {
    border-color: #dc3545; }
  div.bootstrap .custom-select.is-invalid:focus, div.bootstrap .form-control.is-invalid:focus, div.bootstrap .was-validated .custom-select:invalid:focus, div.bootstrap .was-validated .form-control:invalid:focus {
    border-color: #dc3545;
    box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.25); }
  div.bootstrap .custom-select.is-invalid ~ .invalid-feedback, div.bootstrap .custom-select.is-invalid ~ .invalid-tooltip, div.bootstrap .form-control.is-invalid ~ .invalid-feedback, div.bootstrap .form-control.is-invalid ~ .invalid-tooltip, div.bootstrap .was-validated .custom-select:invalid ~ .invalid-feedback, div.bootstrap .was-validated .custom-select:invalid ~ .invalid-tooltip, div.bootstrap .was-validated .form-control:invalid ~ .invalid-feedback, div.bootstrap .was-validated .form-control:invalid ~ .invalid-tooltip {
    display: block; }
  div.bootstrap .form-check-input.is-invalid ~ .form-check-label, div.bootstrap .was-validated .form-check-input:invalid ~ .form-check-label {
    color: #dc3545; }
  div.bootstrap .form-check-input.is-invalid ~ .invalid-feedback, div.bootstrap .form-check-input.is-invalid ~ .invalid-tooltip, div.bootstrap .was-validated .form-check-input:invalid ~ .invalid-feedback, div.bootstrap .was-validated .form-check-input:invalid ~ .invalid-tooltip {
    display: block; }
  div.bootstrap .custom-control-input.is-invalid ~ .custom-control-label, div.bootstrap .was-validated .custom-control-input:invalid ~ .custom-control-label {
    color: #dc3545; }
  div.bootstrap .custom-control-input.is-invalid ~ .custom-control-label::before, div.bootstrap .was-validated .custom-control-input:invalid ~ .custom-control-label::before {
    background-color: #efa2a9; }
  div.bootstrap .custom-control-input.is-invalid ~ .invalid-feedback, div.bootstrap .custom-control-input.is-invalid ~ .invalid-tooltip, div.bootstrap .was-validated .custom-control-input:invalid ~ .invalid-feedback, div.bootstrap .was-validated .custom-control-input:invalid ~ .invalid-tooltip {
    display: block; }
  div.bootstrap .custom-control-input.is-invalid:checked ~ .custom-control-label::before, div.bootstrap .was-validated .custom-control-input:invalid:checked ~ .custom-control-label::before {
    background-color: #e4606d; }
  div.bootstrap .custom-control-input.is-invalid:focus ~ .custom-control-label::before, div.bootstrap .was-validated .custom-control-input:invalid:focus ~ .custom-control-label::before {
    box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem rgba(220, 53, 69, 0.25); }
  div.bootstrap .custom-file-input.is-invalid ~ .custom-file-label, div.bootstrap .was-validated .custom-file-input:invalid ~ .custom-file-label {
    border-color: #dc3545; }
  div.bootstrap .custom-file-input.is-invalid ~ .custom-file-label::before, div.bootstrap .was-validated .custom-file-input:invalid ~ .custom-file-label::before {
    border-color: inherit; }
  div.bootstrap .custom-file-input.is-invalid ~ .invalid-feedback, div.bootstrap .custom-file-input.is-invalid ~ .invalid-tooltip, div.bootstrap .was-validated .custom-file-input:invalid ~ .invalid-feedback, div.bootstrap .was-validated .custom-file-input:invalid ~ .invalid-tooltip {
    display: block; }
  div.bootstrap .custom-file-input.is-invalid:focus ~ .custom-file-label, div.bootstrap .was-validated .custom-file-input:invalid:focus ~ .custom-file-label {
    box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.25); }
  div.bootstrap .form-inline {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -ms-flex-flow: row wrap;
    flex-flow: row wrap;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center; }
  div.bootstrap .form-inline .form-check {
    width: 100%; }
  @media (min-width: 576px) {
    div.bootstrap .form-inline label {
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-align: center;
      -ms-flex-align: center;
      align-items: center;
      -webkit-box-pack: center;
      -ms-flex-pack: center;
      justify-content: center;
      margin-bottom: 0; }
    div.bootstrap .form-inline .form-group {
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-flex: 0;
      -ms-flex: 0 0 auto;
      flex: 0 0 auto;
      -webkit-box-orient: horizontal;
      -webkit-box-direction: normal;
      -ms-flex-flow: row wrap;
      flex-flow: row wrap;
      -webkit-box-align: center;
      -ms-flex-align: center;
      align-items: center;
      margin-bottom: 0; }
    div.bootstrap .form-inline .form-control {
      display: inline-block;
      width: auto;
      vertical-align: middle; }
    div.bootstrap .form-inline .form-control-plaintext {
      display: inline-block; }
    div.bootstrap .form-inline .input-group {
      width: auto; }
    div.bootstrap .form-inline .form-check {
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-align: center;
      -ms-flex-align: center;
      align-items: center;
      -webkit-box-pack: center;
      -ms-flex-pack: center;
      justify-content: center;
      width: auto;
      padding-left: 0; }
    div.bootstrap .form-inline .form-check-input {
      position: relative;
      margin-top: 0;
      margin-right: .25rem;
      margin-left: 0; }
    div.bootstrap .form-inline .custom-control {
      -webkit-box-align: center;
      -ms-flex-align: center;
      align-items: center;
      -webkit-box-pack: center;
      -ms-flex-pack: center;
      justify-content: center; }
    div.bootstrap .form-inline .custom-control-label {
      margin-bottom: 0; } }
  div.bootstrap .btn {
    display: inline-block;
    font-weight: 400;
    text-align: center;
    white-space: nowrap;
    vertical-align: middle;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    border: 1px solid transparent;
    padding: .375rem .75rem;
    font-size: 1rem;
    line-height: 1.5;
    border-radius: .25rem;
    transition: color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out; }
  div.bootstrap .btn:focus, div.bootstrap .btn:hover {
    text-decoration: none; }
  div.bootstrap .btn.focus, div.bootstrap .btn:focus {
    outline: 0;
    box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25); }
  div.bootstrap .btn.disabled, div.bootstrap .btn:disabled {
    opacity: .65; }
  div.bootstrap .btn:not(:disabled):not(.disabled) {
    cursor: pointer; }
  div.bootstrap .btn:not(:disabled):not(.disabled).active, div.bootstrap .btn:not(:disabled):not(.disabled):active {
    background-image: none; }
  div.bootstrap a.btn.disabled, div.bootstrap fieldset:disabled a.btn {
    pointer-events: none; }
  div.bootstrap .btn-primary {
    color: #fff;
    background-color: #007bff;
    border-color: #007bff; }
  div.bootstrap .btn-primary:hover {
    color: #fff;
    background-color: #0069d9;
    border-color: #0062cc; }
  div.bootstrap .btn-primary.focus, div.bootstrap .btn-primary:focus {
    box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.5); }
  div.bootstrap .btn-primary.disabled, div.bootstrap .btn-primary:disabled {
    color: #fff;
    background-color: #007bff;
    border-color: #007bff; }
  div.bootstrap .btn-primary:not(:disabled):not(.disabled).active, div.bootstrap .btn-primary:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-primary.dropdown-toggle {
    color: #fff;
    background-color: #0062cc;
    border-color: #005cbf; }
  div.bootstrap .btn-primary:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-primary:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-primary.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.5); }
  div.bootstrap .btn-secondary {
    color: #fff;
    background-color: #6c757d;
    border-color: #6c757d; }
  div.bootstrap .btn-secondary:hover {
    color: #fff;
    background-color: #5a6268;
    border-color: #545b62; }
  div.bootstrap .btn-secondary.focus, div.bootstrap .btn-secondary:focus {
    box-shadow: 0 0 0 0.2rem rgba(108, 117, 125, 0.5); }
  div.bootstrap .btn-secondary.disabled, div.bootstrap .btn-secondary:disabled {
    color: #fff;
    background-color: #6c757d;
    border-color: #6c757d; }
  div.bootstrap .btn-secondary:not(:disabled):not(.disabled).active, div.bootstrap .btn-secondary:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-secondary.dropdown-toggle {
    color: #fff;
    background-color: #545b62;
    border-color: #4e555b; }
  div.bootstrap .btn-secondary:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-secondary:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-secondary.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(108, 117, 125, 0.5); }
  div.bootstrap .btn-success {
    color: #fff;
    background-color: #28a745;
    border-color: #28a745; }
  div.bootstrap .btn-success:hover {
    color: #fff;
    background-color: #218838;
    border-color: #1e7e34; }
  div.bootstrap .btn-success.focus, div.bootstrap .btn-success:focus {
    box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.5); }
  div.bootstrap .btn-success.disabled, div.bootstrap .btn-success:disabled {
    color: #fff;
    background-color: #28a745;
    border-color: #28a745; }
  div.bootstrap .btn-success:not(:disabled):not(.disabled).active, div.bootstrap .btn-success:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-success.dropdown-toggle {
    color: #fff;
    background-color: #1e7e34;
    border-color: #1c7430; }
  div.bootstrap .btn-success:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-success:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-success.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.5); }
  div.bootstrap .btn-info {
    color: #fff;
    background-color: #17a2b8;
    border-color: #17a2b8; }
  div.bootstrap .btn-info:hover {
    color: #fff;
    background-color: #138496;
    border-color: #117a8b; }
  div.bootstrap .btn-info.focus, div.bootstrap .btn-info:focus {
    box-shadow: 0 0 0 0.2rem rgba(23, 162, 184, 0.5); }
  div.bootstrap .btn-info.disabled, div.bootstrap .btn-info:disabled {
    color: #fff;
    background-color: #17a2b8;
    border-color: #17a2b8; }
  div.bootstrap .btn-info:not(:disabled):not(.disabled).active, div.bootstrap .btn-info:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-info.dropdown-toggle {
    color: #fff;
    background-color: #117a8b;
    border-color: #10707f; }
  div.bootstrap .btn-info:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-info:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-info.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(23, 162, 184, 0.5); }
  div.bootstrap .btn-warning {
    color: #212529;
    background-color: #ffc107;
    border-color: #ffc107; }
  div.bootstrap .btn-warning:hover {
    color: #212529;
    background-color: #e0a800;
    border-color: #d39e00; }
  div.bootstrap .btn-warning.focus, div.bootstrap .btn-warning:focus {
    box-shadow: 0 0 0 0.2rem rgba(255, 193, 7, 0.5); }
  div.bootstrap .btn-warning.disabled, div.bootstrap .btn-warning:disabled {
    color: #212529;
    background-color: #ffc107;
    border-color: #ffc107; }
  div.bootstrap .btn-warning:not(:disabled):not(.disabled).active, div.bootstrap .btn-warning:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-warning.dropdown-toggle {
    color: #212529;
    background-color: #d39e00;
    border-color: #c69500; }
  div.bootstrap .btn-warning:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-warning:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-warning.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(255, 193, 7, 0.5); }
  div.bootstrap .btn-danger {
    color: #fff;
    background-color: #dc3545;
    border-color: #dc3545; }
  div.bootstrap .btn-danger:hover {
    color: #fff;
    background-color: #c82333;
    border-color: #bd2130; }
  div.bootstrap .btn-danger.focus, div.bootstrap .btn-danger:focus {
    box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.5); }
  div.bootstrap .btn-danger.disabled, div.bootstrap .btn-danger:disabled {
    color: #fff;
    background-color: #dc3545;
    border-color: #dc3545; }
  div.bootstrap .btn-danger:not(:disabled):not(.disabled).active, div.bootstrap .btn-danger:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-danger.dropdown-toggle {
    color: #fff;
    background-color: #bd2130;
    border-color: #b21f2d; }
  div.bootstrap .btn-danger:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-danger:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-danger.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.5); }
  div.bootstrap .btn-light {
    color: #212529;
    background-color: #f8f9fa;
    border-color: #f8f9fa; }
  div.bootstrap .btn-light:hover {
    color: #212529;
    background-color: #e2e6ea;
    border-color: #dae0e5; }
  div.bootstrap .btn-light.focus, div.bootstrap .btn-light:focus {
    box-shadow: 0 0 0 0.2rem rgba(248, 249, 250, 0.5); }
  div.bootstrap .btn-light.disabled, div.bootstrap .btn-light:disabled {
    color: #212529;
    background-color: #f8f9fa;
    border-color: #f8f9fa; }
  div.bootstrap .btn-light:not(:disabled):not(.disabled).active, div.bootstrap .btn-light:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-light.dropdown-toggle {
    color: #212529;
    background-color: #dae0e5;
    border-color: #d3d9df; }
  div.bootstrap .btn-light:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-light:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-light.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(248, 249, 250, 0.5); }
  div.bootstrap .btn-dark {
    color: #fff;
    background-color: #343a40;
    border-color: #343a40; }
  div.bootstrap .btn-dark:hover {
    color: #fff;
    background-color: #23272b;
    border-color: #1d2124; }
  div.bootstrap .btn-dark.focus, div.bootstrap .btn-dark:focus {
    box-shadow: 0 0 0 0.2rem rgba(52, 58, 64, 0.5); }
  div.bootstrap .btn-dark.disabled, div.bootstrap .btn-dark:disabled {
    color: #fff;
    background-color: #343a40;
    border-color: #343a40; }
  div.bootstrap .btn-dark:not(:disabled):not(.disabled).active, div.bootstrap .btn-dark:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-dark.dropdown-toggle {
    color: #fff;
    background-color: #1d2124;
    border-color: #171a1d; }
  div.bootstrap .btn-dark:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-dark:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-dark.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(52, 58, 64, 0.5); }
  div.bootstrap .btn-outline-primary {
    color: #007bff;
    background-color: transparent;
    background-image: none;
    border-color: #007bff; }
  div.bootstrap .btn-outline-primary:hover {
    color: #fff;
    background-color: #007bff;
    border-color: #007bff; }
  div.bootstrap .btn-outline-primary.focus, div.bootstrap .btn-outline-primary:focus {
    box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.5); }
  div.bootstrap .btn-outline-primary.disabled, div.bootstrap .btn-outline-primary:disabled {
    color: #007bff;
    background-color: transparent; }
  div.bootstrap .btn-outline-primary:not(:disabled):not(.disabled).active, div.bootstrap .btn-outline-primary:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-outline-primary.dropdown-toggle {
    color: #fff;
    background-color: #007bff;
    border-color: #007bff; }
  div.bootstrap .btn-outline-primary:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-outline-primary:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-outline-primary.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.5); }
  div.bootstrap .btn-outline-secondary {
    color: #6c757d;
    background-color: transparent;
    background-image: none;
    border-color: #6c757d; }
  div.bootstrap .btn-outline-secondary:hover {
    color: #fff;
    background-color: #6c757d;
    border-color: #6c757d; }
  div.bootstrap .btn-outline-secondary.focus, div.bootstrap .btn-outline-secondary:focus {
    box-shadow: 0 0 0 0.2rem rgba(108, 117, 125, 0.5); }
  div.bootstrap .btn-outline-secondary.disabled, div.bootstrap .btn-outline-secondary:disabled {
    color: #6c757d;
    background-color: transparent; }
  div.bootstrap .btn-outline-secondary:not(:disabled):not(.disabled).active, div.bootstrap .btn-outline-secondary:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-outline-secondary.dropdown-toggle {
    color: #fff;
    background-color: #6c757d;
    border-color: #6c757d; }
  div.bootstrap .btn-outline-secondary:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-outline-secondary:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-outline-secondary.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(108, 117, 125, 0.5); }
  div.bootstrap .btn-outline-success {
    color: #28a745;
    background-color: transparent;
    background-image: none;
    border-color: #28a745; }
  div.bootstrap .btn-outline-success:hover {
    color: #fff;
    background-color: #28a745;
    border-color: #28a745; }
  div.bootstrap .btn-outline-success.focus, div.bootstrap .btn-outline-success:focus {
    box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.5); }
  div.bootstrap .btn-outline-success.disabled, div.bootstrap .btn-outline-success:disabled {
    color: #28a745;
    background-color: transparent; }
  div.bootstrap .btn-outline-success:not(:disabled):not(.disabled).active, div.bootstrap .btn-outline-success:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-outline-success.dropdown-toggle {
    color: #fff;
    background-color: #28a745;
    border-color: #28a745; }
  div.bootstrap .btn-outline-success:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-outline-success:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-outline-success.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.5); }
  div.bootstrap .btn-outline-info {
    color: #17a2b8;
    background-color: transparent;
    background-image: none;
    border-color: #17a2b8; }
  div.bootstrap .btn-outline-info:hover {
    color: #fff;
    background-color: #17a2b8;
    border-color: #17a2b8; }
  div.bootstrap .btn-outline-info.focus, div.bootstrap .btn-outline-info:focus {
    box-shadow: 0 0 0 0.2rem rgba(23, 162, 184, 0.5); }
  div.bootstrap .btn-outline-info.disabled, div.bootstrap .btn-outline-info:disabled {
    color: #17a2b8;
    background-color: transparent; }
  div.bootstrap .btn-outline-info:not(:disabled):not(.disabled).active, div.bootstrap .btn-outline-info:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-outline-info.dropdown-toggle {
    color: #fff;
    background-color: #17a2b8;
    border-color: #17a2b8; }
  div.bootstrap .btn-outline-info:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-outline-info:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-outline-info.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(23, 162, 184, 0.5); }
  div.bootstrap .btn-outline-warning {
    color: #ffc107;
    background-color: transparent;
    background-image: none;
    border-color: #ffc107; }
  div.bootstrap .btn-outline-warning:hover {
    color: #212529;
    background-color: #ffc107;
    border-color: #ffc107; }
  div.bootstrap .btn-outline-warning.focus, div.bootstrap .btn-outline-warning:focus {
    box-shadow: 0 0 0 0.2rem rgba(255, 193, 7, 0.5); }
  div.bootstrap .btn-outline-warning.disabled, div.bootstrap .btn-outline-warning:disabled {
    color: #ffc107;
    background-color: transparent; }
  div.bootstrap .btn-outline-warning:not(:disabled):not(.disabled).active, div.bootstrap .btn-outline-warning:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-outline-warning.dropdown-toggle {
    color: #212529;
    background-color: #ffc107;
    border-color: #ffc107; }
  div.bootstrap .btn-outline-warning:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-outline-warning:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-outline-warning.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(255, 193, 7, 0.5); }
  div.bootstrap .btn-outline-danger {
    color: #dc3545;
    background-color: transparent;
    background-image: none;
    border-color: #dc3545; }
  div.bootstrap .btn-outline-danger:hover {
    color: #fff;
    background-color: #dc3545;
    border-color: #dc3545; }
  div.bootstrap .btn-outline-danger.focus, div.bootstrap .btn-outline-danger:focus {
    box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.5); }
  div.bootstrap .btn-outline-danger.disabled, div.bootstrap .btn-outline-danger:disabled {
    color: #dc3545;
    background-color: transparent; }
  div.bootstrap .btn-outline-danger:not(:disabled):not(.disabled).active, div.bootstrap .btn-outline-danger:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-outline-danger.dropdown-toggle {
    color: #fff;
    background-color: #dc3545;
    border-color: #dc3545; }
  div.bootstrap .btn-outline-danger:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-outline-danger:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-outline-danger.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.5); }
  div.bootstrap .btn-outline-light {
    color: #f8f9fa;
    background-color: transparent;
    background-image: none;
    border-color: #f8f9fa; }
  div.bootstrap .btn-outline-light:hover {
    color: #212529;
    background-color: #f8f9fa;
    border-color: #f8f9fa; }
  div.bootstrap .btn-outline-light.focus, div.bootstrap .btn-outline-light:focus {
    box-shadow: 0 0 0 0.2rem rgba(248, 249, 250, 0.5); }
  div.bootstrap .btn-outline-light.disabled, div.bootstrap .btn-outline-light:disabled {
    color: #f8f9fa;
    background-color: transparent; }
  div.bootstrap .btn-outline-light:not(:disabled):not(.disabled).active, div.bootstrap .btn-outline-light:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-outline-light.dropdown-toggle {
    color: #212529;
    background-color: #f8f9fa;
    border-color: #f8f9fa; }
  div.bootstrap .btn-outline-light:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-outline-light:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-outline-light.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(248, 249, 250, 0.5); }
  div.bootstrap .btn-outline-dark {
    color: #343a40;
    background-color: transparent;
    background-image: none;
    border-color: #343a40; }
  div.bootstrap .btn-outline-dark:hover {
    color: #fff;
    background-color: #343a40;
    border-color: #343a40; }
  div.bootstrap .btn-outline-dark.focus, div.bootstrap .btn-outline-dark:focus {
    box-shadow: 0 0 0 0.2rem rgba(52, 58, 64, 0.5); }
  div.bootstrap .btn-outline-dark.disabled, div.bootstrap .btn-outline-dark:disabled {
    color: #343a40;
    background-color: transparent; }
  div.bootstrap .btn-outline-dark:not(:disabled):not(.disabled).active, div.bootstrap .btn-outline-dark:not(:disabled):not(.disabled):active, div.bootstrap .show > .btn-outline-dark.dropdown-toggle {
    color: #fff;
    background-color: #343a40;
    border-color: #343a40; }
  div.bootstrap .btn-outline-dark:not(:disabled):not(.disabled).active:focus, div.bootstrap .btn-outline-dark:not(:disabled):not(.disabled):active:focus, div.bootstrap .show > .btn-outline-dark.dropdown-toggle:focus {
    box-shadow: 0 0 0 0.2rem rgba(52, 58, 64, 0.5); }
  div.bootstrap .btn-link {
    font-weight: 400;
    color: #007bff;
    background-color: transparent; }
  div.bootstrap .btn-link:hover {
    color: #0056b3;
    text-decoration: underline;
    background-color: transparent;
    border-color: transparent; }
  div.bootstrap .btn-link.focus, div.bootstrap .btn-link:focus {
    text-decoration: underline;
    border-color: transparent;
    box-shadow: none; }
  div.bootstrap .btn-link.disabled, div.bootstrap .btn-link:disabled {
    color: #6c757d; }
  div.bootstrap .btn-group-lg > .btn, div.bootstrap .btn-lg {
    padding: .5rem 1rem;
    font-size: 1.25rem;
    line-height: 1.5;
    border-radius: .3rem; }
  div.bootstrap .btn-group-sm > .btn, div.bootstrap .btn-sm {
    padding: .25rem .5rem;
    font-size: .875rem;
    line-height: 1.5;
    border-radius: .2rem; }
  div.bootstrap .btn-block {
    display: block;
    width: 100%; }
  div.bootstrap .btn-block + .btn-block {
    margin-top: .5rem; }
  div.bootstrap input[type=button].btn-block, div.bootstrap input[type=reset].btn-block, div.bootstrap input[type=submit].btn-block {
    width: 100%; }
  div.bootstrap .fade {
    opacity: 0;
    transition: opacity .15s linear; }
  div.bootstrap .fade.show {
    opacity: 1; }
  div.bootstrap .collapse {
    display: none; }
  div.bootstrap .collapse.show {
    display: block; }
  div.bootstrap tr.collapse.show {
    display: table-row; }
  div.bootstrap tbody.collapse.show {
    display: table-row-group; }
  div.bootstrap .collapsing {
    position: relative;
    height: 0;
    overflow: hidden;
    transition: height .35s ease; }
  div.bootstrap .dropdown, div.bootstrap .dropup {
    position: relative; }
  div.bootstrap .dropdown-toggle::after {
    display: inline-block;
    width: 0;
    height: 0;
    margin-left: .255em;
    vertical-align: .255em;
    content: "";
    border-top: .3em solid;
    border-right: .3em solid transparent;
    border-bottom: 0;
    border-left: .3em solid transparent; }
  div.bootstrap .dropdown-toggle:empty::after {
    margin-left: 0; }
  div.bootstrap .dropdown-menu {
    position: absolute;
    top: 100%;
    left: 0;
    z-index: 1000;
    display: none;
    float: left;
    min-width: 10rem;
    padding: .5rem 0;
    margin: .125rem 0 0;
    font-size: 1rem;
    color: #212529;
    text-align: left;
    list-style: none;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid rgba(0, 0, 0, 0.15);
    border-radius: .25rem; }
  div.bootstrap .dropup .dropdown-menu {
    margin-top: 0;
    margin-bottom: .125rem; }
  div.bootstrap .dropup .dropdown-toggle::after {
    display: inline-block;
    width: 0;
    height: 0;
    margin-left: .255em;
    vertical-align: .255em;
    content: "";
    border-top: 0;
    border-right: .3em solid transparent;
    border-bottom: .3em solid;
    border-left: .3em solid transparent; }
  div.bootstrap .dropup .dropdown-toggle:empty::after {
    margin-left: 0; }
  div.bootstrap .dropright .dropdown-menu {
    margin-top: 0;
    margin-left: .125rem; }
  div.bootstrap .dropright .dropdown-toggle::after {
    display: inline-block;
    width: 0;
    height: 0;
    margin-left: .255em;
    vertical-align: .255em;
    content: "";
    border-top: .3em solid transparent;
    border-bottom: .3em solid transparent;
    border-left: .3em solid; }
  div.bootstrap .dropright .dropdown-toggle:empty::after {
    margin-left: 0; }
  div.bootstrap .dropright .dropdown-toggle::after {
    vertical-align: 0; }
  div.bootstrap .dropleft .dropdown-menu {
    margin-top: 0;
    margin-right: .125rem; }
  div.bootstrap .dropleft .dropdown-toggle::after {
    display: inline-block;
    width: 0;
    height: 0;
    margin-left: .255em;
    vertical-align: .255em;
    content: ""; }
  div.bootstrap .dropleft .dropdown-toggle::after {
    display: none; }
  div.bootstrap .dropleft .dropdown-toggle::before {
    display: inline-block;
    width: 0;
    height: 0;
    margin-right: .255em;
    vertical-align: .255em;
    content: "";
    border-top: .3em solid transparent;
    border-right: .3em solid;
    border-bottom: .3em solid transparent; }
  div.bootstrap .dropleft .dropdown-toggle:empty::after {
    margin-left: 0; }
  div.bootstrap .dropleft .dropdown-toggle::before {
    vertical-align: 0; }
  div.bootstrap .dropdown-divider {
    height: 0;
    margin: .5rem 0;
    overflow: hidden;
    border-top: 1px solid #e9ecef; }
  div.bootstrap .dropdown-item {
    display: block;
    width: 100%;
    padding: .25rem 1.5rem;
    clear: both;
    font-weight: 400;
    color: #212529;
    text-align: inherit;
    white-space: nowrap;
    background-color: transparent;
    border: 0; }
  div.bootstrap .dropdown-item:focus, div.bootstrap .dropdown-item:hover {
    color: #16181b;
    text-decoration: none;
    background-color: #f8f9fa; }
  div.bootstrap .dropdown-item.active, div.bootstrap .dropdown-item:active {
    color: #fff;
    text-decoration: none;
    background-color: #007bff; }
  div.bootstrap .dropdown-item.disabled, div.bootstrap .dropdown-item:disabled {
    color: #6c757d;
    background-color: transparent; }
  div.bootstrap .dropdown-menu.show {
    display: block; }
  div.bootstrap .dropdown-header {
    display: block;
    padding: .5rem 1.5rem;
    margin-bottom: 0;
    font-size: .875rem;
    color: #6c757d;
    white-space: nowrap; }
  div.bootstrap .btn-group, div.bootstrap .btn-group-vertical {
    position: relative;
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
    vertical-align: middle; }
  div.bootstrap .btn-group-vertical > .btn, div.bootstrap .btn-group > .btn {
    position: relative;
    -webkit-box-flex: 0;
    -ms-flex: 0 1 auto;
    flex: 0 1 auto; }
  div.bootstrap .btn-group-vertical > .btn:hover, div.bootstrap .btn-group > .btn:hover {
    z-index: 1; }
  div.bootstrap .btn-group-vertical > .btn.active, div.bootstrap .btn-group-vertical > .btn:active, div.bootstrap .btn-group-vertical > .btn:focus, div.bootstrap .btn-group > .btn.active, div.bootstrap .btn-group > .btn:active, div.bootstrap .btn-group > .btn:focus {
    z-index: 1; }
  div.bootstrap .btn-group .btn + .btn, div.bootstrap .btn-group .btn + .btn-group, div.bootstrap .btn-group .btn-group + .btn, div.bootstrap .btn-group .btn-group + .btn-group, div.bootstrap .btn-group-vertical .btn + .btn, div.bootstrap .btn-group-vertical .btn + .btn-group, div.bootstrap .btn-group-vertical .btn-group + .btn, div.bootstrap .btn-group-vertical .btn-group + .btn-group {
    margin-left: -1px; }
  div.bootstrap .btn-toolbar {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -webkit-box-pack: start;
    -ms-flex-pack: start;
    justify-content: flex-start; }
  div.bootstrap .btn-toolbar .input-group {
    width: auto; }
  div.bootstrap .btn-group > .btn:first-child {
    margin-left: 0; }
  div.bootstrap .btn-group > .btn-group:not(:last-child) > .btn, div.bootstrap .btn-group > .btn:not(:last-child):not(.dropdown-toggle) {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0; }
  div.bootstrap .btn-group > .btn-group:not(:first-child) > .btn, div.bootstrap .btn-group > .btn:not(:first-child) {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0; }
  div.bootstrap .dropdown-toggle-split {
    padding-right: .5625rem;
    padding-left: .5625rem; }
  div.bootstrap .dropdown-toggle-split::after {
    margin-left: 0; }
  div.bootstrap .btn-group-sm > .btn + .dropdown-toggle-split, div.bootstrap .btn-sm + .dropdown-toggle-split {
    padding-right: .375rem;
    padding-left: .375rem; }
  div.bootstrap .btn-group-lg > .btn + .dropdown-toggle-split, div.bootstrap .btn-lg + .dropdown-toggle-split {
    padding-right: .75rem;
    padding-left: .75rem; }
  div.bootstrap .btn-group-vertical {
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column;
    -webkit-box-align: start;
    -ms-flex-align: start;
    align-items: flex-start;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center; }
  div.bootstrap .btn-group-vertical .btn, div.bootstrap .btn-group-vertical .btn-group {
    width: 100%; }
  div.bootstrap .btn-group-vertical > .btn + .btn, div.bootstrap .btn-group-vertical > .btn + .btn-group, div.bootstrap .btn-group-vertical > .btn-group + .btn, div.bootstrap .btn-group-vertical > .btn-group + .btn-group {
    margin-top: -1px;
    margin-left: 0; }
  div.bootstrap .btn-group-vertical > .btn-group:not(:last-child) > .btn, div.bootstrap .btn-group-vertical > .btn:not(:last-child):not(.dropdown-toggle) {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0; }
  div.bootstrap .btn-group-vertical > .btn-group:not(:first-child) > .btn, div.bootstrap .btn-group-vertical > .btn:not(:first-child) {
    border-top-left-radius: 0;
    border-top-right-radius: 0; }
  div.bootstrap .btn-group-toggle > .btn, div.bootstrap .btn-group-toggle > .btn-group > .btn {
    margin-bottom: 0; }
  div.bootstrap .btn-group-toggle > .btn input[type=checkbox], div.bootstrap .btn-group-toggle > .btn input[type=radio], div.bootstrap .btn-group-toggle > .btn-group > .btn input[type=checkbox], div.bootstrap .btn-group-toggle > .btn-group > .btn input[type=radio] {
    position: absolute;
    clip: rect(0, 0, 0, 0);
    pointer-events: none; }
  div.bootstrap .input-group {
    position: relative;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -webkit-box-align: stretch;
    -ms-flex-align: stretch;
    align-items: stretch;
    width: 100%; }
  div.bootstrap .input-group > .custom-file, div.bootstrap .input-group > .custom-select, div.bootstrap .input-group > .form-control {
    position: relative;
    -webkit-box-flex: 1;
    -ms-flex: 1 1 auto;
    flex: 1 1 auto;
    width: 1%;
    margin-bottom: 0; }
  div.bootstrap .input-group > .custom-file:focus, div.bootstrap .input-group > .custom-select:focus, div.bootstrap .input-group > .form-control:focus {
    z-index: 3; }
  div.bootstrap .input-group > .custom-file + .custom-file, div.bootstrap .input-group > .custom-file + .custom-select, div.bootstrap .input-group > .custom-file + .form-control, div.bootstrap .input-group > .custom-select + .custom-file, div.bootstrap .input-group > .custom-select + .custom-select, div.bootstrap .input-group > .custom-select + .form-control, div.bootstrap .input-group > .form-control + .custom-file, div.bootstrap .input-group > .form-control + .custom-select, div.bootstrap .input-group > .form-control + .form-control {
    margin-left: -1px; }
  div.bootstrap .input-group > .custom-select:not(:last-child), div.bootstrap .input-group > .form-control:not(:last-child) {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0; }
  div.bootstrap .input-group > .custom-select:not(:first-child), div.bootstrap .input-group > .form-control:not(:first-child) {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0; }
  div.bootstrap .input-group > .custom-file {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center; }
  div.bootstrap .input-group > .custom-file:not(:last-child) .custom-file-label, div.bootstrap .input-group > .custom-file:not(:last-child) .custom-file-label::before {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0; }
  div.bootstrap .input-group > .custom-file:not(:first-child) .custom-file-label, div.bootstrap .input-group > .custom-file:not(:first-child) .custom-file-label::before {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0; }
  div.bootstrap .input-group-append, div.bootstrap .input-group-prepend {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex; }
  div.bootstrap .input-group-append .btn, div.bootstrap .input-group-prepend .btn {
    position: relative;
    z-index: 2; }
  div.bootstrap .input-group-append .btn + .btn, div.bootstrap .input-group-append .btn + .input-group-text, div.bootstrap .input-group-append .input-group-text + .btn, div.bootstrap .input-group-append .input-group-text + .input-group-text, div.bootstrap .input-group-prepend .btn + .btn, div.bootstrap .input-group-prepend .btn + .input-group-text, div.bootstrap .input-group-prepend .input-group-text + .btn, div.bootstrap .input-group-prepend .input-group-text + .input-group-text {
    margin-left: -1px; }
  div.bootstrap .input-group-prepend {
    margin-right: -1px; }
  div.bootstrap .input-group-append {
    margin-left: -1px; }
  div.bootstrap .input-group-text {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    padding: .375rem .75rem;
    margin-bottom: 0;
    font-size: 1rem;
    font-weight: 400;
    line-height: 1.5;
    color: #495057;
    text-align: center;
    white-space: nowrap;
    background-color: #e9ecef;
    border: 1px solid #ced4da;
    border-radius: .25rem; }
  div.bootstrap .input-group-text input[type=checkbox], div.bootstrap .input-group-text input[type=radio] {
    margin-top: 0; }
  div.bootstrap .input-group > .input-group-append:last-child > .btn:not(:last-child):not(.dropdown-toggle), div.bootstrap .input-group > .input-group-append:last-child > .input-group-text:not(:last-child), div.bootstrap .input-group > .input-group-append:not(:last-child) > .btn, div.bootstrap .input-group > .input-group-append:not(:last-child) > .input-group-text, div.bootstrap .input-group > .input-group-prepend > .btn, div.bootstrap .input-group > .input-group-prepend > .input-group-text {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0; }
  div.bootstrap .input-group > .input-group-append > .btn, div.bootstrap .input-group > .input-group-append > .input-group-text, div.bootstrap .input-group > .input-group-prepend:first-child > .btn:not(:first-child), div.bootstrap .input-group > .input-group-prepend:first-child > .input-group-text:not(:first-child), div.bootstrap .input-group > .input-group-prepend:not(:first-child) > .btn, div.bootstrap .input-group > .input-group-prepend:not(:first-child) > .input-group-text {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0; }
  div.bootstrap .custom-control {
    position: relative;
    display: block;
    min-height: 1.5rem;
    padding-left: 1.5rem; }
  div.bootstrap .custom-control-inline {
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
    margin-right: 1rem; }
  div.bootstrap .custom-control-input {
    position: absolute;
    z-index: -1;
    opacity: 0; }
  div.bootstrap .custom-control-input:checked ~ .custom-control-label::before {
    color: #fff;
    background-color: #007bff; }
  div.bootstrap .custom-control-input:focus ~ .custom-control-label::before {
    box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem rgba(0, 123, 255, 0.25); }
  div.bootstrap .custom-control-input:active ~ .custom-control-label::before {
    color: #fff;
    background-color: #b3d7ff; }
  div.bootstrap .custom-control-input:disabled ~ .custom-control-label {
    color: #6c757d; }
  div.bootstrap .custom-control-input:disabled ~ .custom-control-label::before {
    background-color: #e9ecef; }
  div.bootstrap .custom-control-label {
    margin-bottom: 0; }
  div.bootstrap .custom-control-label::before {
    position: absolute;
    top: .25rem;
    left: 0;
    display: block;
    width: 1rem;
    height: 1rem;
    pointer-events: none;
    content: "";
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    background-color: #dee2e6; }
  div.bootstrap .custom-control-label::after {
    position: absolute;
    top: .25rem;
    left: 0;
    display: block;
    width: 1rem;
    height: 1rem;
    content: "";
    background-repeat: no-repeat;
    background-position: center center;
    background-size: 50% 50%; }
  div.bootstrap .custom-checkbox .custom-control-label::before {
    border-radius: .25rem; }
  div.bootstrap .custom-checkbox .custom-control-input:checked ~ .custom-control-label::before {
    background-color: #007bff; }
  div.bootstrap .custom-checkbox .custom-control-input:checked ~ .custom-control-label::after {
    background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'%3E%3Cpath fill='%23fff' d='M6.564.75l-3.59 3.612-1.538-1.55L0 4.26 2.974 7.25 8 2.193z'/%3E%3C/svg%3E"); }
  div.bootstrap .custom-checkbox .custom-control-input:indeterminate ~ .custom-control-label::before {
    background-color: #007bff; }
  div.bootstrap .custom-checkbox .custom-control-input:indeterminate ~ .custom-control-label::after {
    background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 4 4'%3E%3Cpath stroke='%23fff' d='M0 2h4'/%3E%3C/svg%3E"); }
  div.bootstrap .custom-checkbox .custom-control-input:disabled:checked ~ .custom-control-label::before {
    background-color: rgba(0, 123, 255, 0.5); }
  div.bootstrap .custom-checkbox .custom-control-input:disabled:indeterminate ~ .custom-control-label::before {
    background-color: rgba(0, 123, 255, 0.5); }
  div.bootstrap .custom-radio .custom-control-label::before {
    border-radius: 50%; }
  div.bootstrap .custom-radio .custom-control-input:checked ~ .custom-control-label::before {
    background-color: #007bff; }
  div.bootstrap .custom-radio .custom-control-input:checked ~ .custom-control-label::after {
    background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'%3E%3Ccircle r='3' fill='%23fff'/%3E%3C/svg%3E"); }
  div.bootstrap .custom-radio .custom-control-input:disabled:checked ~ .custom-control-label::before {
    background-color: rgba(0, 123, 255, 0.5); }
  div.bootstrap .custom-select {
    display: inline-block;
    width: 100%;
    height: calc(2.25rem + 2px);
    padding: .375rem 1.75rem .375rem .75rem;
    line-height: 1.5;
    color: #495057;
    vertical-align: middle;
    background: #fff url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 4 5'%3E%3Cpath fill='%23343a40' d='M2 0L0 2h4zm0 5L0 3h4z'/%3E%3C/svg%3E") no-repeat right 0.75rem center;
    background-size: 8px 10px;
    border: 1px solid #ced4da;
    border-radius: .25rem;
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none; }
  div.bootstrap .custom-select:focus {
    border-color: #80bdff;
    outline: 0;
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.075), 0 0 5px rgba(128, 189, 255, 0.5); }
  div.bootstrap .custom-select:focus::-ms-value {
    color: #495057;
    background-color: #fff; }
  div.bootstrap .custom-select[multiple], div.bootstrap .custom-select[size]:not([size="1"]) {
    height: auto;
    padding-right: .75rem;
    background-image: none; }
  div.bootstrap .custom-select:disabled {
    color: #6c757d;
    background-color: #e9ecef; }
  div.bootstrap .custom-select::-ms-expand {
    opacity: 0; }
  div.bootstrap .custom-select-sm {
    height: calc(1.8125rem + 2px);
    padding-top: .375rem;
    padding-bottom: .375rem;
    font-size: 75%; }
  div.bootstrap .custom-select-lg {
    height: calc(2.875rem + 2px);
    padding-top: .375rem;
    padding-bottom: .375rem;
    font-size: 125%; }
  div.bootstrap .custom-file {
    position: relative;
    display: inline-block;
    width: 100%;
    height: calc(2.25rem + 2px);
    margin-bottom: 0; }
  div.bootstrap .custom-file-input {
    position: relative;
    z-index: 2;
    width: 100%;
    height: calc(2.25rem + 2px);
    margin: 0;
    opacity: 0; }
  div.bootstrap .custom-file-input:focus ~ .custom-file-control {
    border-color: #80bdff;
    box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25); }
  div.bootstrap .custom-file-input:focus ~ .custom-file-control::before {
    border-color: #80bdff; }
  div.bootstrap .custom-file-input:lang(en) ~ .custom-file-label::after {
    content: "Browse"; }
  div.bootstrap .custom-file-label {
    position: absolute;
    top: 0;
    right: 0;
    left: 0;
    z-index: 1;
    height: calc(2.25rem + 2px);
    padding: .375rem .75rem;
    line-height: 1.5;
    color: #495057;
    background-color: #fff;
    border: 1px solid #ced4da;
    border-radius: .25rem; }
  div.bootstrap .custom-file-label::after {
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    z-index: 3;
    display: block;
    height: calc(calc(2.25rem + 2px) - 1px * 2);
    padding: .375rem .75rem;
    line-height: 1.5;
    color: #495057;
    content: "Browse";
    background-color: #e9ecef;
    border-left: 1px solid #ced4da;
    border-radius: 0 .25rem .25rem 0; }
  div.bootstrap .nav {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    padding-left: 0;
    margin-bottom: 0;
    list-style: none; }
  div.bootstrap .nav-link {
    display: block;
    padding: .5rem 1rem; }
  div.bootstrap .nav-link:focus, div.bootstrap .nav-link:hover {
    text-decoration: none; }
  div.bootstrap .nav-link.disabled {
    color: #6c757d; }
  div.bootstrap .nav-tabs {
    border-bottom: 1px solid #dee2e6; }
  div.bootstrap .nav-tabs .nav-item {
    margin-bottom: -1px; }
  div.bootstrap .nav-tabs .nav-link {
    border: 1px solid transparent;
    border-top-left-radius: .25rem;
    border-top-right-radius: .25rem; }
  div.bootstrap .nav-tabs .nav-link:focus, div.bootstrap .nav-tabs .nav-link:hover {
    border-color: #e9ecef #e9ecef #dee2e6; }
  div.bootstrap .nav-tabs .nav-link.disabled {
    color: #6c757d;
    background-color: transparent;
    border-color: transparent; }
  div.bootstrap .nav-tabs .nav-item.show .nav-link, div.bootstrap .nav-tabs .nav-link.active {
    color: #495057;
    background-color: #fff;
    border-color: #dee2e6 #dee2e6 #fff; }
  div.bootstrap .nav-tabs .dropdown-menu {
    margin-top: -1px;
    border-top-left-radius: 0;
    border-top-right-radius: 0; }
  div.bootstrap .nav-pills .nav-link {
    border-radius: .25rem; }
  div.bootstrap .nav-pills .nav-link.active, div.bootstrap .nav-pills .show > .nav-link {
    color: #fff;
    background-color: #007bff; }
  div.bootstrap .nav-fill .nav-item {
    -webkit-box-flex: 1;
    -ms-flex: 1 1 auto;
    flex: 1 1 auto;
    text-align: center; }
  div.bootstrap .nav-justified .nav-item {
    -ms-flex-preferred-size: 0;
    flex-basis: 0;
    -webkit-box-flex: 1;
    -ms-flex-positive: 1;
    flex-grow: 1;
    text-align: center; }
  div.bootstrap .tab-content > .tab-pane {
    display: none; }
  div.bootstrap .tab-content > .active {
    display: block; }
  div.bootstrap .navbar {
    position: relative;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    -webkit-box-pack: justify;
    -ms-flex-pack: justify;
    justify-content: space-between;
    padding: .5rem 1rem; }
  div.bootstrap .navbar > .container, div.bootstrap .navbar > .container-fluid {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    -webkit-box-pack: justify;
    -ms-flex-pack: justify;
    justify-content: space-between; }
  div.bootstrap .navbar-brand {
    display: inline-block;
    padding-top: .3125rem;
    padding-bottom: .3125rem;
    margin-right: 1rem;
    font-size: 1.25rem;
    line-height: inherit;
    white-space: nowrap; }
  div.bootstrap .navbar-brand:focus, div.bootstrap .navbar-brand:hover {
    text-decoration: none; }
  div.bootstrap .navbar-nav {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column;
    padding-left: 0;
    margin-bottom: 0;
    list-style: none; }
  div.bootstrap .navbar-nav .nav-link {
    padding-right: 0;
    padding-left: 0; }
  div.bootstrap .navbar-nav .dropdown-menu {
    position: static;
    float: none; }
  div.bootstrap .navbar-text {
    display: inline-block;
    padding-top: .5rem;
    padding-bottom: .5rem; }
  div.bootstrap .navbar-collapse {
    -ms-flex-preferred-size: 100%;
    flex-basis: 100%;
    -webkit-box-flex: 1;
    -ms-flex-positive: 1;
    flex-grow: 1;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center; }
  div.bootstrap .navbar-toggler {
    padding: .25rem .75rem;
    font-size: 1.25rem;
    line-height: 1;
    background-color: transparent;
    border: 1px solid transparent;
    border-radius: .25rem; }
  div.bootstrap .navbar-toggler:focus, div.bootstrap .navbar-toggler:hover {
    text-decoration: none; }
  div.bootstrap .navbar-toggler:not(:disabled):not(.disabled) {
    cursor: pointer; }
  div.bootstrap .navbar-toggler-icon {
    display: inline-block;
    width: 1.5em;
    height: 1.5em;
    vertical-align: middle;
    content: "";
    background: no-repeat center center;
    background-size: 100% 100%; }
  @media (max-width: 575.98px) {
    div.bootstrap .navbar-expand-sm > .container, div.bootstrap .navbar-expand-sm > .container-fluid {
      padding-right: 0;
      padding-left: 0; } }
  @media (min-width: 576px) {
    div.bootstrap .navbar-expand-sm {
      -webkit-box-orient: horizontal;
      -webkit-box-direction: normal;
      -ms-flex-flow: row nowrap;
      flex-flow: row nowrap;
      -webkit-box-pack: start;
      -ms-flex-pack: start;
      justify-content: flex-start; }
    div.bootstrap .navbar-expand-sm .navbar-nav {
      -webkit-box-orient: horizontal;
      -webkit-box-direction: normal;
      -ms-flex-direction: row;
      flex-direction: row; }
    div.bootstrap .navbar-expand-sm .navbar-nav .dropdown-menu {
      position: absolute; }
    div.bootstrap .navbar-expand-sm .navbar-nav .dropdown-menu-right {
      right: 0;
      left: auto; }
    div.bootstrap .navbar-expand-sm .navbar-nav .nav-link {
      padding-right: .5rem;
      padding-left: .5rem; }
    div.bootstrap .navbar-expand-sm > .container, div.bootstrap .navbar-expand-sm > .container-fluid {
      -ms-flex-wrap: nowrap;
      flex-wrap: nowrap; }
    div.bootstrap .navbar-expand-sm .navbar-collapse {
      display: -webkit-box !important;
      display: -ms-flexbox !important;
      display: flex !important;
      -ms-flex-preferred-size: auto;
      flex-basis: auto; }
    div.bootstrap .navbar-expand-sm .navbar-toggler {
      display: none; }
    div.bootstrap .navbar-expand-sm .dropup .dropdown-menu {
      top: auto;
      bottom: 100%; } }
  @media (max-width: 767.98px) {
    div.bootstrap .navbar-expand-md > .container, div.bootstrap .navbar-expand-md > .container-fluid {
      padding-right: 0;
      padding-left: 0; } }
  @media (min-width: 768px) {
    div.bootstrap .navbar-expand-md {
      -webkit-box-orient: horizontal;
      -webkit-box-direction: normal;
      -ms-flex-flow: row nowrap;
      flex-flow: row nowrap;
      -webkit-box-pack: start;
      -ms-flex-pack: start;
      justify-content: flex-start; }
    div.bootstrap .navbar-expand-md .navbar-nav {
      -webkit-box-orient: horizontal;
      -webkit-box-direction: normal;
      -ms-flex-direction: row;
      flex-direction: row; }
    div.bootstrap .navbar-expand-md .navbar-nav .dropdown-menu {
      position: absolute; }
    div.bootstrap .navbar-expand-md .navbar-nav .dropdown-menu-right {
      right: 0;
      left: auto; }
    div.bootstrap .navbar-expand-md .navbar-nav .nav-link {
      padding-right: .5rem;
      padding-left: .5rem; }
    div.bootstrap .navbar-expand-md > .container, div.bootstrap .navbar-expand-md > .container-fluid {
      -ms-flex-wrap: nowrap;
      flex-wrap: nowrap; }
    div.bootstrap .navbar-expand-md .navbar-collapse {
      display: -webkit-box !important;
      display: -ms-flexbox !important;
      display: flex !important;
      -ms-flex-preferred-size: auto;
      flex-basis: auto; }
    div.bootstrap .navbar-expand-md .navbar-toggler {
      display: none; }
    div.bootstrap .navbar-expand-md .dropup .dropdown-menu {
      top: auto;
      bottom: 100%; } }
  @media (max-width: 991.98px) {
    div.bootstrap .navbar-expand-lg > .container, div.bootstrap .navbar-expand-lg > .container-fluid {
      padding-right: 0;
      padding-left: 0; } }
  @media (min-width: 992px) {
    div.bootstrap .navbar-expand-lg {
      -webkit-box-orient: horizontal;
      -webkit-box-direction: normal;
      -ms-flex-flow: row nowrap;
      flex-flow: row nowrap;
      -webkit-box-pack: start;
      -ms-flex-pack: start;
      justify-content: flex-start; }
    div.bootstrap .navbar-expand-lg .navbar-nav {
      -webkit-box-orient: horizontal;
      -webkit-box-direction: normal;
      -ms-flex-direction: row;
      flex-direction: row; }
    div.bootstrap .navbar-expand-lg .navbar-nav .dropdown-menu {
      position: absolute; }
    div.bootstrap .navbar-expand-lg .navbar-nav .dropdown-menu-right {
      right: 0;
      left: auto; }
    div.bootstrap .navbar-expand-lg .navbar-nav .nav-link {
      padding-right: .5rem;
      padding-left: .5rem; }
    div.bootstrap .navbar-expand-lg > .container, div.bootstrap .navbar-expand-lg > .container-fluid {
      -ms-flex-wrap: nowrap;
      flex-wrap: nowrap; }
    div.bootstrap .navbar-expand-lg .navbar-collapse {
      display: -webkit-box !important;
      display: -ms-flexbox !important;
      display: flex !important;
      -ms-flex-preferred-size: auto;
      flex-basis: auto; }
    div.bootstrap .navbar-expand-lg .navbar-toggler {
      display: none; }
    div.bootstrap .navbar-expand-lg .dropup .dropdown-menu {
      top: auto;
      bottom: 100%; } }
  @media (max-width: 1199.98px) {
    div.bootstrap .navbar-expand-xl > .container, div.bootstrap .navbar-expand-xl > .container-fluid {
      padding-right: 0;
      padding-left: 0; } }
  @media (min-width: 1200px) {
    div.bootstrap .navbar-expand-xl {
      -webkit-box-orient: horizontal;
      -webkit-box-direction: normal;
      -ms-flex-flow: row nowrap;
      flex-flow: row nowrap;
      -webkit-box-pack: start;
      -ms-flex-pack: start;
      justify-content: flex-start; }
    div.bootstrap .navbar-expand-xl .navbar-nav {
      -webkit-box-orient: horizontal;
      -webkit-box-direction: normal;
      -ms-flex-direction: row;
      flex-direction: row; }
    div.bootstrap .navbar-expand-xl .navbar-nav .dropdown-menu {
      position: absolute; }
    div.bootstrap .navbar-expand-xl .navbar-nav .dropdown-menu-right {
      right: 0;
      left: auto; }
    div.bootstrap .navbar-expand-xl .navbar-nav .nav-link {
      padding-right: .5rem;
      padding-left: .5rem; }
    div.bootstrap .navbar-expand-xl > .container, div.bootstrap .navbar-expand-xl > .container-fluid {
      -ms-flex-wrap: nowrap;
      flex-wrap: nowrap; }
    div.bootstrap .navbar-expand-xl .navbar-collapse {
      display: -webkit-box !important;
      display: -ms-flexbox !important;
      display: flex !important;
      -ms-flex-preferred-size: auto;
      flex-basis: auto; }
    div.bootstrap .navbar-expand-xl .navbar-toggler {
      display: none; }
    div.bootstrap .navbar-expand-xl .dropup .dropdown-menu {
      top: auto;
      bottom: 100%; } }
  div.bootstrap .navbar-expand {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -ms-flex-flow: row nowrap;
    flex-flow: row nowrap;
    -webkit-box-pack: start;
    -ms-flex-pack: start;
    justify-content: flex-start; }
  div.bootstrap .navbar-expand > .container, div.bootstrap .navbar-expand > .container-fluid {
    padding-right: 0;
    padding-left: 0; }
  div.bootstrap .navbar-expand .navbar-nav {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -ms-flex-direction: row;
    flex-direction: row; }
  div.bootstrap .navbar-expand .navbar-nav .dropdown-menu {
    position: absolute; }
  div.bootstrap .navbar-expand .navbar-nav .dropdown-menu-right {
    right: 0;
    left: auto; }
  div.bootstrap .navbar-expand .navbar-nav .nav-link {
    padding-right: .5rem;
    padding-left: .5rem; }
  div.bootstrap .navbar-expand > .container, div.bootstrap .navbar-expand > .container-fluid {
    -ms-flex-wrap: nowrap;
    flex-wrap: nowrap; }
  div.bootstrap .navbar-expand .navbar-collapse {
    display: -webkit-box !important;
    display: -ms-flexbox !important;
    display: flex !important;
    -ms-flex-preferred-size: auto;
    flex-basis: auto; }
  div.bootstrap .navbar-expand .navbar-toggler {
    display: none; }
  div.bootstrap .navbar-expand .dropup .dropdown-menu {
    top: auto;
    bottom: 100%; }
  div.bootstrap .navbar-light .navbar-brand {
    color: rgba(0, 0, 0, 0.9); }
  div.bootstrap .navbar-light .navbar-brand:focus, div.bootstrap .navbar-light .navbar-brand:hover {
    color: rgba(0, 0, 0, 0.9); }
  div.bootstrap .navbar-light .navbar-nav .nav-link {
    color: rgba(0, 0, 0, 0.5); }
  div.bootstrap .navbar-light .navbar-nav .nav-link:focus, div.bootstrap .navbar-light .navbar-nav .nav-link:hover {
    color: rgba(0, 0, 0, 0.7); }
  div.bootstrap .navbar-light .navbar-nav .nav-link.disabled {
    color: rgba(0, 0, 0, 0.3); }
  div.bootstrap .navbar-light .navbar-nav .active > .nav-link, div.bootstrap .navbar-light .navbar-nav .nav-link.active, div.bootstrap .navbar-light .navbar-nav .nav-link.show, div.bootstrap .navbar-light .navbar-nav .show > .nav-link {
    color: rgba(0, 0, 0, 0.9); }
  div.bootstrap .navbar-light .navbar-toggler {
    color: rgba(0, 0, 0, 0.5);
    border-color: rgba(0, 0, 0, 0.1); }
  div.bootstrap .navbar-light .navbar-toggler-icon {
    background-image: url("data:image/svg+xml;charset=utf8,%3Csvg viewBox='0 0 30 30' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath stroke='rgba(0, 0, 0, 0.5)' stroke-width='2' stroke-linecap='round' stroke-miterlimit='10' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E"); }
  div.bootstrap .navbar-light .navbar-text {
    color: rgba(0, 0, 0, 0.5); }
  div.bootstrap .navbar-light .navbar-text a {
    color: rgba(0, 0, 0, 0.9); }
  div.bootstrap .navbar-light .navbar-text a:focus, div.bootstrap .navbar-light .navbar-text a:hover {
    color: rgba(0, 0, 0, 0.9); }
  div.bootstrap .navbar-dark .navbar-brand {
    color: #fff; }
  div.bootstrap .navbar-dark .navbar-brand:focus, div.bootstrap .navbar-dark .navbar-brand:hover {
    color: #fff; }
  div.bootstrap .navbar-dark .navbar-nav .nav-link {
    color: rgba(255, 255, 255, 0.5); }
  div.bootstrap .navbar-dark .navbar-nav .nav-link:focus, div.bootstrap .navbar-dark .navbar-nav .nav-link:hover {
    color: rgba(255, 255, 255, 0.75); }
  div.bootstrap .navbar-dark .navbar-nav .nav-link.disabled {
    color: rgba(255, 255, 255, 0.25); }
  div.bootstrap .navbar-dark .navbar-nav .active > .nav-link, div.bootstrap .navbar-dark .navbar-nav .nav-link.active, div.bootstrap .navbar-dark .navbar-nav .nav-link.show, div.bootstrap .navbar-dark .navbar-nav .show > .nav-link {
    color: #fff; }
  div.bootstrap .navbar-dark .navbar-toggler {
    color: rgba(255, 255, 255, 0.5);
    border-color: rgba(255, 255, 255, 0.1); }
  div.bootstrap .navbar-dark .navbar-toggler-icon {
    background-image: url("data:image/svg+xml;charset=utf8,%3Csvg viewBox='0 0 30 30' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath stroke='rgba(255, 255, 255, 0.5)' stroke-width='2' stroke-linecap='round' stroke-miterlimit='10' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E"); }
  div.bootstrap .navbar-dark .navbar-text {
    color: rgba(255, 255, 255, 0.5); }
  div.bootstrap .navbar-dark .navbar-text a {
    color: #fff; }
  div.bootstrap .navbar-dark .navbar-text a:focus, div.bootstrap .navbar-dark .navbar-text a:hover {
    color: #fff; }
  div.bootstrap .card {
    position: relative;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column;
    min-width: 0;
    word-wrap: break-word;
    background-color: #fff;
    background-clip: border-box;
    border: 1px solid rgba(0, 0, 0, 0.125);
    border-radius: .25rem; }
  div.bootstrap .card > hr {
    margin-right: 0;
    margin-left: 0; }
  div.bootstrap .card > .list-group:first-child .list-group-item:first-child {
    border-top-left-radius: .25rem;
    border-top-right-radius: .25rem; }
  div.bootstrap .card > .list-group:last-child .list-group-item:last-child {
    border-bottom-right-radius: .25rem;
    border-bottom-left-radius: .25rem; }
  div.bootstrap .card-body {
    -webkit-box-flex: 1;
    -ms-flex: 1 1 auto;
    flex: 1 1 auto;
    padding: 1.25rem; }
  div.bootstrap .card-title {
    margin-bottom: .75rem; }
  div.bootstrap .card-subtitle {
    margin-top: -.375rem;
    margin-bottom: 0; }
  div.bootstrap .card-text:last-child {
    margin-bottom: 0; }
  div.bootstrap .card-link:hover {
    text-decoration: none; }
  div.bootstrap .card-link + .card-link {
    margin-left: 1.25rem; }
  div.bootstrap .card-header {
    padding: .75rem 1.25rem;
    margin-bottom: 0;
    background-color: rgba(0, 0, 0, 0.03);
    border-bottom: 1px solid rgba(0, 0, 0, 0.125); }
  div.bootstrap .card-header:first-child {
    border-radius: calc(.25rem - 1px) calc(.25rem - 1px) 0 0; }
  div.bootstrap .card-header + .list-group .list-group-item:first-child {
    border-top: 0; }
  div.bootstrap .card-footer {
    padding: .75rem 1.25rem;
    background-color: rgba(0, 0, 0, 0.03);
    border-top: 1px solid rgba(0, 0, 0, 0.125); }
  div.bootstrap .card-footer:last-child {
    border-radius: 0 0 calc(.25rem - 1px) calc(.25rem - 1px); }
  div.bootstrap .card-header-tabs {
    margin-right: -.625rem;
    margin-bottom: -.75rem;
    margin-left: -.625rem;
    border-bottom: 0; }
  div.bootstrap .card-header-pills {
    margin-right: -.625rem;
    margin-left: -.625rem; }
  div.bootstrap .card-img-overlay {
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    padding: 1.25rem; }
  div.bootstrap .card-img {
    width: 100%;
    border-radius: calc(.25rem - 1px); }
  div.bootstrap .card-img-top {
    width: 100%;
    border-top-left-radius: calc(.25rem - 1px);
    border-top-right-radius: calc(.25rem - 1px); }
  div.bootstrap .card-img-bottom {
    width: 100%;
    border-bottom-right-radius: calc(.25rem - 1px);
    border-bottom-left-radius: calc(.25rem - 1px); }
  div.bootstrap .card-deck {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column; }
  div.bootstrap .card-deck .card {
    margin-bottom: 15px; }
  @media (min-width: 576px) {
    div.bootstrap .card-deck {
      -webkit-box-orient: horizontal;
      -webkit-box-direction: normal;
      -ms-flex-flow: row wrap;
      flex-flow: row wrap;
      margin-right: -15px;
      margin-left: -15px; }
    div.bootstrap .card-deck .card {
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-flex: 1;
      -ms-flex: 1 0 0%;
      flex: 1 0 0%;
      -webkit-box-orient: vertical;
      -webkit-box-direction: normal;
      -ms-flex-direction: column;
      flex-direction: column;
      margin-right: 15px;
      margin-bottom: 0;
      margin-left: 15px; } }
  div.bootstrap .card-group {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column; }
  div.bootstrap .card-group > .card {
    margin-bottom: 15px; }
  @media (min-width: 576px) {
    div.bootstrap .card-group {
      -webkit-box-orient: horizontal;
      -webkit-box-direction: normal;
      -ms-flex-flow: row wrap;
      flex-flow: row wrap; }
    div.bootstrap .card-group > .card {
      -webkit-box-flex: 1;
      -ms-flex: 1 0 0%;
      flex: 1 0 0%;
      margin-bottom: 0; }
    div.bootstrap .card-group > .card + .card {
      margin-left: 0;
      border-left: 0; }
    div.bootstrap .card-group > .card:first-child {
      border-top-right-radius: 0;
      border-bottom-right-radius: 0; }
    div.bootstrap .card-group > .card:first-child .card-header, div.bootstrap .card-group > .card:first-child .card-img-top {
      border-top-right-radius: 0; }
    div.bootstrap .card-group > .card:first-child .card-footer, div.bootstrap .card-group > .card:first-child .card-img-bottom {
      border-bottom-right-radius: 0; }
    div.bootstrap .card-group > .card:last-child {
      border-top-left-radius: 0;
      border-bottom-left-radius: 0; }
    div.bootstrap .card-group > .card:last-child .card-header, div.bootstrap .card-group > .card:last-child .card-img-top {
      border-top-left-radius: 0; }
    div.bootstrap .card-group > .card:last-child .card-footer, div.bootstrap .card-group > .card:last-child .card-img-bottom {
      border-bottom-left-radius: 0; }
    div.bootstrap .card-group > .card:only-child {
      border-radius: .25rem; }
    div.bootstrap .card-group > .card:only-child .card-header, div.bootstrap .card-group > .card:only-child .card-img-top {
      border-top-left-radius: .25rem;
      border-top-right-radius: .25rem; }
    div.bootstrap .card-group > .card:only-child .card-footer, div.bootstrap .card-group > .card:only-child .card-img-bottom {
      border-bottom-right-radius: .25rem;
      border-bottom-left-radius: .25rem; }
    div.bootstrap .card-group > .card:not(:first-child):not(:last-child):not(:only-child) {
      border-radius: 0; }
    div.bootstrap .card-group > .card:not(:first-child):not(:last-child):not(:only-child) .card-footer, div.bootstrap .card-group > .card:not(:first-child):not(:last-child):not(:only-child) .card-header, div.bootstrap .card-group > .card:not(:first-child):not(:last-child):not(:only-child) .card-img-bottom, div.bootstrap .card-group > .card:not(:first-child):not(:last-child):not(:only-child) .card-img-top {
      border-radius: 0; } }
  div.bootstrap .card-columns .card {
    margin-bottom: .75rem; }
  @media (min-width: 576px) {
    div.bootstrap .card-columns {
      -webkit-column-count: 3;
      -moz-column-count: 3;
      column-count: 3;
      -webkit-column-gap: 1.25rem;
      -moz-column-gap: 1.25rem;
      column-gap: 1.25rem; }
    div.bootstrap .card-columns .card {
      display: inline-block;
      width: 100%; } }
  div.bootstrap .breadcrumb {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    padding: .75rem 1rem;
    margin-bottom: 1rem;
    list-style: none;
    background-color: #e9ecef;
    border-radius: .25rem; }
  div.bootstrap .breadcrumb-item + .breadcrumb-item::before {
    display: inline-block;
    padding-right: .5rem;
    padding-left: .5rem;
    color: #6c757d;
    content: "/"; }
  div.bootstrap .breadcrumb-item + .breadcrumb-item:hover::before {
    text-decoration: underline; }
  div.bootstrap .breadcrumb-item + .breadcrumb-item:hover::before {
    text-decoration: none; }
  div.bootstrap .breadcrumb-item.active {
    color: #6c757d; }
  div.bootstrap .pagination {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    padding-left: 0;
    list-style: none;
    border-radius: .25rem; }
  div.bootstrap .page-link {
    position: relative;
    display: block;
    padding: .5rem .75rem;
    margin-left: -1px;
    line-height: 1.25;
    color: #007bff;
    background-color: #fff;
    border: 1px solid #dee2e6; }
  div.bootstrap .page-link:hover {
    color: #0056b3;
    text-decoration: none;
    background-color: #e9ecef;
    border-color: #dee2e6; }
  div.bootstrap .page-link:focus {
    z-index: 2;
    outline: 0;
    box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25); }
  div.bootstrap .page-link:not(:disabled):not(.disabled) {
    cursor: pointer; }
  div.bootstrap .page-item:first-child .page-link {
    margin-left: 0;
    border-top-left-radius: .25rem;
    border-bottom-left-radius: .25rem; }
  div.bootstrap .page-item:last-child .page-link {
    border-top-right-radius: .25rem;
    border-bottom-right-radius: .25rem; }
  div.bootstrap .page-item.active .page-link {
    z-index: 1;
    color: #fff;
    background-color: #007bff;
    border-color: #007bff; }
  div.bootstrap .page-item.disabled .page-link {
    color: #6c757d;
    pointer-events: none;
    cursor: auto;
    background-color: #fff;
    border-color: #dee2e6; }
  div.bootstrap .pagination-lg .page-link {
    padding: .75rem 1.5rem;
    font-size: 1.25rem;
    line-height: 1.5; }
  div.bootstrap .pagination-lg .page-item:first-child .page-link {
    border-top-left-radius: .3rem;
    border-bottom-left-radius: .3rem; }
  div.bootstrap .pagination-lg .page-item:last-child .page-link {
    border-top-right-radius: .3rem;
    border-bottom-right-radius: .3rem; }
  div.bootstrap .pagination-sm .page-link {
    padding: .25rem .5rem;
    font-size: .875rem;
    line-height: 1.5; }
  div.bootstrap .pagination-sm .page-item:first-child .page-link {
    border-top-left-radius: .2rem;
    border-bottom-left-radius: .2rem; }
  div.bootstrap .pagination-sm .page-item:last-child .page-link {
    border-top-right-radius: .2rem;
    border-bottom-right-radius: .2rem; }
  div.bootstrap .badge {
    display: inline-block;
    padding: .25em .4em;
    font-size: 75%;
    font-weight: 700;
    line-height: 1;
    text-align: center;
    white-space: nowrap;
    vertical-align: baseline;
    border-radius: .25rem; }
  div.bootstrap .badge:empty {
    display: none; }
  div.bootstrap .btn .badge {
    position: relative;
    top: -1px; }
  div.bootstrap .badge-pill {
    padding-right: .6em;
    padding-left: .6em;
    border-radius: 10rem; }
  div.bootstrap .badge-primary {
    color: #fff;
    background-color: #007bff; }
  div.bootstrap .badge-primary[href]:focus, div.bootstrap .badge-primary[href]:hover {
    color: #fff;
    text-decoration: none;
    background-color: #0062cc; }
  div.bootstrap .badge-secondary {
    color: #fff;
    background-color: #6c757d; }
  div.bootstrap .badge-secondary[href]:focus, div.bootstrap .badge-secondary[href]:hover {
    color: #fff;
    text-decoration: none;
    background-color: #545b62; }
  div.bootstrap .badge-success {
    color: #fff;
    background-color: #28a745; }
  div.bootstrap .badge-success[href]:focus, div.bootstrap .badge-success[href]:hover {
    color: #fff;
    text-decoration: none;
    background-color: #1e7e34; }
  div.bootstrap .badge-info {
    color: #fff;
    background-color: #17a2b8; }
  div.bootstrap .badge-info[href]:focus, div.bootstrap .badge-info[href]:hover {
    color: #fff;
    text-decoration: none;
    background-color: #117a8b; }
  div.bootstrap .badge-warning {
    color: #212529;
    background-color: #ffc107; }
  div.bootstrap .badge-warning[href]:focus, div.bootstrap .badge-warning[href]:hover {
    color: #212529;
    text-decoration: none;
    background-color: #d39e00; }
  div.bootstrap .badge-danger {
    color: #fff;
    background-color: #dc3545; }
  div.bootstrap .badge-danger[href]:focus, div.bootstrap .badge-danger[href]:hover {
    color: #fff;
    text-decoration: none;
    background-color: #bd2130; }
  div.bootstrap .badge-light {
    color: #212529;
    background-color: #f8f9fa; }
  div.bootstrap .badge-light[href]:focus, div.bootstrap .badge-light[href]:hover {
    color: #212529;
    text-decoration: none;
    background-color: #dae0e5; }
  div.bootstrap .badge-dark {
    color: #fff;
    background-color: #343a40; }
  div.bootstrap .badge-dark[href]:focus, div.bootstrap .badge-dark[href]:hover {
    color: #fff;
    text-decoration: none;
    background-color: #1d2124; }
  div.bootstrap .jumbotron {
    padding: 2rem 1rem;
    margin-bottom: 2rem;
    background-color: #e9ecef;
    border-radius: .3rem; }
  @media (min-width: 576px) {
    div.bootstrap .jumbotron {
      padding: 4rem 2rem; } }
  div.bootstrap .jumbotron-fluid {
    padding-right: 0;
    padding-left: 0;
    border-radius: 0; }
  div.bootstrap .alert {
    position: relative;
    padding: .75rem 1.25rem;
    margin-bottom: 1rem;
    border: 1px solid transparent;
    border-radius: .25rem; }
  div.bootstrap .alert-heading {
    color: inherit; }
  div.bootstrap .alert-link {
    font-weight: 700; }
  div.bootstrap .alert-dismissible {
    padding-right: 4rem; }
  div.bootstrap .alert-dismissible .close {
    position: absolute;
    top: 0;
    right: 0;
    padding: .75rem 1.25rem;
    color: inherit; }
  div.bootstrap .alert-primary {
    color: #004085;
    background-color: #cce5ff;
    border-color: #b8daff; }
  div.bootstrap .alert-primary hr {
    border-top-color: #9fcdff; }
  div.bootstrap .alert-primary .alert-link {
    color: #002752; }
  div.bootstrap .alert-secondary {
    color: #383d41;
    background-color: #e2e3e5;
    border-color: #d6d8db; }
  div.bootstrap .alert-secondary hr {
    border-top-color: #c8cbcf; }
  div.bootstrap .alert-secondary .alert-link {
    color: #202326; }
  div.bootstrap .alert-success {
    color: #155724;
    background-color: #d4edda;
    border-color: #c3e6cb; }
  div.bootstrap .alert-success hr {
    border-top-color: #b1dfbb; }
  div.bootstrap .alert-success .alert-link {
    color: #0b2e13; }
  div.bootstrap .alert-info {
    color: #0c5460;
    background-color: #d1ecf1;
    border-color: #bee5eb; }
  div.bootstrap .alert-info hr {
    border-top-color: #abdde5; }
  div.bootstrap .alert-info .alert-link {
    color: #062c33; }
  div.bootstrap .alert-warning {
    color: #856404;
    background-color: #fff3cd;
    border-color: #ffeeba; }
  div.bootstrap .alert-warning hr {
    border-top-color: #ffe8a1; }
  div.bootstrap .alert-warning .alert-link {
    color: #533f03; }
  div.bootstrap .alert-danger {
    color: #721c24;
    background-color: #f8d7da;
    border-color: #f5c6cb; }
  div.bootstrap .alert-danger hr {
    border-top-color: #f1b0b7; }
  div.bootstrap .alert-danger .alert-link {
    color: #491217; }
  div.bootstrap .alert-light {
    color: #818182;
    background-color: #fefefe;
    border-color: #fdfdfe; }
  div.bootstrap .alert-light hr {
    border-top-color: #ececf6; }
  div.bootstrap .alert-light .alert-link {
    color: #686868; }
  div.bootstrap .alert-dark {
    color: #1b1e21;
    background-color: #d6d8d9;
    border-color: #c6c8ca; }
  div.bootstrap .alert-dark hr {
    border-top-color: #b9bbbe; }
  div.bootstrap .alert-dark .alert-link {
    color: #040505; }
@-webkit-keyframes progress-bar-stripes {
  from {
    background-position: 1rem 0; }
  to {
    background-position: 0 0; } }
@keyframes progress-bar-stripes {
  from {
    background-position: 1rem 0; }
  to {
    background-position: 0 0; } }
  div.bootstrap .progress {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    height: 1rem;
    overflow: hidden;
    font-size: .75rem;
    background-color: #e9ecef;
    border-radius: .25rem; }
  div.bootstrap .progress-bar {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center;
    color: #fff;
    text-align: center;
    background-color: #007bff;
    transition: width .6s ease; }
  div.bootstrap .progress-bar-striped {
    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-size: 1rem 1rem; }
  div.bootstrap .progress-bar-animated {
    -webkit-animation: progress-bar-stripes 1s linear infinite;
    animation: progress-bar-stripes 1s linear infinite; }
  div.bootstrap .media {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: start;
    -ms-flex-align: start;
    align-items: flex-start; }
  div.bootstrap .media-body {
    -webkit-box-flex: 1;
    -ms-flex: 1;
    flex: 1; }
  div.bootstrap .list-group {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column;
    padding-left: 0;
    margin-bottom: 0; }
  div.bootstrap .list-group-item-action {
    width: 100%;
    color: #495057;
    text-align: inherit; }
  div.bootstrap .list-group-item-action:focus, div.bootstrap .list-group-item-action:hover {
    color: #495057;
    text-decoration: none;
    background-color: #f8f9fa; }
  div.bootstrap .list-group-item-action:active {
    color: #212529;
    background-color: #e9ecef; }
  div.bootstrap .list-group-item {
    position: relative;
    display: block;
    padding: .75rem 1.25rem;
    margin-bottom: -1px;
    background-color: #fff;
    border: 1px solid rgba(0, 0, 0, 0.125); }
  div.bootstrap .list-group-item:first-child {
    border-top-left-radius: .25rem;
    border-top-right-radius: .25rem; }
  div.bootstrap .list-group-item:last-child {
    margin-bottom: 0;
    border-bottom-right-radius: .25rem;
    border-bottom-left-radius: .25rem; }
  div.bootstrap .list-group-item:focus, div.bootstrap .list-group-item:hover {
    z-index: 1;
    text-decoration: none; }
  div.bootstrap .list-group-item.disabled, div.bootstrap .list-group-item:disabled {
    color: #6c757d;
    background-color: #fff; }
  div.bootstrap .list-group-item.active {
    z-index: 2;
    color: #fff;
    background-color: #007bff;
    border-color: #007bff; }
  div.bootstrap .list-group-flush .list-group-item {
    border-right: 0;
    border-left: 0;
    border-radius: 0; }
  div.bootstrap .list-group-flush:first-child .list-group-item:first-child {
    border-top: 0; }
  div.bootstrap .list-group-flush:last-child .list-group-item:last-child {
    border-bottom: 0; }
  div.bootstrap .list-group-item-primary {
    color: #004085;
    background-color: #b8daff; }
  div.bootstrap .list-group-item-primary.list-group-item-action:focus, div.bootstrap .list-group-item-primary.list-group-item-action:hover {
    color: #004085;
    background-color: #9fcdff; }
  div.bootstrap .list-group-item-primary.list-group-item-action.active {
    color: #fff;
    background-color: #004085;
    border-color: #004085; }
  div.bootstrap .list-group-item-secondary {
    color: #383d41;
    background-color: #d6d8db; }
  div.bootstrap .list-group-item-secondary.list-group-item-action:focus, div.bootstrap .list-group-item-secondary.list-group-item-action:hover {
    color: #383d41;
    background-color: #c8cbcf; }
  div.bootstrap .list-group-item-secondary.list-group-item-action.active {
    color: #fff;
    background-color: #383d41;
    border-color: #383d41; }
  div.bootstrap .list-group-item-success {
    color: #155724;
    background-color: #c3e6cb; }
  div.bootstrap .list-group-item-success.list-group-item-action:focus, div.bootstrap .list-group-item-success.list-group-item-action:hover {
    color: #155724;
    background-color: #b1dfbb; }
  div.bootstrap .list-group-item-success.list-group-item-action.active {
    color: #fff;
    background-color: #155724;
    border-color: #155724; }
  div.bootstrap .list-group-item-info {
    color: #0c5460;
    background-color: #bee5eb; }
  div.bootstrap .list-group-item-info.list-group-item-action:focus, div.bootstrap .list-group-item-info.list-group-item-action:hover {
    color: #0c5460;
    background-color: #abdde5; }
  div.bootstrap .list-group-item-info.list-group-item-action.active {
    color: #fff;
    background-color: #0c5460;
    border-color: #0c5460; }
  div.bootstrap .list-group-item-warning {
    color: #856404;
    background-color: #ffeeba; }
  div.bootstrap .list-group-item-warning.list-group-item-action:focus, div.bootstrap .list-group-item-warning.list-group-item-action:hover {
    color: #856404;
    background-color: #ffe8a1; }
  div.bootstrap .list-group-item-warning.list-group-item-action.active {
    color: #fff;
    background-color: #856404;
    border-color: #856404; }
  div.bootstrap .list-group-item-danger {
    color: #721c24;
    background-color: #f5c6cb; }
  div.bootstrap .list-group-item-danger.list-group-item-action:focus, div.bootstrap .list-group-item-danger.list-group-item-action:hover {
    color: #721c24;
    background-color: #f1b0b7; }
  div.bootstrap .list-group-item-danger.list-group-item-action.active {
    color: #fff;
    background-color: #721c24;
    border-color: #721c24; }
  div.bootstrap .list-group-item-light {
    color: #818182;
    background-color: #fdfdfe; }
  div.bootstrap .list-group-item-light.list-group-item-action:focus, div.bootstrap .list-group-item-light.list-group-item-action:hover {
    color: #818182;
    background-color: #ececf6; }
  div.bootstrap .list-group-item-light.list-group-item-action.active {
    color: #fff;
    background-color: #818182;
    border-color: #818182; }
  div.bootstrap .list-group-item-dark {
    color: #1b1e21;
    background-color: #c6c8ca; }
  div.bootstrap .list-group-item-dark.list-group-item-action:focus, div.bootstrap .list-group-item-dark.list-group-item-action:hover {
    color: #1b1e21;
    background-color: #b9bbbe; }
  div.bootstrap .list-group-item-dark.list-group-item-action.active {
    color: #fff;
    background-color: #1b1e21;
    border-color: #1b1e21; }
  div.bootstrap .close {
    float: right;
    font-size: 1.5rem;
    font-weight: 700;
    line-height: 1;
    color: #000;
    text-shadow: 0 1px 0 #fff;
    opacity: .5; }
  div.bootstrap .close:focus, div.bootstrap .close:hover {
    color: #000;
    text-decoration: none;
    opacity: .75; }
  div.bootstrap .close:not(:disabled):not(.disabled) {
    cursor: pointer; }
  div.bootstrap button.close {
    padding: 0;
    background-color: transparent;
    border: 0;
    -webkit-appearance: none; }
  div.bootstrap .modal-open {
    overflow: hidden; }
  div.bootstrap .modal {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1050;
    display: none;
    overflow: hidden;
    outline: 0; }
  div.bootstrap .modal-open .modal {
    overflow-x: hidden;
    overflow-y: auto; }
  div.bootstrap .modal-dialog {
    position: relative;
    width: auto;
    margin: .5rem;
    pointer-events: none; }
  div.bootstrap .modal.fade .modal-dialog {
    transition: -webkit-transform .3s ease-out;
    transition: transform .3s ease-out;
    transition: transform .3s ease-out,-webkit-transform .3s ease-out;
    -webkit-transform: translate(0, -25%);
    transform: translate(0, -25%); }
  div.bootstrap .modal.show .modal-dialog {
    -webkit-transform: translate(0, 0);
    transform: translate(0, 0); }
  div.bootstrap .modal-dialog-centered {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    min-height: calc(100% - (.5rem * 2)); }
  div.bootstrap .modal-content {
    position: relative;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column;
    width: 100%;
    pointer-events: auto;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid rgba(0, 0, 0, 0.2);
    border-radius: .3rem;
    outline: 0; }
  div.bootstrap .modal-backdrop {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1040;
    background-color: #000; }
  div.bootstrap .modal-backdrop.fade {
    opacity: 0; }
  div.bootstrap .modal-backdrop.show {
    opacity: .5; }
  div.bootstrap .modal-header {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: start;
    -ms-flex-align: start;
    align-items: flex-start;
    -webkit-box-pack: justify;
    -ms-flex-pack: justify;
    justify-content: space-between;
    padding: 1rem;
    border-bottom: 1px solid #e9ecef;
    border-top-left-radius: .3rem;
    border-top-right-radius: .3rem; }
  div.bootstrap .modal-header .close {
    padding: 1rem;
    margin: -1rem -1rem -1rem auto; }
  div.bootstrap .modal-title {
    margin-bottom: 0;
    line-height: 1.5; }
  div.bootstrap .modal-body {
    position: relative;
    -webkit-box-flex: 1;
    -ms-flex: 1 1 auto;
    flex: 1 1 auto;
    padding: 1rem; }
  div.bootstrap .modal-footer {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    -webkit-box-pack: end;
    -ms-flex-pack: end;
    justify-content: flex-end;
    padding: 1rem;
    border-top: 1px solid #e9ecef; }
  div.bootstrap .modal-footer > :not(:first-child) {
    margin-left: .25rem; }
  div.bootstrap .modal-footer > :not(:last-child) {
    margin-right: .25rem; }
  div.bootstrap .modal-scrollbar-measure {
    position: absolute;
    top: -9999px;
    width: 50px;
    height: 50px;
    overflow: scroll; }
  @media (min-width: 576px) {
    div.bootstrap .modal-dialog {
      max-width: 500px;
      margin: 1.75rem auto; }
    div.bootstrap .modal-dialog-centered {
      min-height: calc(100% - (1.75rem * 2)); }
    div.bootstrap .modal-sm {
      max-width: 300px; } }
  @media (min-width: 992px) {
    div.bootstrap .modal-lg {
      max-width: 800px; } }
  div.bootstrap .tooltip {
    position: absolute;
    z-index: 1070;
    display: block;
    margin: 0;
    font-family: -apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,"Helvetica Neue",Arial,sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol";
    font-style: normal;
    font-weight: 400;
    line-height: 1.5;
    text-align: left;
    text-align: start;
    text-decoration: none;
    text-shadow: none;
    text-transform: none;
    letter-spacing: normal;
    word-break: normal;
    word-spacing: normal;
    white-space: normal;
    line-break: auto;
    font-size: .875rem;
    word-wrap: break-word;
    opacity: 0; }
  div.bootstrap .tooltip.show {
    opacity: .9; }
  div.bootstrap .tooltip .arrow {
    position: absolute;
    display: block;
    width: .8rem;
    height: .4rem; }
  div.bootstrap .tooltip .arrow::before {
    position: absolute;
    content: "";
    border-color: transparent;
    border-style: solid; }
  div.bootstrap .bs-tooltip-auto[x-placement^=top], div.bootstrap .bs-tooltip-top {
    padding: .4rem 0; }
  div.bootstrap .bs-tooltip-auto[x-placement^=top] .arrow, div.bootstrap .bs-tooltip-top .arrow {
    bottom: 0; }
  div.bootstrap .bs-tooltip-auto[x-placement^=top] .arrow::before, div.bootstrap .bs-tooltip-top .arrow::before {
    top: 0;
    border-width: .4rem .4rem 0;
    border-top-color: #000; }
  div.bootstrap .bs-tooltip-auto[x-placement^=right], div.bootstrap .bs-tooltip-right {
    padding: 0 .4rem; }
  div.bootstrap .bs-tooltip-auto[x-placement^=right] .arrow, div.bootstrap .bs-tooltip-right .arrow {
    left: 0;
    width: .4rem;
    height: .8rem; }
  div.bootstrap .bs-tooltip-auto[x-placement^=right] .arrow::before, div.bootstrap .bs-tooltip-right .arrow::before {
    right: 0;
    border-width: .4rem .4rem .4rem 0;
    border-right-color: #000; }
  div.bootstrap .bs-tooltip-auto[x-placement^=bottom], div.bootstrap .bs-tooltip-bottom {
    padding: .4rem 0; }
  div.bootstrap .bs-tooltip-auto[x-placement^=bottom] .arrow, div.bootstrap .bs-tooltip-bottom .arrow {
    top: 0; }
  div.bootstrap .bs-tooltip-auto[x-placement^=bottom] .arrow::before, div.bootstrap .bs-tooltip-bottom .arrow::before {
    bottom: 0;
    border-width: 0 .4rem .4rem;
    border-bottom-color: #000; }
  div.bootstrap .bs-tooltip-auto[x-placement^=left], div.bootstrap .bs-tooltip-left {
    padding: 0 .4rem; }
  div.bootstrap .bs-tooltip-auto[x-placement^=left] .arrow, div.bootstrap .bs-tooltip-left .arrow {
    right: 0;
    width: .4rem;
    height: .8rem; }
  div.bootstrap .bs-tooltip-auto[x-placement^=left] .arrow::before, div.bootstrap .bs-tooltip-left .arrow::before {
    left: 0;
    border-width: .4rem 0 .4rem .4rem;
    border-left-color: #000; }
  div.bootstrap .tooltip-inner {
    max-width: 200px;
    padding: .25rem .5rem;
    color: #fff;
    text-align: center;
    background-color: #000;
    border-radius: .25rem; }
  div.bootstrap .popover {
    position: absolute;
    top: 0;
    left: 0;
    z-index: 1060;
    display: block;
    max-width: 276px;
    font-family: -apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,"Helvetica Neue",Arial,sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol";
    font-style: normal;
    font-weight: 400;
    line-height: 1.5;
    text-align: left;
    text-align: start;
    text-decoration: none;
    text-shadow: none;
    text-transform: none;
    letter-spacing: normal;
    word-break: normal;
    word-spacing: normal;
    white-space: normal;
    line-break: auto;
    font-size: .875rem;
    word-wrap: break-word;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid rgba(0, 0, 0, 0.2);
    border-radius: .3rem; }
  div.bootstrap .popover .arrow {
    position: absolute;
    display: block;
    width: 1rem;
    height: .5rem;
    margin: 0 .3rem; }
  div.bootstrap .popover .arrow::after, div.bootstrap .popover .arrow::before {
    position: absolute;
    display: block;
    content: "";
    border-color: transparent;
    border-style: solid; }
  div.bootstrap .bs-popover-auto[x-placement^=top], div.bootstrap .bs-popover-top {
    margin-bottom: .5rem; }
  div.bootstrap .bs-popover-auto[x-placement^=top] .arrow, div.bootstrap .bs-popover-top .arrow {
    bottom: calc((.5rem + 1px) * -1); }
  div.bootstrap .bs-popover-auto[x-placement^=top] .arrow::after, div.bootstrap .bs-popover-auto[x-placement^=top] .arrow::before, div.bootstrap .bs-popover-top .arrow::after, div.bootstrap .bs-popover-top .arrow::before {
    border-width: .5rem .5rem 0; }
  div.bootstrap .bs-popover-auto[x-placement^=top] .arrow::before, div.bootstrap .bs-popover-top .arrow::before {
    bottom: 0;
    border-top-color: rgba(0, 0, 0, 0.25); }
  div.bootstrap .bs-popover-auto[x-placement^=top] .arrow::after, div.bootstrap .bs-popover-top .arrow::after {
    bottom: 1px;
    border-top-color: #fff; }
  div.bootstrap .bs-popover-auto[x-placement^=right], div.bootstrap .bs-popover-right {
    margin-left: .5rem; }
  div.bootstrap .bs-popover-auto[x-placement^=right] .arrow, div.bootstrap .bs-popover-right .arrow {
    left: calc((.5rem + 1px) * -1);
    width: .5rem;
    height: 1rem;
    margin: .3rem 0; }
  div.bootstrap .bs-popover-auto[x-placement^=right] .arrow::after, div.bootstrap .bs-popover-auto[x-placement^=right] .arrow::before, div.bootstrap .bs-popover-right .arrow::after, div.bootstrap .bs-popover-right .arrow::before {
    border-width: .5rem .5rem .5rem 0; }
  div.bootstrap .bs-popover-auto[x-placement^=right] .arrow::before, div.bootstrap .bs-popover-right .arrow::before {
    left: 0;
    border-right-color: rgba(0, 0, 0, 0.25); }
  div.bootstrap .bs-popover-auto[x-placement^=right] .arrow::after, div.bootstrap .bs-popover-right .arrow::after {
    left: 1px;
    border-right-color: #fff; }
  div.bootstrap .bs-popover-auto[x-placement^=bottom], div.bootstrap .bs-popover-bottom {
    margin-top: .5rem; }
  div.bootstrap .bs-popover-auto[x-placement^=bottom] .arrow, div.bootstrap .bs-popover-bottom .arrow {
    top: calc((.5rem + 1px) * -1); }
  div.bootstrap .bs-popover-auto[x-placement^=bottom] .arrow::after, div.bootstrap .bs-popover-auto[x-placement^=bottom] .arrow::before, div.bootstrap .bs-popover-bottom .arrow::after, div.bootstrap .bs-popover-bottom .arrow::before {
    border-width: 0 .5rem .5rem .5rem; }
  div.bootstrap .bs-popover-auto[x-placement^=bottom] .arrow::before, div.bootstrap .bs-popover-bottom .arrow::before {
    top: 0;
    border-bottom-color: rgba(0, 0, 0, 0.25); }
  div.bootstrap .bs-popover-auto[x-placement^=bottom] .arrow::after, div.bootstrap .bs-popover-bottom .arrow::after {
    top: 1px;
    border-bottom-color: #fff; }
  div.bootstrap .bs-popover-auto[x-placement^=bottom] .popover-header::before, div.bootstrap .bs-popover-bottom .popover-header::before {
    position: absolute;
    top: 0;
    left: 50%;
    display: block;
    width: 1rem;
    margin-left: -.5rem;
    content: "";
    border-bottom: 1px solid #f7f7f7; }
  div.bootstrap .bs-popover-auto[x-placement^=left], div.bootstrap .bs-popover-left {
    margin-right: .5rem; }
  div.bootstrap .bs-popover-auto[x-placement^=left] .arrow, div.bootstrap .bs-popover-left .arrow {
    right: calc((.5rem + 1px) * -1);
    width: .5rem;
    height: 1rem;
    margin: .3rem 0; }
  div.bootstrap .bs-popover-auto[x-placement^=left] .arrow::after, div.bootstrap .bs-popover-auto[x-placement^=left] .arrow::before, div.bootstrap .bs-popover-left .arrow::after, div.bootstrap .bs-popover-left .arrow::before {
    border-width: .5rem 0 .5rem .5rem; }
  div.bootstrap .bs-popover-auto[x-placement^=left] .arrow::before, div.bootstrap .bs-popover-left .arrow::before {
    right: 0;
    border-left-color: rgba(0, 0, 0, 0.25); }
  div.bootstrap .bs-popover-auto[x-placement^=left] .arrow::after, div.bootstrap .bs-popover-left .arrow::after {
    right: 1px;
    border-left-color: #fff; }
  div.bootstrap .popover-header {
    padding: .5rem .75rem;
    margin-bottom: 0;
    font-size: 1rem;
    color: inherit;
    background-color: #f7f7f7;
    border-bottom: 1px solid #ebebeb;
    border-top-left-radius: calc(.3rem - 1px);
    border-top-right-radius: calc(.3rem - 1px); }
  div.bootstrap .popover-header:empty {
    display: none; }
  div.bootstrap .popover-body {
    padding: .5rem .75rem;
    color: #212529; }
  div.bootstrap .carousel {
    position: relative; }
  div.bootstrap .carousel-inner {
    position: relative;
    width: 100%;
    overflow: hidden; }
  div.bootstrap .carousel-item {
    position: relative;
    display: none;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    width: 100%;
    transition: -webkit-transform .6s ease;
    transition: transform .6s ease;
    transition: transform .6s ease,-webkit-transform .6s ease;
    -webkit-backface-visibility: hidden;
    backface-visibility: hidden;
    -webkit-perspective: 1000px;
    perspective: 1000px; }
  div.bootstrap .carousel-item-next, div.bootstrap .carousel-item-prev, div.bootstrap .carousel-item.active {
    display: block; }
  div.bootstrap .carousel-item-next, div.bootstrap .carousel-item-prev {
    position: absolute;
    top: 0; }
  div.bootstrap .carousel-item-next.carousel-item-left, div.bootstrap .carousel-item-prev.carousel-item-right {
    -webkit-transform: translateX(0);
    transform: translateX(0); }
  @supports (-webkit-transform-style: preserve-3d) or (transform-style: preserve-3d) {
    div.bootstrap .carousel-item-next.carousel-item-left, div.bootstrap .carousel-item-prev.carousel-item-right {
      -webkit-transform: translate3d(0, 0, 0);
      transform: translate3d(0, 0, 0); } }
  div.bootstrap .active.carousel-item-right, div.bootstrap .carousel-item-next {
    -webkit-transform: translateX(100%);
    transform: translateX(100%); }
  @supports (-webkit-transform-style: preserve-3d) or (transform-style: preserve-3d) {
    div.bootstrap .active.carousel-item-right, div.bootstrap .carousel-item-next {
      -webkit-transform: translate3d(100%, 0, 0);
      transform: translate3d(100%, 0, 0); } }
  div.bootstrap .active.carousel-item-left, div.bootstrap .carousel-item-prev {
    -webkit-transform: translateX(-100%);
    transform: translateX(-100%); }
  @supports (-webkit-transform-style: preserve-3d) or (transform-style: preserve-3d) {
    div.bootstrap .active.carousel-item-left, div.bootstrap .carousel-item-prev {
      -webkit-transform: translate3d(-100%, 0, 0);
      transform: translate3d(-100%, 0, 0); } }
  div.bootstrap .carousel-control-next, div.bootstrap .carousel-control-prev {
    position: absolute;
    top: 0;
    bottom: 0;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center;
    width: 15%;
    color: #fff;
    text-align: center;
    opacity: .5; }
  div.bootstrap .carousel-control-next:focus, div.bootstrap .carousel-control-next:hover, div.bootstrap .carousel-control-prev:focus, div.bootstrap .carousel-control-prev:hover {
    color: #fff;
    text-decoration: none;
    outline: 0;
    opacity: .9; }
  div.bootstrap .carousel-control-prev {
    left: 0; }
  div.bootstrap .carousel-control-next {
    right: 0; }
  div.bootstrap .carousel-control-next-icon, div.bootstrap .carousel-control-prev-icon {
    display: inline-block;
    width: 20px;
    height: 20px;
    background: transparent no-repeat center center;
    background-size: 100% 100%; }
  div.bootstrap .carousel-control-prev-icon {
    background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='%23fff' viewBox='0 0 8 8'%3E%3Cpath d='M5.25 0l-4 4 4 4 1.5-1.5-2.5-2.5 2.5-2.5-1.5-1.5z'/%3E%3C/svg%3E"); }
  div.bootstrap .carousel-control-next-icon {
    background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='%23fff' viewBox='0 0 8 8'%3E%3Cpath d='M2.75 0l-1.5 1.5 2.5 2.5-2.5 2.5 1.5 1.5 4-4-4-4z'/%3E%3C/svg%3E"); }
  div.bootstrap .carousel-indicators {
    position: absolute;
    right: 0;
    bottom: 10px;
    left: 0;
    z-index: 15;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center;
    padding-left: 0;
    margin-right: 15%;
    margin-left: 15%;
    list-style: none; }
  div.bootstrap .carousel-indicators li {
    position: relative;
    -webkit-box-flex: 0;
    -ms-flex: 0 1 auto;
    flex: 0 1 auto;
    width: 30px;
    height: 3px;
    margin-right: 3px;
    margin-left: 3px;
    text-indent: -999px;
    background-color: rgba(255, 255, 255, 0.5); }
  div.bootstrap .carousel-indicators li::before {
    position: absolute;
    top: -10px;
    left: 0;
    display: inline-block;
    width: 100%;
    height: 10px;
    content: ""; }
  div.bootstrap .carousel-indicators li::after {
    position: absolute;
    bottom: -10px;
    left: 0;
    display: inline-block;
    width: 100%;
    height: 10px;
    content: ""; }
  div.bootstrap .carousel-indicators .active {
    background-color: #fff; }
  div.bootstrap .carousel-caption {
    position: absolute;
    right: 15%;
    bottom: 20px;
    left: 15%;
    z-index: 10;
    padding-top: 20px;
    padding-bottom: 20px;
    color: #fff;
    text-align: center; }
  div.bootstrap .align-baseline {
    vertical-align: baseline !important; }
  div.bootstrap .align-top {
    vertical-align: top !important; }
  div.bootstrap .align-middle {
    vertical-align: middle !important; }
  div.bootstrap .align-bottom {
    vertical-align: bottom !important; }
  div.bootstrap .align-text-bottom {
    vertical-align: text-bottom !important; }
  div.bootstrap .align-text-top {
    vertical-align: text-top !important; }
  div.bootstrap .bg-primary {
    background-color: #007bff !important; }
  div.bootstrap a.bg-primary:focus, div.bootstrap a.bg-primary:hover, div.bootstrap button.bg-primary:focus, div.bootstrap button.bg-primary:hover {
    background-color: #0062cc !important; }
  div.bootstrap .bg-secondary {
    background-color: #6c757d !important; }
  div.bootstrap a.bg-secondary:focus, div.bootstrap a.bg-secondary:hover, div.bootstrap button.bg-secondary:focus, div.bootstrap button.bg-secondary:hover {
    background-color: #545b62 !important; }
  div.bootstrap .bg-success {
    background-color: #28a745 !important; }
  div.bootstrap a.bg-success:focus, div.bootstrap a.bg-success:hover, div.bootstrap button.bg-success:focus, div.bootstrap button.bg-success:hover {
    background-color: #1e7e34 !important; }
  div.bootstrap .bg-info {
    background-color: #17a2b8 !important; }
  div.bootstrap a.bg-info:focus, div.bootstrap a.bg-info:hover, div.bootstrap button.bg-info:focus, div.bootstrap button.bg-info:hover {
    background-color: #117a8b !important; }
  div.bootstrap .bg-warning {
    background-color: #ffc107 !important; }
  div.bootstrap a.bg-warning:focus, div.bootstrap a.bg-warning:hover, div.bootstrap button.bg-warning:focus, div.bootstrap button.bg-warning:hover {
    background-color: #d39e00 !important; }
  div.bootstrap .bg-danger {
    background-color: #dc3545 !important; }
  div.bootstrap a.bg-danger:focus, div.bootstrap a.bg-danger:hover, div.bootstrap button.bg-danger:focus, div.bootstrap button.bg-danger:hover {
    background-color: #bd2130 !important; }
  div.bootstrap .bg-light {
    background-color: #f8f9fa !important; }
  div.bootstrap a.bg-light:focus, div.bootstrap a.bg-light:hover, div.bootstrap button.bg-light:focus, div.bootstrap button.bg-light:hover {
    background-color: #dae0e5 !important; }
  div.bootstrap .bg-dark {
    background-color: #343a40 !important; }
  div.bootstrap a.bg-dark:focus, div.bootstrap a.bg-dark:hover, div.bootstrap button.bg-dark:focus, div.bootstrap button.bg-dark:hover {
    background-color: #1d2124 !important; }
  div.bootstrap .bg-white {
    background-color: #fff !important; }
  div.bootstrap .bg-transparent {
    background-color: transparent !important; }
  div.bootstrap .border {
    border: 1px solid #dee2e6 !important; }
  div.bootstrap .border-top {
    border-top: 1px solid #dee2e6 !important; }
  div.bootstrap .border-right {
    border-right: 1px solid #dee2e6 !important; }
  div.bootstrap .border-bottom {
    border-bottom: 1px solid #dee2e6 !important; }
  div.bootstrap .border-left {
    border-left: 1px solid #dee2e6 !important; }
  div.bootstrap .border-0 {
    border: 0 !important; }
  div.bootstrap .border-top-0 {
    border-top: 0 !important; }
  div.bootstrap .border-right-0 {
    border-right: 0 !important; }
  div.bootstrap .border-bottom-0 {
    border-bottom: 0 !important; }
  div.bootstrap .border-left-0 {
    border-left: 0 !important; }
  div.bootstrap .border-primary {
    border-color: #007bff !important; }
  div.bootstrap .border-secondary {
    border-color: #6c757d !important; }
  div.bootstrap .border-success {
    border-color: #28a745 !important; }
  div.bootstrap .border-info {
    border-color: #17a2b8 !important; }
  div.bootstrap .border-warning {
    border-color: #ffc107 !important; }
  div.bootstrap .border-danger {
    border-color: #dc3545 !important; }
  div.bootstrap .border-light {
    border-color: #f8f9fa !important; }
  div.bootstrap .border-dark {
    border-color: #343a40 !important; }
  div.bootstrap .border-white {
    border-color: #fff !important; }
  div.bootstrap .rounded {
    border-radius: 0.25rem !important; }
  div.bootstrap .rounded-top {
    border-top-left-radius: 0.25rem !important;
    border-top-right-radius: 0.25rem !important; }
  div.bootstrap .rounded-right {
    border-top-right-radius: 0.25rem !important;
    border-bottom-right-radius: 0.25rem !important; }
  div.bootstrap .rounded-bottom {
    border-bottom-right-radius: 0.25rem !important;
    border-bottom-left-radius: 0.25rem !important; }
  div.bootstrap .rounded-left {
    border-top-left-radius: 0.25rem !important;
    border-bottom-left-radius: 0.25rem !important; }
  div.bootstrap .rounded-circle {
    border-radius: 50% !important; }
  div.bootstrap .rounded-0 {
    border-radius: 0 !important; }
  div.bootstrap .clearfix::after {
    display: block;
    clear: both;
    content: ""; }
  div.bootstrap .d-none {
    display: none !important; }
  div.bootstrap .d-inline {
    display: inline !important; }
  div.bootstrap .d-inline-block {
    display: inline-block !important; }
  div.bootstrap .d-block {
    display: block !important; }
  div.bootstrap .d-table {
    display: table !important; }
  div.bootstrap .d-table-row {
    display: table-row !important; }
  div.bootstrap .d-table-cell {
    display: table-cell !important; }
  div.bootstrap .d-flex {
    display: -webkit-box !important;
    display: -ms-flexbox !important;
    display: flex !important; }
  div.bootstrap .d-inline-flex {
    display: -webkit-inline-box !important;
    display: -ms-inline-flexbox !important;
    display: inline-flex !important; }
  @media (min-width: 576px) {
    div.bootstrap .d-sm-none {
      display: none !important; }
    div.bootstrap .d-sm-inline {
      display: inline !important; }
    div.bootstrap .d-sm-inline-block {
      display: inline-block !important; }
    div.bootstrap .d-sm-block {
      display: block !important; }
    div.bootstrap .d-sm-table {
      display: table !important; }
    div.bootstrap .d-sm-table-row {
      display: table-row !important; }
    div.bootstrap .d-sm-table-cell {
      display: table-cell !important; }
    div.bootstrap .d-sm-flex {
      display: -webkit-box !important;
      display: -ms-flexbox !important;
      display: flex !important; }
    div.bootstrap .d-sm-inline-flex {
      display: -webkit-inline-box !important;
      display: -ms-inline-flexbox !important;
      display: inline-flex !important; } }
  @media (min-width: 768px) {
    div.bootstrap .d-md-none {
      display: none !important; }
    div.bootstrap .d-md-inline {
      display: inline !important; }
    div.bootstrap .d-md-inline-block {
      display: inline-block !important; }
    div.bootstrap .d-md-block {
      display: block !important; }
    div.bootstrap .d-md-table {
      display: table !important; }
    div.bootstrap .d-md-table-row {
      display: table-row !important; }
    div.bootstrap .d-md-table-cell {
      display: table-cell !important; }
    div.bootstrap .d-md-flex {
      display: -webkit-box !important;
      display: -ms-flexbox !important;
      display: flex !important; }
    div.bootstrap .d-md-inline-flex {
      display: -webkit-inline-box !important;
      display: -ms-inline-flexbox !important;
      display: inline-flex !important; } }
  @media (min-width: 992px) {
    div.bootstrap .d-lg-none {
      display: none !important; }
    div.bootstrap .d-lg-inline {
      display: inline !important; }
    div.bootstrap .d-lg-inline-block {
      display: inline-block !important; }
    div.bootstrap .d-lg-block {
      display: block !important; }
    div.bootstrap .d-lg-table {
      display: table !important; }
    div.bootstrap .d-lg-table-row {
      display: table-row !important; }
    div.bootstrap .d-lg-table-cell {
      display: table-cell !important; }
    div.bootstrap .d-lg-flex {
      display: -webkit-box !important;
      display: -ms-flexbox !important;
      display: flex !important; }
    div.bootstrap .d-lg-inline-flex {
      display: -webkit-inline-box !important;
      display: -ms-inline-flexbox !important;
      display: inline-flex !important; } }
  @media (min-width: 1200px) {
    div.bootstrap .d-xl-none {
      display: none !important; }
    div.bootstrap .d-xl-inline {
      display: inline !important; }
    div.bootstrap .d-xl-inline-block {
      display: inline-block !important; }
    div.bootstrap .d-xl-block {
      display: block !important; }
    div.bootstrap .d-xl-table {
      display: table !important; }
    div.bootstrap .d-xl-table-row {
      display: table-row !important; }
    div.bootstrap .d-xl-table-cell {
      display: table-cell !important; }
    div.bootstrap .d-xl-flex {
      display: -webkit-box !important;
      display: -ms-flexbox !important;
      display: flex !important; }
    div.bootstrap .d-xl-inline-flex {
      display: -webkit-inline-box !important;
      display: -ms-inline-flexbox !important;
      display: inline-flex !important; } }
  @media print {
    div.bootstrap .d-print-none {
      display: none !important; }
    div.bootstrap .d-print-inline {
      display: inline !important; }
    div.bootstrap .d-print-inline-block {
      display: inline-block !important; }
    div.bootstrap .d-print-block {
      display: block !important; }
    div.bootstrap .d-print-table {
      display: table !important; }
    div.bootstrap .d-print-table-row {
      display: table-row !important; }
    div.bootstrap .d-print-table-cell {
      display: table-cell !important; }
    div.bootstrap .d-print-flex {
      display: -webkit-box !important;
      display: -ms-flexbox !important;
      display: flex !important; }
    div.bootstrap .d-print-inline-flex {
      display: -webkit-inline-box !important;
      display: -ms-inline-flexbox !important;
      display: inline-flex !important; } }
  div.bootstrap .embed-responsive {
    position: relative;
    display: block;
    width: 100%;
    padding: 0;
    overflow: hidden; }
  div.bootstrap .embed-responsive::before {
    display: block;
    content: ""; }
  div.bootstrap .embed-responsive .embed-responsive-item, div.bootstrap .embed-responsive embed, div.bootstrap .embed-responsive iframe, div.bootstrap .embed-responsive object, div.bootstrap .embed-responsive video {
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    width: 100%;
    height: 100%;
    border: 0; }
  div.bootstrap .embed-responsive-21by9::before {
    padding-top: 42.857143%; }
  div.bootstrap .embed-responsive-16by9::before {
    padding-top: 56.25%; }
  div.bootstrap .embed-responsive-4by3::before {
    padding-top: 75%; }
  div.bootstrap .embed-responsive-1by1::before {
    padding-top: 100%; }
  div.bootstrap .flex-row {
    -webkit-box-orient: horizontal !important;
    -webkit-box-direction: normal !important;
    -ms-flex-direction: row !important;
    flex-direction: row !important; }
  div.bootstrap .flex-column {
    -webkit-box-orient: vertical !important;
    -webkit-box-direction: normal !important;
    -ms-flex-direction: column !important;
    flex-direction: column !important; }
  div.bootstrap .flex-row-reverse {
    -webkit-box-orient: horizontal !important;
    -webkit-box-direction: reverse !important;
    -ms-flex-direction: row-reverse !important;
    flex-direction: row-reverse !important; }
  div.bootstrap .flex-column-reverse {
    -webkit-box-orient: vertical !important;
    -webkit-box-direction: reverse !important;
    -ms-flex-direction: column-reverse !important;
    flex-direction: column-reverse !important; }
  div.bootstrap .flex-wrap {
    -ms-flex-wrap: wrap !important;
    flex-wrap: wrap !important; }
  div.bootstrap .flex-nowrap {
    -ms-flex-wrap: nowrap !important;
    flex-wrap: nowrap !important; }
  div.bootstrap .flex-wrap-reverse {
    -ms-flex-wrap: wrap-reverse !important;
    flex-wrap: wrap-reverse !important; }
  div.bootstrap .justify-content-start {
    -webkit-box-pack: start !important;
    -ms-flex-pack: start !important;
    justify-content: flex-start !important; }
  div.bootstrap .justify-content-end {
    -webkit-box-pack: end !important;
    -ms-flex-pack: end !important;
    justify-content: flex-end !important; }
  div.bootstrap .justify-content-center {
    -webkit-box-pack: center !important;
    -ms-flex-pack: center !important;
    justify-content: center !important; }
  div.bootstrap .justify-content-between {
    -webkit-box-pack: justify !important;
    -ms-flex-pack: justify !important;
    justify-content: space-between !important; }
  div.bootstrap .justify-content-around {
    -ms-flex-pack: distribute !important;
    justify-content: space-around !important; }
  div.bootstrap .align-items-start {
    -webkit-box-align: start !important;
    -ms-flex-align: start !important;
    align-items: flex-start !important; }
  div.bootstrap .align-items-end {
    -webkit-box-align: end !important;
    -ms-flex-align: end !important;
    align-items: flex-end !important; }
  div.bootstrap .align-items-center {
    -webkit-box-align: center !important;
    -ms-flex-align: center !important;
    align-items: center !important; }
  div.bootstrap .align-items-baseline {
    -webkit-box-align: baseline !important;
    -ms-flex-align: baseline !important;
    align-items: baseline !important; }
  div.bootstrap .align-items-stretch {
    -webkit-box-align: stretch !important;
    -ms-flex-align: stretch !important;
    align-items: stretch !important; }
  div.bootstrap .align-content-start {
    -ms-flex-line-pack: start !important;
    align-content: flex-start !important; }
  div.bootstrap .align-content-end {
    -ms-flex-line-pack: end !important;
    align-content: flex-end !important; }
  div.bootstrap .align-content-center {
    -ms-flex-line-pack: center !important;
    align-content: center !important; }
  div.bootstrap .align-content-between {
    -ms-flex-line-pack: justify !important;
    align-content: space-between !important; }
  div.bootstrap .align-content-around {
    -ms-flex-line-pack: distribute !important;
    align-content: space-around !important; }
  div.bootstrap .align-content-stretch {
    -ms-flex-line-pack: stretch !important;
    align-content: stretch !important; }
  div.bootstrap .align-self-auto {
    -ms-flex-item-align: auto !important;
    align-self: auto !important; }
  div.bootstrap .align-self-start {
    -ms-flex-item-align: start !important;
    align-self: flex-start !important; }
  div.bootstrap .align-self-end {
    -ms-flex-item-align: end !important;
    align-self: flex-end !important; }
  div.bootstrap .align-self-center {
    -ms-flex-item-align: center !important;
    align-self: center !important; }
  div.bootstrap .align-self-baseline {
    -ms-flex-item-align: baseline !important;
    align-self: baseline !important; }
  div.bootstrap .align-self-stretch {
    -ms-flex-item-align: stretch !important;
    align-self: stretch !important; }
  @media (min-width: 576px) {
    div.bootstrap .flex-sm-row {
      -webkit-box-orient: horizontal !important;
      -webkit-box-direction: normal !important;
      -ms-flex-direction: row !important;
      flex-direction: row !important; }
    div.bootstrap .flex-sm-column {
      -webkit-box-orient: vertical !important;
      -webkit-box-direction: normal !important;
      -ms-flex-direction: column !important;
      flex-direction: column !important; }
    div.bootstrap .flex-sm-row-reverse {
      -webkit-box-orient: horizontal !important;
      -webkit-box-direction: reverse !important;
      -ms-flex-direction: row-reverse !important;
      flex-direction: row-reverse !important; }
    div.bootstrap .flex-sm-column-reverse {
      -webkit-box-orient: vertical !important;
      -webkit-box-direction: reverse !important;
      -ms-flex-direction: column-reverse !important;
      flex-direction: column-reverse !important; }
    div.bootstrap .flex-sm-wrap {
      -ms-flex-wrap: wrap !important;
      flex-wrap: wrap !important; }
    div.bootstrap .flex-sm-nowrap {
      -ms-flex-wrap: nowrap !important;
      flex-wrap: nowrap !important; }
    div.bootstrap .flex-sm-wrap-reverse {
      -ms-flex-wrap: wrap-reverse !important;
      flex-wrap: wrap-reverse !important; }
    div.bootstrap .justify-content-sm-start {
      -webkit-box-pack: start !important;
      -ms-flex-pack: start !important;
      justify-content: flex-start !important; }
    div.bootstrap .justify-content-sm-end {
      -webkit-box-pack: end !important;
      -ms-flex-pack: end !important;
      justify-content: flex-end !important; }
    div.bootstrap .justify-content-sm-center {
      -webkit-box-pack: center !important;
      -ms-flex-pack: center !important;
      justify-content: center !important; }
    div.bootstrap .justify-content-sm-between {
      -webkit-box-pack: justify !important;
      -ms-flex-pack: justify !important;
      justify-content: space-between !important; }
    div.bootstrap .justify-content-sm-around {
      -ms-flex-pack: distribute !important;
      justify-content: space-around !important; }
    div.bootstrap .align-items-sm-start {
      -webkit-box-align: start !important;
      -ms-flex-align: start !important;
      align-items: flex-start !important; }
    div.bootstrap .align-items-sm-end {
      -webkit-box-align: end !important;
      -ms-flex-align: end !important;
      align-items: flex-end !important; }
    div.bootstrap .align-items-sm-center {
      -webkit-box-align: center !important;
      -ms-flex-align: center !important;
      align-items: center !important; }
    div.bootstrap .align-items-sm-baseline {
      -webkit-box-align: baseline !important;
      -ms-flex-align: baseline !important;
      align-items: baseline !important; }
    div.bootstrap .align-items-sm-stretch {
      -webkit-box-align: stretch !important;
      -ms-flex-align: stretch !important;
      align-items: stretch !important; }
    div.bootstrap .align-content-sm-start {
      -ms-flex-line-pack: start !important;
      align-content: flex-start !important; }
    div.bootstrap .align-content-sm-end {
      -ms-flex-line-pack: end !important;
      align-content: flex-end !important; }
    div.bootstrap .align-content-sm-center {
      -ms-flex-line-pack: center !important;
      align-content: center !important; }
    div.bootstrap .align-content-sm-between {
      -ms-flex-line-pack: justify !important;
      align-content: space-between !important; }
    div.bootstrap .align-content-sm-around {
      -ms-flex-line-pack: distribute !important;
      align-content: space-around !important; }
    div.bootstrap .align-content-sm-stretch {
      -ms-flex-line-pack: stretch !important;
      align-content: stretch !important; }
    div.bootstrap .align-self-sm-auto {
      -ms-flex-item-align: auto !important;
      align-self: auto !important; }
    div.bootstrap .align-self-sm-start {
      -ms-flex-item-align: start !important;
      align-self: flex-start !important; }
    div.bootstrap .align-self-sm-end {
      -ms-flex-item-align: end !important;
      align-self: flex-end !important; }
    div.bootstrap .align-self-sm-center {
      -ms-flex-item-align: center !important;
      align-self: center !important; }
    div.bootstrap .align-self-sm-baseline {
      -ms-flex-item-align: baseline !important;
      align-self: baseline !important; }
    div.bootstrap .align-self-sm-stretch {
      -ms-flex-item-align: stretch !important;
      align-self: stretch !important; } }
  @media (min-width: 768px) {
    div.bootstrap .flex-md-row {
      -webkit-box-orient: horizontal !important;
      -webkit-box-direction: normal !important;
      -ms-flex-direction: row !important;
      flex-direction: row !important; }
    div.bootstrap .flex-md-column {
      -webkit-box-orient: vertical !important;
      -webkit-box-direction: normal !important;
      -ms-flex-direction: column !important;
      flex-direction: column !important; }
    div.bootstrap .flex-md-row-reverse {
      -webkit-box-orient: horizontal !important;
      -webkit-box-direction: reverse !important;
      -ms-flex-direction: row-reverse !important;
      flex-direction: row-reverse !important; }
    div.bootstrap .flex-md-column-reverse {
      -webkit-box-orient: vertical !important;
      -webkit-box-direction: reverse !important;
      -ms-flex-direction: column-reverse !important;
      flex-direction: column-reverse !important; }
    div.bootstrap .flex-md-wrap {
      -ms-flex-wrap: wrap !important;
      flex-wrap: wrap !important; }
    div.bootstrap .flex-md-nowrap {
      -ms-flex-wrap: nowrap !important;
      flex-wrap: nowrap !important; }
    div.bootstrap .flex-md-wrap-reverse {
      -ms-flex-wrap: wrap-reverse !important;
      flex-wrap: wrap-reverse !important; }
    div.bootstrap .justify-content-md-start {
      -webkit-box-pack: start !important;
      -ms-flex-pack: start !important;
      justify-content: flex-start !important; }
    div.bootstrap .justify-content-md-end {
      -webkit-box-pack: end !important;
      -ms-flex-pack: end !important;
      justify-content: flex-end !important; }
    div.bootstrap .justify-content-md-center {
      -webkit-box-pack: center !important;
      -ms-flex-pack: center !important;
      justify-content: center !important; }
    div.bootstrap .justify-content-md-between {
      -webkit-box-pack: justify !important;
      -ms-flex-pack: justify !important;
      justify-content: space-between !important; }
    div.bootstrap .justify-content-md-around {
      -ms-flex-pack: distribute !important;
      justify-content: space-around !important; }
    div.bootstrap .align-items-md-start {
      -webkit-box-align: start !important;
      -ms-flex-align: start !important;
      align-items: flex-start !important; }
    div.bootstrap .align-items-md-end {
      -webkit-box-align: end !important;
      -ms-flex-align: end !important;
      align-items: flex-end !important; }
    div.bootstrap .align-items-md-center {
      -webkit-box-align: center !important;
      -ms-flex-align: center !important;
      align-items: center !important; }
    div.bootstrap .align-items-md-baseline {
      -webkit-box-align: baseline !important;
      -ms-flex-align: baseline !important;
      align-items: baseline !important; }
    div.bootstrap .align-items-md-stretch {
      -webkit-box-align: stretch !important;
      -ms-flex-align: stretch !important;
      align-items: stretch !important; }
    div.bootstrap .align-content-md-start {
      -ms-flex-line-pack: start !important;
      align-content: flex-start !important; }
    div.bootstrap .align-content-md-end {
      -ms-flex-line-pack: end !important;
      align-content: flex-end !important; }
    div.bootstrap .align-content-md-center {
      -ms-flex-line-pack: center !important;
      align-content: center !important; }
    div.bootstrap .align-content-md-between {
      -ms-flex-line-pack: justify !important;
      align-content: space-between !important; }
    div.bootstrap .align-content-md-around {
      -ms-flex-line-pack: distribute !important;
      align-content: space-around !important; }
    div.bootstrap .align-content-md-stretch {
      -ms-flex-line-pack: stretch !important;
      align-content: stretch !important; }
    div.bootstrap .align-self-md-auto {
      -ms-flex-item-align: auto !important;
      align-self: auto !important; }
    div.bootstrap .align-self-md-start {
      -ms-flex-item-align: start !important;
      align-self: flex-start !important; }
    div.bootstrap .align-self-md-end {
      -ms-flex-item-align: end !important;
      align-self: flex-end !important; }
    div.bootstrap .align-self-md-center {
      -ms-flex-item-align: center !important;
      align-self: center !important; }
    div.bootstrap .align-self-md-baseline {
      -ms-flex-item-align: baseline !important;
      align-self: baseline !important; }
    div.bootstrap .align-self-md-stretch {
      -ms-flex-item-align: stretch !important;
      align-self: stretch !important; } }
  @media (min-width: 992px) {
    div.bootstrap .flex-lg-row {
      -webkit-box-orient: horizontal !important;
      -webkit-box-direction: normal !important;
      -ms-flex-direction: row !important;
      flex-direction: row !important; }
    div.bootstrap .flex-lg-column {
      -webkit-box-orient: vertical !important;
      -webkit-box-direction: normal !important;
      -ms-flex-direction: column !important;
      flex-direction: column !important; }
    div.bootstrap .flex-lg-row-reverse {
      -webkit-box-orient: horizontal !important;
      -webkit-box-direction: reverse !important;
      -ms-flex-direction: row-reverse !important;
      flex-direction: row-reverse !important; }
    div.bootstrap .flex-lg-column-reverse {
      -webkit-box-orient: vertical !important;
      -webkit-box-direction: reverse !important;
      -ms-flex-direction: column-reverse !important;
      flex-direction: column-reverse !important; }
    div.bootstrap .flex-lg-wrap {
      -ms-flex-wrap: wrap !important;
      flex-wrap: wrap !important; }
    div.bootstrap .flex-lg-nowrap {
      -ms-flex-wrap: nowrap !important;
      flex-wrap: nowrap !important; }
    div.bootstrap .flex-lg-wrap-reverse {
      -ms-flex-wrap: wrap-reverse !important;
      flex-wrap: wrap-reverse !important; }
    div.bootstrap .justify-content-lg-start {
      -webkit-box-pack: start !important;
      -ms-flex-pack: start !important;
      justify-content: flex-start !important; }
    div.bootstrap .justify-content-lg-end {
      -webkit-box-pack: end !important;
      -ms-flex-pack: end !important;
      justify-content: flex-end !important; }
    div.bootstrap .justify-content-lg-center {
      -webkit-box-pack: center !important;
      -ms-flex-pack: center !important;
      justify-content: center !important; }
    div.bootstrap .justify-content-lg-between {
      -webkit-box-pack: justify !important;
      -ms-flex-pack: justify !important;
      justify-content: space-between !important; }
    div.bootstrap .justify-content-lg-around {
      -ms-flex-pack: distribute !important;
      justify-content: space-around !important; }
    div.bootstrap .align-items-lg-start {
      -webkit-box-align: start !important;
      -ms-flex-align: start !important;
      align-items: flex-start !important; }
    div.bootstrap .align-items-lg-end {
      -webkit-box-align: end !important;
      -ms-flex-align: end !important;
      align-items: flex-end !important; }
    div.bootstrap .align-items-lg-center {
      -webkit-box-align: center !important;
      -ms-flex-align: center !important;
      align-items: center !important; }
    div.bootstrap .align-items-lg-baseline {
      -webkit-box-align: baseline !important;
      -ms-flex-align: baseline !important;
      align-items: baseline !important; }
    div.bootstrap .align-items-lg-stretch {
      -webkit-box-align: stretch !important;
      -ms-flex-align: stretch !important;
      align-items: stretch !important; }
    div.bootstrap .align-content-lg-start {
      -ms-flex-line-pack: start !important;
      align-content: flex-start !important; }
    div.bootstrap .align-content-lg-end {
      -ms-flex-line-pack: end !important;
      align-content: flex-end !important; }
    div.bootstrap .align-content-lg-center {
      -ms-flex-line-pack: center !important;
      align-content: center !important; }
    div.bootstrap .align-content-lg-between {
      -ms-flex-line-pack: justify !important;
      align-content: space-between !important; }
    div.bootstrap .align-content-lg-around {
      -ms-flex-line-pack: distribute !important;
      align-content: space-around !important; }
    div.bootstrap .align-content-lg-stretch {
      -ms-flex-line-pack: stretch !important;
      align-content: stretch !important; }
    div.bootstrap .align-self-lg-auto {
      -ms-flex-item-align: auto !important;
      align-self: auto !important; }
    div.bootstrap .align-self-lg-start {
      -ms-flex-item-align: start !important;
      align-self: flex-start !important; }
    div.bootstrap .align-self-lg-end {
      -ms-flex-item-align: end !important;
      align-self: flex-end !important; }
    div.bootstrap .align-self-lg-center {
      -ms-flex-item-align: center !important;
      align-self: center !important; }
    div.bootstrap .align-self-lg-baseline {
      -ms-flex-item-align: baseline !important;
      align-self: baseline !important; }
    div.bootstrap .align-self-lg-stretch {
      -ms-flex-item-align: stretch !important;
      align-self: stretch !important; } }
  @media (min-width: 1200px) {
    div.bootstrap .flex-xl-row {
      -webkit-box-orient: horizontal !important;
      -webkit-box-direction: normal !important;
      -ms-flex-direction: row !important;
      flex-direction: row !important; }
    div.bootstrap .flex-xl-column {
      -webkit-box-orient: vertical !important;
      -webkit-box-direction: normal !important;
      -ms-flex-direction: column !important;
      flex-direction: column !important; }
    div.bootstrap .flex-xl-row-reverse {
      -webkit-box-orient: horizontal !important;
      -webkit-box-direction: reverse !important;
      -ms-flex-direction: row-reverse !important;
      flex-direction: row-reverse !important; }
    div.bootstrap .flex-xl-column-reverse {
      -webkit-box-orient: vertical !important;
      -webkit-box-direction: reverse !important;
      -ms-flex-direction: column-reverse !important;
      flex-direction: column-reverse !important; }
    div.bootstrap .flex-xl-wrap {
      -ms-flex-wrap: wrap !important;
      flex-wrap: wrap !important; }
    div.bootstrap .flex-xl-nowrap {
      -ms-flex-wrap: nowrap !important;
      flex-wrap: nowrap !important; }
    div.bootstrap .flex-xl-wrap-reverse {
      -ms-flex-wrap: wrap-reverse !important;
      flex-wrap: wrap-reverse !important; }
    div.bootstrap .justify-content-xl-start {
      -webkit-box-pack: start !important;
      -ms-flex-pack: start !important;
      justify-content: flex-start !important; }
    div.bootstrap .justify-content-xl-end {
      -webkit-box-pack: end !important;
      -ms-flex-pack: end !important;
      justify-content: flex-end !important; }
    div.bootstrap .justify-content-xl-center {
      -webkit-box-pack: center !important;
      -ms-flex-pack: center !important;
      justify-content: center !important; }
    div.bootstrap .justify-content-xl-between {
      -webkit-box-pack: justify !important;
      -ms-flex-pack: justify !important;
      justify-content: space-between !important; }
    div.bootstrap .justify-content-xl-around {
      -ms-flex-pack: distribute !important;
      justify-content: space-around !important; }
    div.bootstrap .align-items-xl-start {
      -webkit-box-align: start !important;
      -ms-flex-align: start !important;
      align-items: flex-start !important; }
    div.bootstrap .align-items-xl-end {
      -webkit-box-align: end !important;
      -ms-flex-align: end !important;
      align-items: flex-end !important; }
    div.bootstrap .align-items-xl-center {
      -webkit-box-align: center !important;
      -ms-flex-align: center !important;
      align-items: center !important; }
    div.bootstrap .align-items-xl-baseline {
      -webkit-box-align: baseline !important;
      -ms-flex-align: baseline !important;
      align-items: baseline !important; }
    div.bootstrap .align-items-xl-stretch {
      -webkit-box-align: stretch !important;
      -ms-flex-align: stretch !important;
      align-items: stretch !important; }
    div.bootstrap .align-content-xl-start {
      -ms-flex-line-pack: start !important;
      align-content: flex-start !important; }
    div.bootstrap .align-content-xl-end {
      -ms-flex-line-pack: end !important;
      align-content: flex-end !important; }
    div.bootstrap .align-content-xl-center {
      -ms-flex-line-pack: center !important;
      align-content: center !important; }
    div.bootstrap .align-content-xl-between {
      -ms-flex-line-pack: justify !important;
      align-content: space-between !important; }
    div.bootstrap .align-content-xl-around {
      -ms-flex-line-pack: distribute !important;
      align-content: space-around !important; }
    div.bootstrap .align-content-xl-stretch {
      -ms-flex-line-pack: stretch !important;
      align-content: stretch !important; }
    div.bootstrap .align-self-xl-auto {
      -ms-flex-item-align: auto !important;
      align-self: auto !important; }
    div.bootstrap .align-self-xl-start {
      -ms-flex-item-align: start !important;
      align-self: flex-start !important; }
    div.bootstrap .align-self-xl-end {
      -ms-flex-item-align: end !important;
      align-self: flex-end !important; }
    div.bootstrap .align-self-xl-center {
      -ms-flex-item-align: center !important;
      align-self: center !important; }
    div.bootstrap .align-self-xl-baseline {
      -ms-flex-item-align: baseline !important;
      align-self: baseline !important; }
    div.bootstrap .align-self-xl-stretch {
      -ms-flex-item-align: stretch !important;
      align-self: stretch !important; } }
  div.bootstrap .float-left {
    float: left !important; }
  div.bootstrap .float-right {
    float: right !important; }
  div.bootstrap .float-none {
    float: none !important; }
  @media (min-width: 576px) {
    div.bootstrap .float-sm-left {
      float: left !important; }
    div.bootstrap .float-sm-right {
      float: right !important; }
    div.bootstrap .float-sm-none {
      float: none !important; } }
  @media (min-width: 768px) {
    div.bootstrap .float-md-left {
      float: left !important; }
    div.bootstrap .float-md-right {
      float: right !important; }
    div.bootstrap .float-md-none {
      float: none !important; } }
  @media (min-width: 992px) {
    div.bootstrap .float-lg-left {
      float: left !important; }
    div.bootstrap .float-lg-right {
      float: right !important; }
    div.bootstrap .float-lg-none {
      float: none !important; } }
  @media (min-width: 1200px) {
    div.bootstrap .float-xl-left {
      float: left !important; }
    div.bootstrap .float-xl-right {
      float: right !important; }
    div.bootstrap .float-xl-none {
      float: none !important; } }
  div.bootstrap .position-static {
    position: static !important; }
  div.bootstrap .position-relative {
    position: relative !important; }
  div.bootstrap .position-absolute {
    position: absolute !important; }
  div.bootstrap .position-fixed {
    position: fixed !important; }
  div.bootstrap .position-sticky {
    position: -webkit-sticky !important;
    position: sticky !important; }
  div.bootstrap .fixed-top {
    position: fixed;
    top: 0;
    right: 0;
    left: 0;
    z-index: 1030; }
  div.bootstrap .fixed-bottom {
    position: fixed;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1030; }
  @supports (position: -webkit-sticky) or (position: sticky) {
    div.bootstrap .sticky-top {
      position: -webkit-sticky;
      position: sticky;
      top: 0;
      z-index: 1020; } }
  div.bootstrap .sr-only {
    position: absolute;
    width: 1px;
    height: 1px;
    padding: 0;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    white-space: nowrap;
    -webkit-clip-path: inset(50%);
    clip-path: inset(50%);
    border: 0; }
  div.bootstrap .sr-only-focusable:active, div.bootstrap .sr-only-focusable:focus {
    position: static;
    width: auto;
    height: auto;
    overflow: visible;
    clip: auto;
    white-space: normal;
    -webkit-clip-path: none;
    clip-path: none; }
  div.bootstrap .w-25 {
    width: 25% !important; }
  div.bootstrap .w-50 {
    width: 50% !important; }
  div.bootstrap .w-75 {
    width: 75% !important; }
  div.bootstrap .w-100 {
    width: 100% !important; }
  div.bootstrap .h-25 {
    height: 25% !important; }
  div.bootstrap .h-50 {
    height: 50% !important; }
  div.bootstrap .h-75 {
    height: 75% !important; }
  div.bootstrap .h-100 {
    height: 100% !important; }
  div.bootstrap .mw-100 {
    max-width: 100% !important; }
  div.bootstrap .mh-100 {
    max-height: 100% !important; }
  div.bootstrap .m-0 {
    margin: 0 !important; }
  div.bootstrap .mt-0, div.bootstrap .my-0 {
    margin-top: 0 !important; }
  div.bootstrap .mr-0, div.bootstrap .mx-0 {
    margin-right: 0 !important; }
  div.bootstrap .mb-0, div.bootstrap .my-0 {
    margin-bottom: 0 !important; }
  div.bootstrap .ml-0, div.bootstrap .mx-0 {
    margin-left: 0 !important; }
  div.bootstrap .m-1 {
    margin: 0.25rem !important; }
  div.bootstrap .mt-1, div.bootstrap .my-1 {
    margin-top: 0.25rem !important; }
  div.bootstrap .mr-1, div.bootstrap .mx-1 {
    margin-right: 0.25rem !important; }
  div.bootstrap .mb-1, div.bootstrap .my-1 {
    margin-bottom: 0.25rem !important; }
  div.bootstrap .ml-1, div.bootstrap .mx-1 {
    margin-left: 0.25rem !important; }
  div.bootstrap .m-2 {
    margin: 0.5rem !important; }
  div.bootstrap .mt-2, div.bootstrap .my-2 {
    margin-top: 0.5rem !important; }
  div.bootstrap .mr-2, div.bootstrap .mx-2 {
    margin-right: 0.5rem !important; }
  div.bootstrap .mb-2, div.bootstrap .my-2 {
    margin-bottom: 0.5rem !important; }
  div.bootstrap .ml-2, div.bootstrap .mx-2 {
    margin-left: 0.5rem !important; }
  div.bootstrap .m-3 {
    margin: 1rem !important; }
  div.bootstrap .mt-3, div.bootstrap .my-3 {
    margin-top: 1rem !important; }
  div.bootstrap .mr-3, div.bootstrap .mx-3 {
    margin-right: 1rem !important; }
  div.bootstrap .mb-3, div.bootstrap .my-3 {
    margin-bottom: 1rem !important; }
  div.bootstrap .ml-3, div.bootstrap .mx-3 {
    margin-left: 1rem !important; }
  div.bootstrap .m-4 {
    margin: 1.5rem !important; }
  div.bootstrap .mt-4, div.bootstrap .my-4 {
    margin-top: 1.5rem !important; }
  div.bootstrap .mr-4, div.bootstrap .mx-4 {
    margin-right: 1.5rem !important; }
  div.bootstrap .mb-4, div.bootstrap .my-4 {
    margin-bottom: 1.5rem !important; }
  div.bootstrap .ml-4, div.bootstrap .mx-4 {
    margin-left: 1.5rem !important; }
  div.bootstrap .m-5 {
    margin: 3rem !important; }
  div.bootstrap .mt-5, div.bootstrap .my-5 {
    margin-top: 3rem !important; }
  div.bootstrap .mr-5, div.bootstrap .mx-5 {
    margin-right: 3rem !important; }
  div.bootstrap .mb-5, div.bootstrap .my-5 {
    margin-bottom: 3rem !important; }
  div.bootstrap .ml-5, div.bootstrap .mx-5 {
    margin-left: 3rem !important; }
  div.bootstrap .p-0 {
    padding: 0 !important; }
  div.bootstrap .pt-0, div.bootstrap .py-0 {
    padding-top: 0 !important; }
  div.bootstrap .pr-0, div.bootstrap .px-0 {
    padding-right: 0 !important; }
  div.bootstrap .pb-0, div.bootstrap .py-0 {
    padding-bottom: 0 !important; }
  div.bootstrap .pl-0, div.bootstrap .px-0 {
    padding-left: 0 !important; }
  div.bootstrap .p-1 {
    padding: 0.25rem !important; }
  div.bootstrap .pt-1, div.bootstrap .py-1 {
    padding-top: 0.25rem !important; }
  div.bootstrap .pr-1, div.bootstrap .px-1 {
    padding-right: 0.25rem !important; }
  div.bootstrap .pb-1, div.bootstrap .py-1 {
    padding-bottom: 0.25rem !important; }
  div.bootstrap .pl-1, div.bootstrap .px-1 {
    padding-left: 0.25rem !important; }
  div.bootstrap .p-2 {
    padding: 0.5rem !important; }
  div.bootstrap .pt-2, div.bootstrap .py-2 {
    padding-top: 0.5rem !important; }
  div.bootstrap .pr-2, div.bootstrap .px-2 {
    padding-right: 0.5rem !important; }
  div.bootstrap .pb-2, div.bootstrap .py-2 {
    padding-bottom: 0.5rem !important; }
  div.bootstrap .pl-2, div.bootstrap .px-2 {
    padding-left: 0.5rem !important; }
  div.bootstrap .p-3 {
    padding: 1rem !important; }
  div.bootstrap .pt-3, div.bootstrap .py-3 {
    padding-top: 1rem !important; }
  div.bootstrap .pr-3, div.bootstrap .px-3 {
    padding-right: 1rem !important; }
  div.bootstrap .pb-3, div.bootstrap .py-3 {
    padding-bottom: 1rem !important; }
  div.bootstrap .pl-3, div.bootstrap .px-3 {
    padding-left: 1rem !important; }
  div.bootstrap .p-4 {
    padding: 1.5rem !important; }
  div.bootstrap .pt-4, div.bootstrap .py-4 {
    padding-top: 1.5rem !important; }
  div.bootstrap .pr-4, div.bootstrap .px-4 {
    padding-right: 1.5rem !important; }
  div.bootstrap .pb-4, div.bootstrap .py-4 {
    padding-bottom: 1.5rem !important; }
  div.bootstrap .pl-4, div.bootstrap .px-4 {
    padding-left: 1.5rem !important; }
  div.bootstrap .p-5 {
    padding: 3rem !important; }
  div.bootstrap .pt-5, div.bootstrap .py-5 {
    padding-top: 3rem !important; }
  div.bootstrap .pr-5, div.bootstrap .px-5 {
    padding-right: 3rem !important; }
  div.bootstrap .pb-5, div.bootstrap .py-5 {
    padding-bottom: 3rem !important; }
  div.bootstrap .pl-5, div.bootstrap .px-5 {
    padding-left: 3rem !important; }
  div.bootstrap .m-auto {
    margin: auto !important; }
  div.bootstrap .mt-auto, div.bootstrap .my-auto {
    margin-top: auto !important; }
  div.bootstrap .mr-auto, div.bootstrap .mx-auto {
    margin-right: auto !important; }
  div.bootstrap .mb-auto, div.bootstrap .my-auto {
    margin-bottom: auto !important; }
  div.bootstrap .ml-auto, div.bootstrap .mx-auto {
    margin-left: auto !important; }
  @media (min-width: 576px) {
    div.bootstrap .m-sm-0 {
      margin: 0 !important; }
    div.bootstrap .mt-sm-0, div.bootstrap .my-sm-0 {
      margin-top: 0 !important; }
    div.bootstrap .mr-sm-0, div.bootstrap .mx-sm-0 {
      margin-right: 0 !important; }
    div.bootstrap .mb-sm-0, div.bootstrap .my-sm-0 {
      margin-bottom: 0 !important; }
    div.bootstrap .ml-sm-0, div.bootstrap .mx-sm-0 {
      margin-left: 0 !important; }
    div.bootstrap .m-sm-1 {
      margin: 0.25rem !important; }
    div.bootstrap .mt-sm-1, div.bootstrap .my-sm-1 {
      margin-top: 0.25rem !important; }
    div.bootstrap .mr-sm-1, div.bootstrap .mx-sm-1 {
      margin-right: 0.25rem !important; }
    div.bootstrap .mb-sm-1, div.bootstrap .my-sm-1 {
      margin-bottom: 0.25rem !important; }
    div.bootstrap .ml-sm-1, div.bootstrap .mx-sm-1 {
      margin-left: 0.25rem !important; }
    div.bootstrap .m-sm-2 {
      margin: 0.5rem !important; }
    div.bootstrap .mt-sm-2, div.bootstrap .my-sm-2 {
      margin-top: 0.5rem !important; }
    div.bootstrap .mr-sm-2, div.bootstrap .mx-sm-2 {
      margin-right: 0.5rem !important; }
    div.bootstrap .mb-sm-2, div.bootstrap .my-sm-2 {
      margin-bottom: 0.5rem !important; }
    div.bootstrap .ml-sm-2, div.bootstrap .mx-sm-2 {
      margin-left: 0.5rem !important; }
    div.bootstrap .m-sm-3 {
      margin: 1rem !important; }
    div.bootstrap .mt-sm-3, div.bootstrap .my-sm-3 {
      margin-top: 1rem !important; }
    div.bootstrap .mr-sm-3, div.bootstrap .mx-sm-3 {
      margin-right: 1rem !important; }
    div.bootstrap .mb-sm-3, div.bootstrap .my-sm-3 {
      margin-bottom: 1rem !important; }
    div.bootstrap .ml-sm-3, div.bootstrap .mx-sm-3 {
      margin-left: 1rem !important; }
    div.bootstrap .m-sm-4 {
      margin: 1.5rem !important; }
    div.bootstrap .mt-sm-4, div.bootstrap .my-sm-4 {
      margin-top: 1.5rem !important; }
    div.bootstrap .mr-sm-4, div.bootstrap .mx-sm-4 {
      margin-right: 1.5rem !important; }
    div.bootstrap .mb-sm-4, div.bootstrap .my-sm-4 {
      margin-bottom: 1.5rem !important; }
    div.bootstrap .ml-sm-4, div.bootstrap .mx-sm-4 {
      margin-left: 1.5rem !important; }
    div.bootstrap .m-sm-5 {
      margin: 3rem !important; }
    div.bootstrap .mt-sm-5, div.bootstrap .my-sm-5 {
      margin-top: 3rem !important; }
    div.bootstrap .mr-sm-5, div.bootstrap .mx-sm-5 {
      margin-right: 3rem !important; }
    div.bootstrap .mb-sm-5, div.bootstrap .my-sm-5 {
      margin-bottom: 3rem !important; }
    div.bootstrap .ml-sm-5, div.bootstrap .mx-sm-5 {
      margin-left: 3rem !important; }
    div.bootstrap .p-sm-0 {
      padding: 0 !important; }
    div.bootstrap .pt-sm-0, div.bootstrap .py-sm-0 {
      padding-top: 0 !important; }
    div.bootstrap .pr-sm-0, div.bootstrap .px-sm-0 {
      padding-right: 0 !important; }
    div.bootstrap .pb-sm-0, div.bootstrap .py-sm-0 {
      padding-bottom: 0 !important; }
    div.bootstrap .pl-sm-0, div.bootstrap .px-sm-0 {
      padding-left: 0 !important; }
    div.bootstrap .p-sm-1 {
      padding: 0.25rem !important; }
    div.bootstrap .pt-sm-1, div.bootstrap .py-sm-1 {
      padding-top: 0.25rem !important; }
    div.bootstrap .pr-sm-1, div.bootstrap .px-sm-1 {
      padding-right: 0.25rem !important; }
    div.bootstrap .pb-sm-1, div.bootstrap .py-sm-1 {
      padding-bottom: 0.25rem !important; }
    div.bootstrap .pl-sm-1, div.bootstrap .px-sm-1 {
      padding-left: 0.25rem !important; }
    div.bootstrap .p-sm-2 {
      padding: 0.5rem !important; }
    div.bootstrap .pt-sm-2, div.bootstrap .py-sm-2 {
      padding-top: 0.5rem !important; }
    div.bootstrap .pr-sm-2, div.bootstrap .px-sm-2 {
      padding-right: 0.5rem !important; }
    div.bootstrap .pb-sm-2, div.bootstrap .py-sm-2 {
      padding-bottom: 0.5rem !important; }
    div.bootstrap .pl-sm-2, div.bootstrap .px-sm-2 {
      padding-left: 0.5rem !important; }
    div.bootstrap .p-sm-3 {
      padding: 1rem !important; }
    div.bootstrap .pt-sm-3, div.bootstrap .py-sm-3 {
      padding-top: 1rem !important; }
    div.bootstrap .pr-sm-3, div.bootstrap .px-sm-3 {
      padding-right: 1rem !important; }
    div.bootstrap .pb-sm-3, div.bootstrap .py-sm-3 {
      padding-bottom: 1rem !important; }
    div.bootstrap .pl-sm-3, div.bootstrap .px-sm-3 {
      padding-left: 1rem !important; }
    div.bootstrap .p-sm-4 {
      padding: 1.5rem !important; }
    div.bootstrap .pt-sm-4, div.bootstrap .py-sm-4 {
      padding-top: 1.5rem !important; }
    div.bootstrap .pr-sm-4, div.bootstrap .px-sm-4 {
      padding-right: 1.5rem !important; }
    div.bootstrap .pb-sm-4, div.bootstrap .py-sm-4 {
      padding-bottom: 1.5rem !important; }
    div.bootstrap .pl-sm-4, div.bootstrap .px-sm-4 {
      padding-left: 1.5rem !important; }
    div.bootstrap .p-sm-5 {
      padding: 3rem !important; }
    div.bootstrap .pt-sm-5, div.bootstrap .py-sm-5 {
      padding-top: 3rem !important; }
    div.bootstrap .pr-sm-5, div.bootstrap .px-sm-5 {
      padding-right: 3rem !important; }
    div.bootstrap .pb-sm-5, div.bootstrap .py-sm-5 {
      padding-bottom: 3rem !important; }
    div.bootstrap .pl-sm-5, div.bootstrap .px-sm-5 {
      padding-left: 3rem !important; }
    div.bootstrap .m-sm-auto {
      margin: auto !important; }
    div.bootstrap .mt-sm-auto, div.bootstrap .my-sm-auto {
      margin-top: auto !important; }
    div.bootstrap .mr-sm-auto, div.bootstrap .mx-sm-auto {
      margin-right: auto !important; }
    div.bootstrap .mb-sm-auto, div.bootstrap .my-sm-auto {
      margin-bottom: auto !important; }
    div.bootstrap .ml-sm-auto, div.bootstrap .mx-sm-auto {
      margin-left: auto !important; } }
  @media (min-width: 768px) {
    div.bootstrap .m-md-0 {
      margin: 0 !important; }
    div.bootstrap .mt-md-0, div.bootstrap .my-md-0 {
      margin-top: 0 !important; }
    div.bootstrap .mr-md-0, div.bootstrap .mx-md-0 {
      margin-right: 0 !important; }
    div.bootstrap .mb-md-0, div.bootstrap .my-md-0 {
      margin-bottom: 0 !important; }
    div.bootstrap .ml-md-0, div.bootstrap .mx-md-0 {
      margin-left: 0 !important; }
    div.bootstrap .m-md-1 {
      margin: 0.25rem !important; }
    div.bootstrap .mt-md-1, div.bootstrap .my-md-1 {
      margin-top: 0.25rem !important; }
    div.bootstrap .mr-md-1, div.bootstrap .mx-md-1 {
      margin-right: 0.25rem !important; }
    div.bootstrap .mb-md-1, div.bootstrap .my-md-1 {
      margin-bottom: 0.25rem !important; }
    div.bootstrap .ml-md-1, div.bootstrap .mx-md-1 {
      margin-left: 0.25rem !important; }
    div.bootstrap .m-md-2 {
      margin: 0.5rem !important; }
    div.bootstrap .mt-md-2, div.bootstrap .my-md-2 {
      margin-top: 0.5rem !important; }
    div.bootstrap .mr-md-2, div.bootstrap .mx-md-2 {
      margin-right: 0.5rem !important; }
    div.bootstrap .mb-md-2, div.bootstrap .my-md-2 {
      margin-bottom: 0.5rem !important; }
    div.bootstrap .ml-md-2, div.bootstrap .mx-md-2 {
      margin-left: 0.5rem !important; }
    div.bootstrap .m-md-3 {
      margin: 1rem !important; }
    div.bootstrap .mt-md-3, div.bootstrap .my-md-3 {
      margin-top: 1rem !important; }
    div.bootstrap .mr-md-3, div.bootstrap .mx-md-3 {
      margin-right: 1rem !important; }
    div.bootstrap .mb-md-3, div.bootstrap .my-md-3 {
      margin-bottom: 1rem !important; }
    div.bootstrap .ml-md-3, div.bootstrap .mx-md-3 {
      margin-left: 1rem !important; }
    div.bootstrap .m-md-4 {
      margin: 1.5rem !important; }
    div.bootstrap .mt-md-4, div.bootstrap .my-md-4 {
      margin-top: 1.5rem !important; }
    div.bootstrap .mr-md-4, div.bootstrap .mx-md-4 {
      margin-right: 1.5rem !important; }
    div.bootstrap .mb-md-4, div.bootstrap .my-md-4 {
      margin-bottom: 1.5rem !important; }
    div.bootstrap .ml-md-4, div.bootstrap .mx-md-4 {
      margin-left: 1.5rem !important; }
    div.bootstrap .m-md-5 {
      margin: 3rem !important; }
    div.bootstrap .mt-md-5, div.bootstrap .my-md-5 {
      margin-top: 3rem !important; }
    div.bootstrap .mr-md-5, div.bootstrap .mx-md-5 {
      margin-right: 3rem !important; }
    div.bootstrap .mb-md-5, div.bootstrap .my-md-5 {
      margin-bottom: 3rem !important; }
    div.bootstrap .ml-md-5, div.bootstrap .mx-md-5 {
      margin-left: 3rem !important; }
    div.bootstrap .p-md-0 {
      padding: 0 !important; }
    div.bootstrap .pt-md-0, div.bootstrap .py-md-0 {
      padding-top: 0 !important; }
    div.bootstrap .pr-md-0, div.bootstrap .px-md-0 {
      padding-right: 0 !important; }
    div.bootstrap .pb-md-0, div.bootstrap .py-md-0 {
      padding-bottom: 0 !important; }
    div.bootstrap .pl-md-0, div.bootstrap .px-md-0 {
      padding-left: 0 !important; }
    div.bootstrap .p-md-1 {
      padding: 0.25rem !important; }
    div.bootstrap .pt-md-1, div.bootstrap .py-md-1 {
      padding-top: 0.25rem !important; }
    div.bootstrap .pr-md-1, div.bootstrap .px-md-1 {
      padding-right: 0.25rem !important; }
    div.bootstrap .pb-md-1, div.bootstrap .py-md-1 {
      padding-bottom: 0.25rem !important; }
    div.bootstrap .pl-md-1, div.bootstrap .px-md-1 {
      padding-left: 0.25rem !important; }
    div.bootstrap .p-md-2 {
      padding: 0.5rem !important; }
    div.bootstrap .pt-md-2, div.bootstrap .py-md-2 {
      padding-top: 0.5rem !important; }
    div.bootstrap .pr-md-2, div.bootstrap .px-md-2 {
      padding-right: 0.5rem !important; }
    div.bootstrap .pb-md-2, div.bootstrap .py-md-2 {
      padding-bottom: 0.5rem !important; }
    div.bootstrap .pl-md-2, div.bootstrap .px-md-2 {
      padding-left: 0.5rem !important; }
    div.bootstrap .p-md-3 {
      padding: 1rem !important; }
    div.bootstrap .pt-md-3, div.bootstrap .py-md-3 {
      padding-top: 1rem !important; }
    div.bootstrap .pr-md-3, div.bootstrap .px-md-3 {
      padding-right: 1rem !important; }
    div.bootstrap .pb-md-3, div.bootstrap .py-md-3 {
      padding-bottom: 1rem !important; }
    div.bootstrap .pl-md-3, div.bootstrap .px-md-3 {
      padding-left: 1rem !important; }
    div.bootstrap .p-md-4 {
      padding: 1.5rem !important; }
    div.bootstrap .pt-md-4, div.bootstrap .py-md-4 {
      padding-top: 1.5rem !important; }
    div.bootstrap .pr-md-4, div.bootstrap .px-md-4 {
      padding-right: 1.5rem !important; }
    div.bootstrap .pb-md-4, div.bootstrap .py-md-4 {
      padding-bottom: 1.5rem !important; }
    div.bootstrap .pl-md-4, div.bootstrap .px-md-4 {
      padding-left: 1.5rem !important; }
    div.bootstrap .p-md-5 {
      padding: 3rem !important; }
    div.bootstrap .pt-md-5, div.bootstrap .py-md-5 {
      padding-top: 3rem !important; }
    div.bootstrap .pr-md-5, div.bootstrap .px-md-5 {
      padding-right: 3rem !important; }
    div.bootstrap .pb-md-5, div.bootstrap .py-md-5 {
      padding-bottom: 3rem !important; }
    div.bootstrap .pl-md-5, div.bootstrap .px-md-5 {
      padding-left: 3rem !important; }
    div.bootstrap .m-md-auto {
      margin: auto !important; }
    div.bootstrap .mt-md-auto, div.bootstrap .my-md-auto {
      margin-top: auto !important; }
    div.bootstrap .mr-md-auto, div.bootstrap .mx-md-auto {
      margin-right: auto !important; }
    div.bootstrap .mb-md-auto, div.bootstrap .my-md-auto {
      margin-bottom: auto !important; }
    div.bootstrap .ml-md-auto, div.bootstrap .mx-md-auto {
      margin-left: auto !important; } }
  @media (min-width: 992px) {
    div.bootstrap .m-lg-0 {
      margin: 0 !important; }
    div.bootstrap .mt-lg-0, div.bootstrap .my-lg-0 {
      margin-top: 0 !important; }
    div.bootstrap .mr-lg-0, div.bootstrap .mx-lg-0 {
      margin-right: 0 !important; }
    div.bootstrap .mb-lg-0, div.bootstrap .my-lg-0 {
      margin-bottom: 0 !important; }
    div.bootstrap .ml-lg-0, div.bootstrap .mx-lg-0 {
      margin-left: 0 !important; }
    div.bootstrap .m-lg-1 {
      margin: 0.25rem !important; }
    div.bootstrap .mt-lg-1, div.bootstrap .my-lg-1 {
      margin-top: 0.25rem !important; }
    div.bootstrap .mr-lg-1, div.bootstrap .mx-lg-1 {
      margin-right: 0.25rem !important; }
    div.bootstrap .mb-lg-1, div.bootstrap .my-lg-1 {
      margin-bottom: 0.25rem !important; }
    div.bootstrap .ml-lg-1, div.bootstrap .mx-lg-1 {
      margin-left: 0.25rem !important; }
    div.bootstrap .m-lg-2 {
      margin: 0.5rem !important; }
    div.bootstrap .mt-lg-2, div.bootstrap .my-lg-2 {
      margin-top: 0.5rem !important; }
    div.bootstrap .mr-lg-2, div.bootstrap .mx-lg-2 {
      margin-right: 0.5rem !important; }
    div.bootstrap .mb-lg-2, div.bootstrap .my-lg-2 {
      margin-bottom: 0.5rem !important; }
    div.bootstrap .ml-lg-2, div.bootstrap .mx-lg-2 {
      margin-left: 0.5rem !important; }
    div.bootstrap .m-lg-3 {
      margin: 1rem !important; }
    div.bootstrap .mt-lg-3, div.bootstrap .my-lg-3 {
      margin-top: 1rem !important; }
    div.bootstrap .mr-lg-3, div.bootstrap .mx-lg-3 {
      margin-right: 1rem !important; }
    div.bootstrap .mb-lg-3, div.bootstrap .my-lg-3 {
      margin-bottom: 1rem !important; }
    div.bootstrap .ml-lg-3, div.bootstrap .mx-lg-3 {
      margin-left: 1rem !important; }
    div.bootstrap .m-lg-4 {
      margin: 1.5rem !important; }
    div.bootstrap .mt-lg-4, div.bootstrap .my-lg-4 {
      margin-top: 1.5rem !important; }
    div.bootstrap .mr-lg-4, div.bootstrap .mx-lg-4 {
      margin-right: 1.5rem !important; }
    div.bootstrap .mb-lg-4, div.bootstrap .my-lg-4 {
      margin-bottom: 1.5rem !important; }
    div.bootstrap .ml-lg-4, div.bootstrap .mx-lg-4 {
      margin-left: 1.5rem !important; }
    div.bootstrap .m-lg-5 {
      margin: 3rem !important; }
    div.bootstrap .mt-lg-5, div.bootstrap .my-lg-5 {
      margin-top: 3rem !important; }
    div.bootstrap .mr-lg-5, div.bootstrap .mx-lg-5 {
      margin-right: 3rem !important; }
    div.bootstrap .mb-lg-5, div.bootstrap .my-lg-5 {
      margin-bottom: 3rem !important; }
    div.bootstrap .ml-lg-5, div.bootstrap .mx-lg-5 {
      margin-left: 3rem !important; }
    div.bootstrap .p-lg-0 {
      padding: 0 !important; }
    div.bootstrap .pt-lg-0, div.bootstrap .py-lg-0 {
      padding-top: 0 !important; }
    div.bootstrap .pr-lg-0, div.bootstrap .px-lg-0 {
      padding-right: 0 !important; }
    div.bootstrap .pb-lg-0, div.bootstrap .py-lg-0 {
      padding-bottom: 0 !important; }
    div.bootstrap .pl-lg-0, div.bootstrap .px-lg-0 {
      padding-left: 0 !important; }
    div.bootstrap .p-lg-1 {
      padding: 0.25rem !important; }
    div.bootstrap .pt-lg-1, div.bootstrap .py-lg-1 {
      padding-top: 0.25rem !important; }
    div.bootstrap .pr-lg-1, div.bootstrap .px-lg-1 {
      padding-right: 0.25rem !important; }
    div.bootstrap .pb-lg-1, div.bootstrap .py-lg-1 {
      padding-bottom: 0.25rem !important; }
    div.bootstrap .pl-lg-1, div.bootstrap .px-lg-1 {
      padding-left: 0.25rem !important; }
    div.bootstrap .p-lg-2 {
      padding: 0.5rem !important; }
    div.bootstrap .pt-lg-2, div.bootstrap .py-lg-2 {
      padding-top: 0.5rem !important; }
    div.bootstrap .pr-lg-2, div.bootstrap .px-lg-2 {
      padding-right: 0.5rem !important; }
    div.bootstrap .pb-lg-2, div.bootstrap .py-lg-2 {
      padding-bottom: 0.5rem !important; }
    div.bootstrap .pl-lg-2, div.bootstrap .px-lg-2 {
      padding-left: 0.5rem !important; }
    div.bootstrap .p-lg-3 {
      padding: 1rem !important; }
    div.bootstrap .pt-lg-3, div.bootstrap .py-lg-3 {
      padding-top: 1rem !important; }
    div.bootstrap .pr-lg-3, div.bootstrap .px-lg-3 {
      padding-right: 1rem !important; }
    div.bootstrap .pb-lg-3, div.bootstrap .py-lg-3 {
      padding-bottom: 1rem !important; }
    div.bootstrap .pl-lg-3, div.bootstrap .px-lg-3 {
      padding-left: 1rem !important; }
    div.bootstrap .p-lg-4 {
      padding: 1.5rem !important; }
    div.bootstrap .pt-lg-4, div.bootstrap .py-lg-4 {
      padding-top: 1.5rem !important; }
    div.bootstrap .pr-lg-4, div.bootstrap .px-lg-4 {
      padding-right: 1.5rem !important; }
    div.bootstrap .pb-lg-4, div.bootstrap .py-lg-4 {
      padding-bottom: 1.5rem !important; }
    div.bootstrap .pl-lg-4, div.bootstrap .px-lg-4 {
      padding-left: 1.5rem !important; }
    div.bootstrap .p-lg-5 {
      padding: 3rem !important; }
    div.bootstrap .pt-lg-5, div.bootstrap .py-lg-5 {
      padding-top: 3rem !important; }
    div.bootstrap .pr-lg-5, div.bootstrap .px-lg-5 {
      padding-right: 3rem !important; }
    div.bootstrap .pb-lg-5, div.bootstrap .py-lg-5 {
      padding-bottom: 3rem !important; }
    div.bootstrap .pl-lg-5, div.bootstrap .px-lg-5 {
      padding-left: 3rem !important; }
    div.bootstrap .m-lg-auto {
      margin: auto !important; }
    div.bootstrap .mt-lg-auto, div.bootstrap .my-lg-auto {
      margin-top: auto !important; }
    div.bootstrap .mr-lg-auto, div.bootstrap .mx-lg-auto {
      margin-right: auto !important; }
    div.bootstrap .mb-lg-auto, div.bootstrap .my-lg-auto {
      margin-bottom: auto !important; }
    div.bootstrap .ml-lg-auto, div.bootstrap .mx-lg-auto {
      margin-left: auto !important; } }
  @media (min-width: 1200px) {
    div.bootstrap .m-xl-0 {
      margin: 0 !important; }
    div.bootstrap .mt-xl-0, div.bootstrap .my-xl-0 {
      margin-top: 0 !important; }
    div.bootstrap .mr-xl-0, div.bootstrap .mx-xl-0 {
      margin-right: 0 !important; }
    div.bootstrap .mb-xl-0, div.bootstrap .my-xl-0 {
      margin-bottom: 0 !important; }
    div.bootstrap .ml-xl-0, div.bootstrap .mx-xl-0 {
      margin-left: 0 !important; }
    div.bootstrap .m-xl-1 {
      margin: 0.25rem !important; }
    div.bootstrap .mt-xl-1, div.bootstrap .my-xl-1 {
      margin-top: 0.25rem !important; }
    div.bootstrap .mr-xl-1, div.bootstrap .mx-xl-1 {
      margin-right: 0.25rem !important; }
    div.bootstrap .mb-xl-1, div.bootstrap .my-xl-1 {
      margin-bottom: 0.25rem !important; }
    div.bootstrap .ml-xl-1, div.bootstrap .mx-xl-1 {
      margin-left: 0.25rem !important; }
    div.bootstrap .m-xl-2 {
      margin: 0.5rem !important; }
    div.bootstrap .mt-xl-2, div.bootstrap .my-xl-2 {
      margin-top: 0.5rem !important; }
    div.bootstrap .mr-xl-2, div.bootstrap .mx-xl-2 {
      margin-right: 0.5rem !important; }
    div.bootstrap .mb-xl-2, div.bootstrap .my-xl-2 {
      margin-bottom: 0.5rem !important; }
    div.bootstrap .ml-xl-2, div.bootstrap .mx-xl-2 {
      margin-left: 0.5rem !important; }
    div.bootstrap .m-xl-3 {
      margin: 1rem !important; }
    div.bootstrap .mt-xl-3, div.bootstrap .my-xl-3 {
      margin-top: 1rem !important; }
    div.bootstrap .mr-xl-3, div.bootstrap .mx-xl-3 {
      margin-right: 1rem !important; }
    div.bootstrap .mb-xl-3, div.bootstrap .my-xl-3 {
      margin-bottom: 1rem !important; }
    div.bootstrap .ml-xl-3, div.bootstrap .mx-xl-3 {
      margin-left: 1rem !important; }
    div.bootstrap .m-xl-4 {
      margin: 1.5rem !important; }
    div.bootstrap .mt-xl-4, div.bootstrap .my-xl-4 {
      margin-top: 1.5rem !important; }
    div.bootstrap .mr-xl-4, div.bootstrap .mx-xl-4 {
      margin-right: 1.5rem !important; }
    div.bootstrap .mb-xl-4, div.bootstrap .my-xl-4 {
      margin-bottom: 1.5rem !important; }
    div.bootstrap .ml-xl-4, div.bootstrap .mx-xl-4 {
      margin-left: 1.5rem !important; }
    div.bootstrap .m-xl-5 {
      margin: 3rem !important; }
    div.bootstrap .mt-xl-5, div.bootstrap .my-xl-5 {
      margin-top: 3rem !important; }
    div.bootstrap .mr-xl-5, div.bootstrap .mx-xl-5 {
      margin-right: 3rem !important; }
    div.bootstrap .mb-xl-5, div.bootstrap .my-xl-5 {
      margin-bottom: 3rem !important; }
    div.bootstrap .ml-xl-5, div.bootstrap .mx-xl-5 {
      margin-left: 3rem !important; }
    div.bootstrap .p-xl-0 {
      padding: 0 !important; }
    div.bootstrap .pt-xl-0, div.bootstrap .py-xl-0 {
      padding-top: 0 !important; }
    div.bootstrap .pr-xl-0, div.bootstrap .px-xl-0 {
      padding-right: 0 !important; }
    div.bootstrap .pb-xl-0, div.bootstrap .py-xl-0 {
      padding-bottom: 0 !important; }
    div.bootstrap .pl-xl-0, div.bootstrap .px-xl-0 {
      padding-left: 0 !important; }
    div.bootstrap .p-xl-1 {
      padding: 0.25rem !important; }
    div.bootstrap .pt-xl-1, div.bootstrap .py-xl-1 {
      padding-top: 0.25rem !important; }
    div.bootstrap .pr-xl-1, div.bootstrap .px-xl-1 {
      padding-right: 0.25rem !important; }
    div.bootstrap .pb-xl-1, div.bootstrap .py-xl-1 {
      padding-bottom: 0.25rem !important; }
    div.bootstrap .pl-xl-1, div.bootstrap .px-xl-1 {
      padding-left: 0.25rem !important; }
    div.bootstrap .p-xl-2 {
      padding: 0.5rem !important; }
    div.bootstrap .pt-xl-2, div.bootstrap .py-xl-2 {
      padding-top: 0.5rem !important; }
    div.bootstrap .pr-xl-2, div.bootstrap .px-xl-2 {
      padding-right: 0.5rem !important; }
    div.bootstrap .pb-xl-2, div.bootstrap .py-xl-2 {
      padding-bottom: 0.5rem !important; }
    div.bootstrap .pl-xl-2, div.bootstrap .px-xl-2 {
      padding-left: 0.5rem !important; }
    div.bootstrap .p-xl-3 {
      padding: 1rem !important; }
    div.bootstrap .pt-xl-3, div.bootstrap .py-xl-3 {
      padding-top: 1rem !important; }
    div.bootstrap .pr-xl-3, div.bootstrap .px-xl-3 {
      padding-right: 1rem !important; }
    div.bootstrap .pb-xl-3, div.bootstrap .py-xl-3 {
      padding-bottom: 1rem !important; }
    div.bootstrap .pl-xl-3, div.bootstrap .px-xl-3 {
      padding-left: 1rem !important; }
    div.bootstrap .p-xl-4 {
      padding: 1.5rem !important; }
    div.bootstrap .pt-xl-4, div.bootstrap .py-xl-4 {
      padding-top: 1.5rem !important; }
    div.bootstrap .pr-xl-4, div.bootstrap .px-xl-4 {
      padding-right: 1.5rem !important; }
    div.bootstrap .pb-xl-4, div.bootstrap .py-xl-4 {
      padding-bottom: 1.5rem !important; }
    div.bootstrap .pl-xl-4, div.bootstrap .px-xl-4 {
      padding-left: 1.5rem !important; }
    div.bootstrap .p-xl-5 {
      padding: 3rem !important; }
    div.bootstrap .pt-xl-5, div.bootstrap .py-xl-5 {
      padding-top: 3rem !important; }
    div.bootstrap .pr-xl-5, div.bootstrap .px-xl-5 {
      padding-right: 3rem !important; }
    div.bootstrap .pb-xl-5, div.bootstrap .py-xl-5 {
      padding-bottom: 3rem !important; }
    div.bootstrap .pl-xl-5, div.bootstrap .px-xl-5 {
      padding-left: 3rem !important; }
    div.bootstrap .m-xl-auto {
      margin: auto !important; }
    div.bootstrap .mt-xl-auto, div.bootstrap .my-xl-auto {
      margin-top: auto !important; }
    div.bootstrap .mr-xl-auto, div.bootstrap .mx-xl-auto {
      margin-right: auto !important; }
    div.bootstrap .mb-xl-auto, div.bootstrap .my-xl-auto {
      margin-bottom: auto !important; }
    div.bootstrap .ml-xl-auto, div.bootstrap .mx-xl-auto {
      margin-left: auto !important; } }
  div.bootstrap .text-justify {
    text-align: justify !important; }
  div.bootstrap .text-nowrap {
    white-space: nowrap !important; }
  div.bootstrap .text-truncate {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap; }
  div.bootstrap .text-left {
    text-align: left !important; }
  div.bootstrap .text-right {
    text-align: right !important; }
  div.bootstrap .text-center {
    text-align: center !important; }
  @media (min-width: 576px) {
    div.bootstrap .text-sm-left {
      text-align: left !important; }
    div.bootstrap .text-sm-right {
      text-align: right !important; }
    div.bootstrap .text-sm-center {
      text-align: center !important; } }
  @media (min-width: 768px) {
    div.bootstrap .text-md-left {
      text-align: left !important; }
    div.bootstrap .text-md-right {
      text-align: right !important; }
    div.bootstrap .text-md-center {
      text-align: center !important; } }
  @media (min-width: 992px) {
    div.bootstrap .text-lg-left {
      text-align: left !important; }
    div.bootstrap .text-lg-right {
      text-align: right !important; }
    div.bootstrap .text-lg-center {
      text-align: center !important; } }
  @media (min-width: 1200px) {
    div.bootstrap .text-xl-left {
      text-align: left !important; }
    div.bootstrap .text-xl-right {
      text-align: right !important; }
    div.bootstrap .text-xl-center {
      text-align: center !important; } }
  div.bootstrap .text-lowercase {
    text-transform: lowercase !important; }
  div.bootstrap .text-uppercase {
    text-transform: uppercase !important; }
  div.bootstrap .text-capitalize {
    text-transform: capitalize !important; }
  div.bootstrap .font-weight-light {
    font-weight: 300 !important; }
  div.bootstrap .font-weight-normal {
    font-weight: 400 !important; }
  div.bootstrap .font-weight-bold {
    font-weight: 700 !important; }
  div.bootstrap .font-italic {
    font-style: italic !important; }
  div.bootstrap .text-white {
    color: #fff !important; }
  div.bootstrap .text-primary {
    color: #007bff !important; }
  div.bootstrap a.text-primary:focus, div.bootstrap a.text-primary:hover {
    color: #0062cc !important; }
  div.bootstrap .text-secondary {
    color: #6c757d !important; }
  div.bootstrap a.text-secondary:focus, div.bootstrap a.text-secondary:hover {
    color: #545b62 !important; }
  div.bootstrap .text-success {
    color: #28a745 !important; }
  div.bootstrap a.text-success:focus, div.bootstrap a.text-success:hover {
    color: #1e7e34 !important; }
  div.bootstrap .text-info {
    color: #17a2b8 !important; }
  div.bootstrap a.text-info:focus, div.bootstrap a.text-info:hover {
    color: #117a8b !important; }
  div.bootstrap .text-warning {
    color: #ffc107 !important; }
  div.bootstrap a.text-warning:focus, div.bootstrap a.text-warning:hover {
    color: #d39e00 !important; }
  div.bootstrap .text-danger {
    color: #dc3545 !important; }
  div.bootstrap a.text-danger:focus, div.bootstrap a.text-danger:hover {
    color: #bd2130 !important; }
  div.bootstrap .text-light {
    color: #f8f9fa !important; }
  div.bootstrap a.text-light:focus, div.bootstrap a.text-light:hover {
    color: #dae0e5 !important; }
  div.bootstrap .text-dark {
    color: #343a40 !important; }
  div.bootstrap a.text-dark:focus, div.bootstrap a.text-dark:hover {
    color: #1d2124 !important; }
  div.bootstrap .text-muted {
    color: #6c757d !important; }
  div.bootstrap .text-hide {
    font: 0/0 a;
    color: transparent;
    text-shadow: none;
    background-color: transparent;
    border: 0; }
  div.bootstrap .visible {
    visibility: visible !important; }
  div.bootstrap .invisible {
    visibility: hidden !important; }
  @media print {
    div.bootstrap *, div.bootstrap ::after, div.bootstrap ::before {
      text-shadow: none !important;
      box-shadow: none !important; }
    div.bootstrap a:not(.btn) {
      text-decoration: underline; }
    div.bootstrap abbr[title]::after {
      content: " (" attr(title) ")"; }
    div.bootstrap pre {
      white-space: pre-wrap !important; }
    div.bootstrap blockquote, div.bootstrap pre {
      border: 1px solid #999;
      page-break-inside: avoid; }
    div.bootstrap thead {
      display: table-header-group; }
    div.bootstrap img, div.bootstrap tr {
      page-break-inside: avoid; }
    div.bootstrap h2, div.bootstrap h3, div.bootstrap p {
      orphans: 3;
      widows: 3; }
    div.bootstrap h2, div.bootstrap h3 {
      page-break-after: avoid; }
    @page {
      div.bootstrap {
        size: a3; } }
    div.bootstrap body {
      min-width: 992px !important; }
    div.bootstrap .container {
      min-width: 992px !important; }
    div.bootstrap .navbar {
      display: none; }
    div.bootstrap .badge {
      border: 1px solid #000; }
    div.bootstrap .table {
      border-collapse: collapse !important; }
    div.bootstrap .table td, div.bootstrap .table th {
      background-color: #fff !important; }
    div.bootstrap .table-bordered td, div.bootstrap .table-bordered th {
      border: 1px solid #ddd !important; } }
